# Should be included by user model that must be authorized
module AuthorizationUserConcern
  extend ActiveSupport::Concern

  included do
    # the user is connected to auth items via the auth_roles
    has_and_belongs_to_many :auth_roles, autosave: true

    # get all auth items that the user has through his roles
    #
    # If an item is provided by multiple roles, it is added once
    def auth_items
      unless @items
        @items = Hash.new
        auth_roles.each do |role|
          role.auth_items.each do |item|
            @items[item.id] =  item
          end
        end
      end
      @items.values
    end

    # gewünscht ist EINE Rolle pro Benutzertyp.
    # def auth_items
    #   role = AuthRole.where(user_type: person.class.name).take
    #   return role.auth_items if role
    #   return []
    # end

    # this adds the default roles for user_type to user
     before_create do
        self.auth_roles << AuthRole.where(user_type: identifiable_type, is_default_role: true).all
     end

  end

  module ClassMethods
  end

end