module Grants
  class PortfolioItem
      def self.subject; 'Portfolio::Item'; end
      def self.grants
        {
          create: {
              #----------------------------------------------------------------
              # USAGES:
              # authorize!( :create,portfolio_item_ready_for_save )
              # can? (:create, Portfolio::Item )
              # Client.accessible_by(current_ability,:create_portfolio_item)
              #----------------------------------------------------------------
              name: 'Anlegen',
              scopes: {
                  own_institutions: {
                      name: 'in eigenen Einrichtungen',
                      user_types: [::Teacher],
                      default_for:  [::Teacher],
                      teacher: -> ability, teacher do
                        ability.can :create, ::Portfolio::Item, { # when the item is for a client group at an institution where the teacher is working
                            portfolio: { client_group: { institution: { teacher_institution_relations: { teacher_id: teacher.id }  }  }  }
                        }
                        ability.can :create, ::Portfolio::Item, {  # when the item is for a client at an institution where the teacher is working
                            portfolio: {  client: {   institution: { teacher_institution_relations: {  teacher_id: teacher.id  }   }  }   }
                        }
                        ability.can :create_portfolio_item, ::Client, {  # when the client is at an institution where the teacher is working
                            institution: { teacher_institution_relations: { teacher_id: teacher.id }  }
                        }
                      end
                  },
                  special_ed_own_institutions: {
                      name: 'als Sonderpädagoge in eigenen Einrichtungen',
                      user_types: [::Teacher],
                      default_for:  [],
                      teacher: -> ability, teacher do
                        ability.can :create, ::Portfolio::Item, { # when the item is for a client at an institution where the teacher is working as a special ed
                            portfolio: { client: { institution: { teacher_institution_relations: {  teacher: {  teacher_category: { is_special_ed: true},  id: teacher.id  } }  }  }  }
                        }
                        ability.can :create, ::Portfolio::Item, { # when the item is for a client group at an institution where the teacher is working as a special ed
                            portfolio: { client_group: { institution: { teacher_institution_relations: {  teacher: {  teacher_category: { is_special_ed: true},  id: teacher.id  } }  }  }  }
                        }
                        ability.can :create_portfolio_item, ::Client, {  # when the client is at an institution where the teacher is working as a special ed
                            institution: { teacher_institution_relations: {  teacher: {  teacher_category: { is_special_ed: true},  id: teacher.id  }  }  }
                        }
                      end
                  },
                  in_own_client_group: {
                      name: 'in der eigenen Klasse',
                      user_types: [::Teacher],
                      default_for:  [],
                      teacher: -> ability, teacher do
                        ability.can :create, ::Portfolio::Item, { # when the item is for a client_group where the teacher is class teacher
                            portfolio: {  client_group: { teacher_id: teacher.id  }  }
                        }
                        ability.can :create, ::Portfolio::Item, {  # when the item is for a client where the teacher is class teacher
                            portfolio: {  client: { client_group: { teacher_id: teacher.id }  } }
                        }
                        ability.can :create_portfolio_item, ::Client, { # when the client is in a client group where the teacher is class teacher
                            client_group: { teacher_id: teacher.id }
                        }
                      end
                  },
                  involved_in_expertise: {
                      name: 'im Gutachten beteiligt',
                      user_types: [::Teacher],
                      default_for:  [::Teacher],
                      teacher: -> ability, teacher do
                        ability.can :create, ::Portfolio::Item, { portfolio: { client: { expertise_teacher_id:  teacher.id } }   }
                      end
                  },
                  involved_in_comment: {
                      name: 'wenn über Kommentare beteiligt',
                      user_types: [::Teacher],
                      default_for:  [::Teacher],
                      teacher: -> ability, teacher do
                        # feature_439: also all item of a portfolio can be updated where the teacher is referenced in some portfolio comment as reviewer
                        ability.can :create, ::Portfolio::Item, {
                            portfolio: {
                                portfolio_items: {
                                    portfolio_comments: {teacher_id: teacher.id, teacher_perform_review: true}
                                }
                            }
                        }
                      end
                  }
              }
          },
          read: {
              #----------------------------------------------------------------
              # USAGES:
              # authorize!( :read, portfolio_item_about_to_be_shown )
              # can? (:read, Portfolio::Item )
              # can? (:read, portfolio_item_instance )
              # ::Portfolio::Item.accessible_by( current_ability)
              #----------------------------------------------------------------
              name: 'Anzeigen',
              scopes: {
                  system_wide: {
                      name: 'Systemweit',
                      user_types: [::Manager],
                      default_for: [],
                      manager: -> ability, manager do
                        ability.can :read, ::Portfolio::Item # all items accessible
                        ability.can [:read,:create], ::Portfolio::Comment # all items accessible
                        ability.can [:update,:destroy], ::Portfolio::Comment, {
                            author_id: manager.id, author_type: 'Manager'
                        }
                      end
                  },
                  own_institutions: {
                      name: 'in eigenen Einrichtungen',
                      user_types: [::Manager,::Teacher],
                      default_for:  [::Manager,::Teacher],
                      manager: -> ability, manager do
                        ability.can :read, ::Portfolio::Item, { # when the item is for a client in an institution below the managers institution
                            portfolio: { client: { institution: { all_parent_institutions: { parent_id: manager.institution_id } } }  }
                        }
                        ability.can :read, ::Portfolio::Item, { # when the item is for a client_group in an institution below the managers institution
                            portfolio: {  client_group: { institution: { all_parent_institutions: { parent_id: manager.institution_id }  } }  }
                        }
                        ability.can [:read,:create], ::Portfolio::Comment, {
                            portfolio_item: { portfolio: { client: { institution: { all_parent_institutions: { parent_id: manager.institution_id } } }  } }
                        }
                        ability.can [:read,:create], ::Portfolio::Comment, {
                            portfolio_item: { portfolio: {  client_group: { institution: { all_parent_institutions: { parent_id: manager.institution_id }  } }  } }
                        }
                        ability.can [:update,:destroy], ::Portfolio::Comment, {
                            author_id: manager.id, author_type: 'Manager'
                        }
                      end,
                      teacher: -> ability, teacher do
                        ability.can :read, ::Portfolio::Item, { # when the item is for a client in an institution where teacher is working
                            portfolio: {  client: { institution: { teacher_institution_relations: { teacher_id: teacher.id } }  } }
                        }
                        ability.can :read, ::Portfolio::Item, {  # when the item is for a client group in an institution where teacher is working
                            portfolio: {  client_group: { institution: { teacher_institution_relations: { teacher_id: teacher.id } }  } }
                        }
                        ability.can [:read,:create], ::Portfolio::Comment, {
                            portfolio_item: { portfolio: {  client: { institution: { teacher_institution_relations: { teacher_id: teacher.id } }  } } }
                        }
                        ability.can [:read,:create], ::Portfolio::Comment, {
                            portfolio_item: { portfolio: {  client_group: { institution: { teacher_institution_relations: { teacher_id: teacher.id } }  } } }
                        }
                        ability.can [:update,:destroy], ::Portfolio::Comment, {
                            author_id: teacher.id, author_type: 'Teacher'
                        }
                      end
                  },
                  involved: {
                      name: 'wenn beteiligt',
                      user_types: [::Teacher],
                      default_for:  [::Teacher],
                      teacher: -> ability, teacher do
                        ability.can :read, ::Portfolio::Item, { # when teacher is directly involved in item
                            involved_teachers: {id: teacher.id}
                        }
                        ability.can :read, ::Portfolio::Item, { # when teacher is involved in an evaluation of the item
                            evaluable_target_agreements: {evaluation: {evaluation_involved_teachers: {teacher_id: teacher.id}}    }
                        }
                        ability.can [:read,:create], ::Portfolio::Comment, {
                            portfolio_item: { involved_teachers: {id: teacher.id} }
                        }
                        ability.can [:read,:create], ::Portfolio::Comment, {
                            portfolio_item: { evaluable_target_agreements: {evaluation: {evaluation_involved_teachers: {teacher_id: teacher.id}}    } }
                        }
                        ability.can [:update,:destroy], ::Portfolio::Comment, {
                            author_id: teacher.id, author_type: 'Teacher'
                        }
                      end
                  },
                  involved_in_expertise: {
                      name: 'im Gutachten beteiligt',
                      user_types: [::Teacher,::Manager],
                      default_for:  [::Teacher,::Manager],
                      teacher: -> ability, teacher do
                        ability.can :read, ::Portfolio::Item, { portfolio: { client: { expertise_teacher_id:  teacher.id } }   }
                        ability.can :read, ::Portfolio::Item, {  portfolio: { client: {  expertise_institution_id:  teacher.institutions.ids } }  }
                      end,
                      manager: -> ability, manager do
                        ability.can :read, ::Portfolio::Item, { portfolio: { client: { expertise_manager_id:  manager.id } }   }
                      end
                  },
                  involved_in_comment: {
                      name: 'wenn über Kommentare beteiligt',
                      user_types: [::Teacher],
                      default_for:  [::Teacher],
                      teacher: -> ability, teacher do
                        ability.can [:update,:destroy], ::Portfolio::Comment, {
                            author_id: teacher.id, author_type: 'Teacher'
                        }
                        ability.can [:read,:create], ::Portfolio::Comment, {
                            portfolio_item: {
                              portfolio: {
                                  portfolio_items: {
                                      portfolio_comments: {teacher_id: teacher.id, teacher_perform_review: true}
                                  }
                              }
                            }
                        }
                        ability.can [:read,:create], ::Portfolio::Comment, {
                            portfolio_item: {
                                portfolio: {
                                    portfolio_items: {
                                        portfolio_comments: {teacher_id: teacher.id, teacher_choose_reviewer: true}
                                    }
                                }
                            }
                        }
                        # feature_439: also all item of a portfolio can be read where the teacher is referenced in some portfolio comment
                        ability.can :read, ::Portfolio::Item, {
                            portfolio: {
                                portfolio_items: {
                                    portfolio_comments: {teacher_id: teacher.id, teacher_perform_review: true}
                                }
                            }
                        }
                        ability.can :read, ::Portfolio::Item, {
                            portfolio: {
                                portfolio_items: {
                                    portfolio_comments: {teacher_id: teacher.id, teacher_choose_reviewer: true}
                                }
                            }
                        }
                      end
                  },
              }
          },
          update: {
              #----------------------------------------------------------------
              # USAGES:
              # authorize!( :update, portfolio_item_to_be_saved )
              # can? (:update, Portfolio::Item )
              # can? (:update, portfolio_item_instance )
              # ::Portfolio::Item.accessible_by( current_ability,:update )
              #----------------------------------------------------------------
              name: 'Bearbeiten',
              scopes: {
                  own_institutions: {
                      name: 'in eigenen Einrichtungen',
                      user_types: [::Teacher],
                      default_for:  [::Teacher],
                      teacher: -> ability, teacher do
                        ability.can :update, ::Portfolio::Item, { # when the item is for a client group at an institution where the teacher is working
                            portfolio: { client_group: { institution: { teacher_institution_relations: { teacher_id: teacher.id }  }  }  }
                        }
                        ability.can :update, ::Portfolio::Item, {  # when the item is for a client at an institution where the teacher is working
                            portfolio: {  client: {   institution: { teacher_institution_relations: {  teacher_id: teacher.id  }   }  }   }
                        }
                      end
                  },
                  involved: {
                      name: 'wenn beteiligt',
                      user_types: [::Teacher],
                      default_for:  [],
                      teacher: -> ability, teacher do
                        ability.can :update, ::Portfolio::Item, { # when teacher is directly involved in item
                            involved_teachers: {id: teacher.id}
                        }
                        ability.can :update, ::Portfolio::Item, { # when teacher is involved in an evaluation of the item
                            evaluable_target_agreements: {evaluation: {evaluation_involved_teachers: {id: teacher.id}}}
                        }
                      end
                  },
                  special_ed_own_institutions: {
                      name: 'als Sonderpädagoge in eigenen Einrichtungen',
                      user_types: [::Teacher],
                      default_for:  [],
                      teacher: -> ability, teacher do
                        ability.can :update, ::Portfolio::Item, {  # when teacher is working at same institution as the client_group and is also a special ed there
                            portfolio: {client_group: {institution: {teacher_institution_relations: {teacher: {teacher_category: {is_special_ed: true}, id: teacher.id}}}}}
                        }
                        ability.can :update, ::Portfolio::Item, { # when teacher is working at same institution as the client and is also a special ed there
                            portfolio: {client: {institution: {teacher_institution_relations: {teacher: {teacher_category: {is_special_ed: true}, id: teacher.id}}}}}
                        }
                      end
                  },
                  in_own_client_group: {
                      name: 'in der eigenen Klasse',
                      user_types: [::Teacher],
                      default_for:  [],
                      teacher: -> ability, teacher do
                        ability.can :update, ::Portfolio::Item, {  # when teacher is class teacher of client_group of the item
                            portfolio: {  client_group: {  teacher_id: teacher.id  }  }
                        }
                        ability.can :update, ::Portfolio::Item, { # when teacher is class teacher of client of the item
                            portfolio: { client: {  client_group: {  teacher_id: teacher.id }  } }
                        }
                      end
                  },
                  involved_in_expertise: {
                      name: 'im Gutachten beteiligt',
                      user_types: [::Teacher],
                      default_for:  [::Teacher],
                      teacher: -> ability, teacher do
                        ability.can :update, ::Portfolio::Item, { portfolio: { client: { expertise_teacher_id:  teacher.id } }   }
                      end
                  },
                  involved_in_comment: {
                      name: 'wenn über Kommentare beteiligt',
                      user_types: [::Teacher],
                      default_for:  [::Teacher],
                      teacher: -> ability, teacher do
                        # feature_439: also all item of a portfolio can be updated where the teacher is referenced in some portfolio comment as reviewer
                        ability.can :update, ::Portfolio::Item, {
                            portfolio: {
                                portfolio_items: {
                                    portfolio_comments: {teacher_id: teacher.id, teacher_perform_review: true}
                                }
                            }
                        }
                      end
                  }
              }
          },
          destroy: {
              name: 'Löschen',
              scopes: {
                  own_institutions: {
                      name: 'in eigenen Einrichtungen',
                      user_types: [::Teacher],
                      default_for:  [::Teacher],
                      teacher: -> ability, teacher do
                        ability.can :destroy, ::Portfolio::Item, {
                            portfolio: {client: {institution: {teacher_institution_relations: {teacher_id: teacher.id}}}}
                        }
                      end
                  },
                  involved_at_own_institutions: {
                      name: 'in eigenen Einrichtungen wenn beteiligt',
                      user_types: [::Teacher],
                      default_for:  [],
                      teacher: -> ability, teacher do
                        ability.can :destroy, ::Portfolio::Item, {
                            portfolio: {
                                client_group: {
                                    institution: {
                                        teacher_institution_relations: {
                                            teacher_id: teacher.id
                                        }
                                    }
                                }
                            },
                            involved_teachers: {
                                id: teacher.id
                            }
                        }
                        ability.can :destroy, ::Portfolio::Item, {
                            portfolio: {
                                client: {
                                    institution: {
                                        teacher_institution_relations: {
                                            teacher_id: teacher.id
                                        }
                                    }
                                }
                            },
                            involved_teachers: {
                                id: teacher.id
                            }
                        }
                        ability.can :destroy, ::Portfolio::Item, {
                            portfolio: {
                                client: {
                                    institution: {
                                        teacher_institution_relations: {
                                            teacher_id: teacher.id
                                        }
                                    }
                                }
                            },
                            evaluable_target_agreements: {
                                evaluation:{
                                    evaluation_involved_teachers:{
                                        teacher_id: teacher.id
                                    }
                                }
                            }
                        }
                        ability.can :destroy, ::Portfolio::Item, {
                            portfolio: {
                                client_group: {
                                    institution: {
                                        teacher_institution_relations: {
                                            teacher_id: teacher.id
                                        }
                                    }
                                }
                            },
                            evaluable_target_agreements: {
                                evaluation:{
                                    evaluation_involved_teachers:{
                                        teacher_id: teacher.id
                                    }
                                }
                            }
                        }
                      end
                  },
                  special_ed_own_institutions: {
                      name: 'als Sonderpädagoge in eigenen Einrichtungen',
                      user_types: [::Teacher],
                      default_for:  [],
                      teacher: -> ability, teacher do
                        ability.can :destroy, ::Portfolio::Item, {
                            portfolio: {
                                client_group: {
                                    institution:{
                                        teacher_institution_relations: {
                                            teacher: {
                                                teacher_category: { is_special_ed: true},
                                                id: teacher.id
                                            }
                                        }
                                    }
                                }
                            },
                        }
                        ability.can :destroy, ::Portfolio::Item, {
                            portfolio: {
                                client: {
                                    institution:{
                                        teacher_institution_relations: {
                                            teacher: {
                                                teacher_category: { is_special_ed: true},
                                                id: teacher.id
                                            }
                                        }
                                    }
                                }
                            },
                        }
                      end
                  },
                  in_own_client_group: {
                      name: 'in der eigenen Klasse',
                      user_types: [::Teacher],
                      default_for:  [],
                      teacher: -> ability, teacher do
                        ability.can :destroy, ::Portfolio::Item, {
                            portfolio: {
                                client_group: {
                                    teacher_id: teacher.id
                                }
                            }
                        }
                        ability.can :destroy, ::Portfolio::Item, {
                            portfolio: {
                                client: {
                                    client_group: {
                                        teacher_id: teacher.id
                                    }
                                }
                            }
                        }
                      end
                  },
                  involved_in_expertise: {
                      name: 'im Gutachten beteiligt',
                      user_types: [::Teacher],
                      default_for:  [::Teacher],
                      teacher: -> ability, teacher do
                        ability.can :destroy, ::Portfolio::Item, { portfolio: { client: { expertise_teacher_id:  teacher.id } }   }
                      end
                  },
              }
          }
        }
      end
  end
end