class ChecklistTplsController < ApplicationController

  before_action :set_checklist_tpl, only: [:show, :edit, :update, :destroy]


  def index
    authorize!(:read, ChecklistTpl)
    @checklist_tpls_grid = ChecklistTplsGrid.new(params[:checklist_tpls_grid]) do |scope|
      scope.page(params[:page]).per(25)
    end
    add_breadcrumb "Checklisten", checklist_tpls_path
  end


  def new
    authorize!(:create, ChecklistTpl)
    @checklist_tpl = ChecklistTpl.new
    add_breadcrumb "Checklisten", checklist_tpls_path
    add_breadcrumb "Neu"
  end

  def edit
    authorize!(:update, @checklist_tpl)
    add_breadcrumb "Checklisten", checklist_tpls_path
    add_breadcrumb "#{@checklist_tpl.name} bearbeiten", edit_checklist_tpl_path(@checklist_tpl)
  end

  def create
    authorize!(:create, ChecklistTpl)
    @checklist_tpl = ChecklistTpl.new(checklist_tpl_params)

    respond_to do |format|
      if @checklist_tpl.save
        format.html { redirect_to checklist_tpls_path, success: 'Gespeichert' }
      else
        format.html { render :new }
      end
    end
  end

  def update
    authorize!(:update, @checklist_tpl)
    respond_to do |format|
      if @checklist_tpl.update(checklist_tpl_params)
        format.html { redirect_to checklist_tpls_path, success: 'Gespeichert' }
      else
        format.html { render :edit }
      end
    end
  end

  def destroy
    authorize!(:destroy, @checklist_tpl)
    respond_to do |format|
      @checklist_tpl.destroy
      format.html { redirect_to checklist_tpls_path, success: 'Gelöscht' }
    end
  end

  private
  # Use callbacks to share common setup or constraints between actions.
  def set_checklist_tpl
    @checklist_tpl = ChecklistTpl.where(id: params[:id]).take!
  end

  # Never trust parameters from the scary internet, only allow the white list through.
  def checklist_tpl_params
    params.require(:checklist_tpl).permit(
        :id, :portfolio_specialization_id, :name, :checklist_type, :is_active,
        checklist_group_tpls_attributes: [
            :id, :portfolio_specialization_id, :is_mandatory, :name, :_destroy,
            checklist_question_tpls_attributes: [
                :id, :checklist_tpl_id,:portfolio_specialization_id,:name,:is_checkable,:has_freetext,
                :has_portfolio_item_references, :is_mandatory, :accepts_upload,:_destroy
            ]
        ]
    )
  end


end
