class DiagnosticsController < ApplicationController

  # actually, the create uses no user input, so no harm can be done here.
  skip_before_action :verify_authenticity_token, only: [:create_from_remote]

  def index
    @grid = DiagnosticsGrid.new(params[:diagnostics_grid]) do |scope|
      scope.page(params[:page])
    end
    add_breadcrumb "Diagnostiken", :diagnostics_path
  end

  def show
    @diagnostic = Diagnostic.where(catalog_id: params[:catalog_id]).take!
    add_breadcrumb "Diagnostiken", :diagnostics_path
    add_breadcrumb @diagnostic.abbreviation, diagnostic_path(@diagnostic.catalog_id)
  end

  def new
    @diagnostic = Diagnostic.new
    authorize!(:create, Diagnostic)
    add_breadcrumb "Diagnostiken", :diagnostics_path
    add_breadcrumb "Neue Diagnostik"
  end

  def create
    add_breadcrumb "Diagnostiken", :diagnostics_path
    add_breadcrumb "Neue Diagnostik"
    @diagnostic = Diagnostic.new(diagnostic_params)
    authorize!(:create, @diagnostic)
    respond_to do |format|
      if @diagnostic.save
        format.html { redirect_to edit_stock_diagnostic_path(@diagnostic.catalog_id),  success: 'Gespeichert'}
      else
        flash.now[:danger] = 'Bitte prüfen Sie Ihre Eingaben'
        format.html { render :new }
      end
    end
  end

  def edit
    @diagnostic = Diagnostic.where(catalog_id: params[:catalog_id]).take!
    authorize!(:update, @diagnostic)
    add_breadcrumb "Diagnostiken", :diagnostics_path
    add_breadcrumb @diagnostic.abbreviation, diagnostic_path(@diagnostic.catalog_id)
  end

  def update
    @diagnostic = Diagnostic.where(catalog_id: params[:catalog_id]).take!
    @diagnostic.assign_attributes(diagnostic_params)
    authorize!(:update, @diagnostic)
    add_breadcrumb "Diagnostiken", :diagnostics_path
    add_breadcrumb @diagnostic.abbreviation, diagnostic_path(@diagnostic)
    respond_to do |format|
      if @diagnostic.save
        format.html { redirect_to diagnostics_path,  success: 'Gespeichert'}
      else
        flash.now[:danger] = 'Bitte prüfen Sie Ihre Eingaben'
        format.html { render :edit }
      end
    end
  end

  def edit_stock
    @diagnostic = Diagnostic.where(catalog_id: params[:catalog_id]).take!
    authorize!(:read, @diagnostic)
    authorize!(:read, Institution)
    add_breadcrumb "Diagnostiken", :diagnostics_path
    add_breadcrumb @diagnostic.abbreviation, edit_stock_diagnostic_path(@diagnostic.catalog_id)
  end

  def update_stock
    @diagnostic = Diagnostic.where(catalog_id: params[:catalog_id]).take!
    @diagnostic.assign_attributes(diagnostic_stock_params)
    respond_to do |format|
      if @diagnostic.save
        format.html { redirect_to edit_stock_diagnostic_path(@diagnostic.catalog_id),  success: 'Gespeichert'}
      else
        flash.now[:danger] = 'Bitte prüfen Sie Ihre Eingaben'
        format.html { render :edit_stock }
      end
    end
  end

  def create_from_remote
    @diagnostic = Diagnostic.where(catalog_id: params[:catalog_id]).take
    if @diagnostic.present?
      flash[:success] = "Der Katalogeintrag wurde hinzugefügt."
      redirect_to edit_stock_diagnostic_path @diagnostic.catalog_id and return
    end
    remote_diagnostic = CsbApi::Diagnostic.includes('diagnostic-images','diagnostic-characteristics','diagnostic-norms','portfolio-specializations').where(id: params[:catalog_id]).take(1)
    if remote_diagnostic.blank?
      flash[:danger] = "Der Katalogeintrag existiert nicht."
      redirect_to  remote_diagnostics_path and return
    end
    @diagnostic = remote_diagnostic.first.build_model
    authorize!(:create, @diagnostic)
    respond_to do |format|
      if @diagnostic.save(validate: false)
        format.html { redirect_to edit_stock_diagnostic_path @diagnostic.catalog_id,  success: 'Der Katalogeintrag wurde hinzugefügt.'}
      else
        flash.now[:danger] = 'Der zentrale Bibiliothekseintrag ist leider unvollständig und muss noch ergänzt werden.'
        format.html { render :new }
      end
    end
  end

  def destroy
    diagnostic = Diagnostic.where(id: params[:catalog_id]).take!
    diagnostic.destroy if diagnostic
    flash[:success] = "Der Eintrag wurde gelöscht."
    redirect_to  diagnostics_path
  end

  private
  def diagnostic_stock_params
    params.require(:diagnostic).permit(
        # nothing is permitted for actual diagnostic, as they are updated from csb catalog.
        diagnostic_institution_stocks_attributes: [
            :id,:institution_id,:diagnostic_id, :stock
        ]
    )
  end

  def diagnostic_params
    params.require(:diagnostic).permit(
        :title,
        :authors,
        :year,
        :subtitle,
        :abbreviation,
        :min_level,
        :max_level,
        :short_description,
        :description,
        :url,
        :is_range_okologie,
        :is_range_integration,
        :is_range_intensitat,
        :age_from,
        :age_to,
        :cover_image,
        :cover_image_cache,
        characteristics_attributes: [
          :id,
          :name, 
          :is_positive,
          :diagnostic_id
        ],
        norm_scales_attributes: [
          :id,
          :name,
          :range_from,
          :range_to,
          :std_dev,
          :avg,
          :cut_off_low,
          :cut_off_sub_avg,
          :cut_off_above_avg,
          :cut_off_high,
          :catalog_fields,
          :diagnostic_id
        ]
    );                
  end

end
