# TODO:  all these checks on institution_type are a nightmare, refactor institutions to STI ASAP with model + controller per type
class InstitutionsController < ApplicationController
  include PdfConcern

  def index_redirect
    # references issue #345
    redirect_to (params[:institution_type].is_a? Array) ? "/institutions_t/#{params[:institution_type].join('/')}" : "/institutions_t/#{params[:institution_type]}"
    # if at this point, the location is not the correct scheme ( should not happen but does ), we set it explicit
    if request.ssl?
      self.location= URI(location).tap{|uri| uri.scheme='https'}.to_s
    end
    # if the redirect is still not performed by the browser, we try with a script.
    self.response_body = %(<!DOCTYPE html><html><head><script type='text/javascript'>window.location.replace('#{self.location}');</script></head><body><a href="#{self.location}">Redirecting...</a></body></html>)
  end

  def index
    authorize!(:read, Institution)
    it = institution_type;it = [it] if it.is_a? String
    @institution_grid = InstitutionGrid.new(params[:institution_grid]) do |scope|
      scope.accessible_by(current_ability).page(params[:page]).per(25).only_type(it)
    end
    add_first_bread_crumb
    @it = it
  end

  def show
    @institution = Institution.where(id: params[:id]).take!
    authorize!(:read, @institution)
    @child_institutions = @institution.child_institutions.accessible_by(current_ability)
    add_first_bread_crumb(@institution.institution_type)
    add_breadcrumb "#{@institution.name}", institution_path(@institution), title: "Einrichtung anzeigen"
    render "institutions/#{@institution.institution_type}/show"
  end

  # select parent institution for a new institution
  def select
    it = institution_type;it = it.first if it.is_a? Array
    authorize!(:create, Institution)
    redirect_to new_institution_path(institution_type: it) and return  if it == Institution::TYPE_EXTERN
    add_first_bread_crumb
    add_breadcrumb "neu", :new_institution_path    
    render "institutions/#{it}/select"
  end

  def new
    it = institution_type;it = it.first if it.is_a? Array
    if it == Institution::TYPE_SCHOOL
      unless params['school_no'].present?
        flash[:danger] = "Konnte die Schulnummer #{params['school_no']} nicht finden."
        redirect_to select_new_institution_path(institution_type: it) and return
      end
      template = CsbApi::Institution.includes('address').includes('institution-category').where(school_no: params['school_no']).take(1)
      if template.present?
        if Institution.exists?(school_no: template.first['school-no'])
          flash[:danger] = "Die Schulnummer #{params['school_no']} ist bereits angelegt."
          redirect_to select_new_institution_path(institution_type: it) and return
        end
        @institution = template.first.build_model
      else
        flash[:danger] = "Konnte die Schulnummer #{params['school_no']} nicht finden."
        redirect_to select_new_institution_path(institution_type: it) and return
      end
    end
    @institution = Institution.new unless @institution.present?
    @institution.build_address unless @institution.address.present?
    @institution.institution_type = it
    if it != Institution::TYPE_EXTERN
      @institution.parent_institution = Institution.where(id: params['parent_id']).take! if params['parent_id'].present?
    end
    authorize!(:create, Institution)
    add_first_bread_crumb
    add_breadcrumb "neu", :new_institution_path
    render "institutions/#{@institution.institution_type}/new"
  end

  def edit
    @institution = Institution.where(id: params[:id]).take!
    authorize!(:update, @institution)
    add_first_bread_crumb(@institution.institution_type)
    add_breadcrumb "#{@institution.name}", institution_path(@institution), title: "Einrichtung anzeigen"
    add_breadcrumb "bearbeiten", edit_institution_path(@institution)    
  end

  def create
    it = institution_type;it = it.first if it.is_a? Array
    @institution = Institution.new(institution_params)
    authorize!(:create, @institution)
    add_first_bread_crumb(@institution.institution_type)
    add_breadcrumb "neu", :new_institution_path
    if @institution.save
      # bei Bedarf zum Formular für neue Externe Begleitperson zurück kehren
      if session.has_key?(:supporter_id)
        flash[:info] = "Erfolgreich gespeichert. Nun kann die neue externe Einrichtung ausgewählt werden."
        path = "#{edit_supporter_path(session[:supporter_id])}?supporter[institution_choice]=2&supporter[institution_id]=#{@institution.id}#supporter-institution"
        session.delete(:supporter_id)
        redirect_to path and return
      end
      redirect_to institution_path(@institution)
    else
      render "institutions/#{@institution.institution_type}/new"
    end
  end

  def update
    @institution = Institution.where(id: params[:id]).take!
    authorize!(:update, @institution)
    add_first_bread_crumb(@institution.institution_type)
    add_breadcrumb "#{@institution.name}", institution_path(@institution), title: "Einrichtung anzeigen"
    add_breadcrumb "bearbeiten", edit_institution_path(@institution)
    @institution.assign_attributes institution_params
    if @institution.save
      redirect_to @institution
    else
      render "edit"
    end
  end

  def destroy
    @institution = Institution.where(id: params[:id]).first
    authorize!(:destroy, @institution)
    unless @institution.cannot_be_destroyed?
      Institution.destroy_all(id: params[:id])
      redirect_to institutions_url(institution_type: @institution.institution_type), success: 'Einrichtung erfolgreich gelöscht.'
    else
      redirect_to institution_url(@institution), warning: @institution.cannot_be_destroyed_reason
    end

  end

  def preview_logo_pdf
    @institution = Institution.where(id: params[:institution_id]).take!
    authorize!(:read, @institution)
    add_first_bread_crumb
    add_breadcrumb "#{@institution.name}", institution_path(@institution), title: "Einrichtung anzeigen"
    respond_to do |format|
      format.pdf { render_pdf(
          "#{@institution.name}}.pdf",
          "institutions/#{@institution.institution_type}/show", #:show,
          title: "#{@institution.name}",
        )
      }
    end
  end

  def destroy_logo
    @institution = Institution.find(params[:institution_id])    
    authorize!(:update, @institution)
    respond_to do |format|
      @institution.remove_logo!
      if @institution.save        
        format.html { redirect_to edit_institution_url(@institution), success: "Das Logo wurde gelöscht." }
      else
        format.html { redirect_to edit_institution_url(@institution), danger: "nicht möglich" }
      end
    end
  end

  def stats
    @institution = Institution.where(id: params[:id]).take!
    SchoolStat.generate(@institution)
    @current_stat= SchoolStat.current_entry(@institution)
    @last_stat = SchoolStat.last_entry(@institution)
    authorize!(:read, @institution)
    add_first_bread_crumb(@institution.institution_type)
    add_breadcrumb "#{@institution.name}", institution_path(@institution), title: "Einrichtungsstatistik"
    render "institutions/#{@institution.institution_type}/stats"
  end

  private

    def institution_params
      params.require(:institution).permit(
        :institution_type, :name, :school_no, :parent_id, :institution_category_id,
         :allocation_formula_special_ed_level_1,
        :allocation_formula_special_ed_level_2,
        :allocation_formula_special_ed_level_3,
        :email, :fax, :website,:phone, :comment, :description,:logo,:logo_cache,
        educational_course_ids: [],
        address_attributes: [
          :id,:street,:city,:region,:country,:number,:zip
        ]
      )
    end

    def institution_type
      params[:institution_type] = params[:institution_type].split('/') if params[:institution_type]
      params[:institution_type] ? params[:institution_type] : Institution::TYPE_ORGANISATIONAL
    end

    def add_first_bread_crumb(it=false)
      it ||= institution_type;
      it = [it] if it.is_a? String
      if it.include?(Institution::TYPE_EXTERN)
        add_breadcrumb "Externe Einrichtungen", institutions_path(institution_type: Institution::TYPE_EXTERN)
      elsif it.include?(Institution::TYPE_ORGANISATIONAL)
        add_breadcrumb "Organisationseinheiten", institutions_path(institution_type: Institution::TYPE_ORGANISATIONAL)
      elsif it.include?(Institution::TYPE_SCHOOL) || it.include?(Institution::TYPE_EDUCATIONAL)
        #add_breadcrumb "Schulen und Bildungseinrichtungen", institutions_path(institution_type: [Institution::TYPE_SCHOOL, Institution::TYPE_EDUCATIONAL])
        add_breadcrumb "Schulen", institutions_path(institution_type: [Institution::TYPE_SCHOOL, Institution::TYPE_EDUCATIONAL])
      else
        add_breadcrumb "Einrichtungen", :institutions_path
      end
    end

end
