class UserPagesController < ApplicationController

  def logs
    unless current_user.super_admin?
      redirect_to :dashboard
    end
    if params[:size].present?
      size = [0,params[:size].to_i].max
    else
      size = 1024
    end
    if params[:context].present?
      context = [0,params[:context].to_i].max
    else
      context=20
    end
    if params[:grep].present?
      grep = params[:grep].gsub(/[^a-zA-Z0-9]/, "")
    else
      grep = nil
    end
    if size > 0
      if grep
        if context == 0
          @logs = `tail -n #{size} log/#{Rails.env}.log | grep '#{grep}' | lib/ansi2html.sh --bg=dark --palette=xterm`
        else
          @logs = `tail -n #{size} log/#{Rails.env}.log | grep -C#{context} '#{grep}' | lib/ansi2html.sh --bg=dark --palette=xterm`
        end
      else
        @logs = `tail -n #{size} log/#{Rails.env}.log | lib/ansi2html.sh --bg=dark --palette=xterm`
      end
    else
      if grep
        if context == 0
          @logs = `cat log/#{Rails.env}.log | grep '#{grep}' | lib/ansi2html.sh --bg=dark --palette=xterm`
        else
          @logs = `cat log/#{Rails.env}.log | grep -C#{context} '#{grep}' | lib/ansi2html.sh --bg=dark --palette=xterm`
        end
      else
        @logs = `cat log/#{Rails.env}.log | lib/ansi2html.sh --bg=dark --palette=xterm`
      end
    end
    render 'user_pages/logs', layout: false
  end

  def dashboard
    # authorization is not done here, as everyone can access his own dashboard
    if current_user.is_teacher?
      teacher_dashboard( current_user.person ) and return
    end
    if current_user.is_manager?
      redirect_to institutions_path and return
    end
    render :file => "#{Rails.root}/public/404.html",  :status => 404
  end

  def messages_inbox
    respond_to do |format|
      format.js do
        @grid = UserMessageGrid.new(params[:user_message_grid]) do
          scope = current_user.person.received_user_messages_message_box.page(params[:page]).per(25)
          scope = scope.order(created_at: :desc) unless params[:user_message_grid] && params[:user_message_grid].key?(:order)
          scope
        end
      end
    end
  end


  def messages_outbox
    respond_to do |format|
      format.js do
        @grid = UserMessageGrid.new(params[:user_message_grid]) do
          scope = current_user.person.sent_user_messages_message_box.page(params[:page]).per(25)
          scope = scope.order(created_at: :desc) unless params[:user_message_grid] && params[:user_message_grid].key?(:order)
          scope
        end
      end
    end
  end

  def messages_trash
    respond_to do |format|
      format.js do
        @grid = UserMessageGrid.new(params[:user_message_grid]) do
          scope = current_user.person.combined_user_messages_trash.page(params[:page]).per(25)
          scope = scope.order(created_at: :desc) unless params[:user_message_grid] && params[:user_message_grid].key?(:order)
          scope
        end
      end
    end
  end

  def messages
    render(file: "#{Rails.root}/public/404.html", status: 404) and return unless current_user.person.class.include? UserMessageConcern
  end

  def read_message
    @message = UserMessage.where(id: params[:id]).take!
    @message.read_message
    @message.save
    render text: true
  end

  def trash_message
    @message = UserMessage.where(id: params[:id]).take!
    @message.trash_message
    @message.save
    render text: true
  end

  def restore_message
    @message = UserMessage.where(id: params[:id]).take!
    @message.restore_message
    @message.save
    render text: true
  end

  def delete_message
    @message = UserMessage.where(id: params[:id]).take!
    @message.destroy
    render text: true
  end

  private

  def teacher_dashboard(teacher)
    @teacher = teacher
    @latest_portfolio_items = teacher.latest_portfolio_items.includes(:involved_guardians,:involved_teachers)
    @associated_clients = @teacher.associated_clients.includes(:client_group,:guardians)
    @associated_institutions = Institution.only_type([ Institution::TYPE_SCHOOL,Institution::TYPE_EDUCATIONAL,Institution::TYPE_ORGANISATIONAL]).accessible_by(current_ability).all
    @client_groups = @teacher.associated_client_groups.joins(:semester).where(semesters: {id: Semester.following_and_current.ids})
    @library_suggestions = @associated_clients.collect do |c|
      c.diagnostic_suggestions
    end.flatten
    render 'teacher_dashboard'
  end





end
