class CareerItemsGrid < BaseGrid


  scope do
    CareerItem.order(start_at: :desc,created_at: :desc).all
  end

  filter(:description, :string, header: 'Notizen ') do |value|
    self.where(["career_items.description LIKE ?",  "%#{value}%"])
  end

  filter(:institution, :string, header: 'Einrichtung ') do |value|
    self.where(["career_items.institution_name LIKE ?",  "%#{value}%"])
  end
  filter(:client_group, :string, header: 'Klasse ') do |value|
    self.where(["career_items.client_group_name LIKE ?",  "%#{value}%"])
  end
  filter(:teacher, :string, header: 'Lehrer ') do |value|
    self.where(["career_items.teacher_name LIKE ?",  "%#{value}%"])
  end
  filter(:portfolio_level, :enum, :select => [0,1,2,3], header: 'Förderstufe ') do |value|
    self.where(["career_items.portfolio_level = ?",  value])
  end


  column(:start_at, header: "Änderungsdatum")  do |i|
    "<strong>#{I18n.l(i.start_at,format: :short)}</strong>".html_safe
  end
  column(:change, header: "Änderung", order: :change_type, html: true)  do |i|
    "#{CareerItem::CHANGE_TYPES[i.change_type]} - #{show_career_item_change_text(i)}".html_safe
  end
  column(:institution, header: "Einrichtung")  do |i|
    "#{i.institution_name}".html_safe
  end
  column(:client_group, header: "Klasse")  do |i|
    "#{i.client_group_name}".html_safe
  end
  column(:teacher, header: "Lehrer")  do |i|
    "#{i.teacher_name}".html_safe
  end
  column(:portfolio_level, header: "Förderstufe")  do |i|
    "#{i.portfolio_level}".html_safe
  end

  column(:description, header: "Notizen", html: true) do |item|

    if description = item.description

      id = "description"+item.id.to_s+"Modal"

      modal = '<div class="modal fade" id="'+id+'" tabindex="-1" role="dialog" aria-labelledby="myModalLabel">
          <div class="modal-dialog" role="document">
            <div class="modal-content">
              <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-label="Schließen">
                  <span aria-hidden="true">&times;</span>
                </button>
                <h4 class="modal-title" id="myModalLabel">Notizen</h4>
              </div>
              <div class="modal-body">
                '+description+'
              </div>
            </div>
          </div>
        </div>'

      button = truncate(description, length: 50) {
        button_tag("(weiterlesen)", {
            class: "btn-link",
            type: "button",
            title: "weitere Informationen anzeigen",
            "data-toggle": "modal",
            "data-target": "##{id}",
          })
        }.html_safe

      button + modal.html_safe
    end
  end

  column(:actions,  header: '', style: 'width:100px', :html => true) do |i|
      if can?(:update,i)
        "<div class='btn-group btn-group-nowrap btn-group-xs  pull-right' >
            <a href='#{edit_client_career_item_path(i.client_id,i)}' role='button' class='btn btn-success btn-sm'>
              <i class='glyphicon glyphicon-pencil'></i>
            </a>
        </div>".html_safe
      end
  end

end