class DiagnosticsGrid < BaseGrid


  scope do
   Diagnostic.includes(:characteristics,:diagnostic_imgs,:portfolio_specializations)
  end

  def filter_value_as_string(name)
     if name == :institution
       filter = filter_by_name(name)
       value = filter_value(filter)
       return Institution.where('id in (?)',value).pluck(:name).join("#{filter.separator} ")
     end
     super(name)
  end

  filter(:institution, :enum, header: "Einrichtung",  :select => proc { Institution.all.collect {|i| [ i.name, i.id ] } }, multiple: true ) do |value|
    self.joins(:diagnostic_institution_stocks).distinct.where('diagnostic_institution_stocks.institution_id IN (?)',value).where('diagnostic_institution_stocks.stock > 0')
  end

  filter(:characteristic, :string, header: "Merkmal") do |value|
    self.joins("INNER JOIN characteristics as characteristics_filter ON characteristics_filter.diagnostic_id = diagnostics.id").distinct
        .where('characteristics_filter.name ILIKE ? ', "%#{value}%")
  end

  filter(:title,  :string, header: "Titel") do |value|
    self.where('title ILIKE ? ', "%#{value}%")
  end

  filter(:abbreviation, :string, header: "Abkürzung") do |value|
    self.where('abbreviation ILIKE ? ', "%#{value}%")
  end

  filter(:age_from_ge, :integer, header: "Altersbereich von") do |value|
    self.where("age_from >= ?", value)
  end

  filter(:age_to_le, :integer, header: "bis") do |value|
    self.where("age_from <= ?", value)
  end

  # Here, the columns are solely for sorting purpose
  column(:title, header: 'Titel', order: 'title')
  column(:abbreviation, header: 'Abk.', order: 'abbreviation')
  column(:year, header: 'Jahr', order: 'year')
  column(:age_from, header: 'Altersbereich', order: 'age_from')


end