class TeacherGrid < BaseGrid

  scope do
    Teacher.includes(teacher_institution_relations: :institution).all.order('last_name DESC')
  end

  filter(:name, :string, header: "Name") do |value, scope|
     value.split.inject(scope) do |_scope,part|
       _scope.where("first_name LIKE '%#{part}' OR last_name LIKE '%#{part}'")
     end
  end
  
  filter(:teacher_category_id, :enum, header: "Lehramt",  :select => proc { TeacherCategory.all.map {|t| [t.name, t.id] }} )
  
  filter(:client_group_id, :enum, header: "Klassenlehrer",  :select => proc { ClientGroup.active.map {|c| [c.name, c.id] }} )
  
  filter(:institutions, :enum, header: "Einrichtungen",  :select => proc { Institution.all.map {|c| [c.name, c.id] }}) do |value|
    self.joins(:teacher_institution_relations).where('teacher_institution_relations.institution_id = ?',value)
  end
  filter(:portfolio_specializations, :enum, header: "sonderpädagogische Fachrichtung", :select => proc { PortfolioSpecialization.all.map {|c| [c.name, c.id] }}) do |value|
    self.joins(:teacher_institution_relations).where('teacher_institution_relations.portfolio_specialization_id = ?',value)
  end

  
  column(:name, header: "Name", html: true)  do |teacher|
    show_teacher(teacher)
  end
  
  column(:teacher_category_id, header: "Lehramt", class: 'hidden-xs')  do |teacher|
    teacher.teacher_category ? teacher.teacher_category.name : '-'
  end
  
  column(:institutions, header: "Einrichtungen / Fachrichtungen", class: 'hidden-xs')  do |teacher|
    teacher.teacher_institution_relations.map{|r| "#{r.institution.name}#{r.portfolio_specialization ? " (#{r.portfolio_specialization.name})" : '' }"}.join(',<br/>'.html_safe)
  end



  #column(:teacher_institution_category_id, header: "Funktionen")  do |teacher|
  #  teacher.teacher_institution_relations.where('teacher_institution_category_id IS NOT NULL').map do |relation|
  #    relation.teacher_institution_category.name
  #  end.uniq.join(', ')
  #end
  
  column(:current_client_group, header: "Klassenleitung", class: 'hidden-xs', html: true)  do |teacher|
    show_client_group(teacher.current_client_group)
  end
  
  column(:email, header: "Email")
  
  column(:phone, header: "Telefon")
  
  column(:mobile, header: "Mobil")

  column(:actions,  header: '', :html => true) do |i|
    _wrp = 0
    delete_button = ""
    update_button = ""
    update_roles_button = ""
    if can?(:read,i)
    _wrp += 1
    read_button = "<a href='#{teacher_path(i)}' role='button' class='btn btn-success'>
          <i class='glyphicon glyphicon-eye-open'></i>
        </a>"
    end
    if can?(:update,i)
      _wrp += 1
      update_button = " <a href='#{edit_teacher_path(i)}' role='button' class='btn btn-success btn-sm'>
            <i class='glyphicon glyphicon-pencil'></i>
          </a>"
    end
    if can?(:update_roles,i) && i.identity.present?
      _wrp += 1
      update_roles_button = " <a href='#{edit_roles_teacher_path(i)}' role='button' class='btn btn-success btn-sm'>
            <i class='glyphicon glyphicon-list'></i>
          </a>"
    end
    if can?(:destroy,i)
      _wrp += 1
      delete_button = " #{ link_to  teacher_path(i), data: {:confirm => 'Sicher?'},
                                    role: 'button', class: 'btn btn-danger', :method => :delete do
        content_tag(:i, nil, class: 'glyphicon glyphicon-remove')
      end if i.is_destructable? }"
    end
      "<div class='btn-group btn-group-nowrap-#{_wrp} btn-group-xs  pull-right' >
         #{update_button}
          #{update_roles_button}
          #{read_button}
          #{delete_button}
      </div>".html_safe
  end

end
