module ApplicationHelper

	def include_origin_for_remote_form(file)
		hidden_field_tag("origin",File.basename(file,File.extname(file)).sub(/^_/, ""))
  end


  def show_text(text)
    return "<em>nicht vorhanden</em>".html_safe if text.blank?
    text
  end

  def show_person(person)
    return "n/a" if person.nil?
  	person.first_name+' '+person.last_name
  end

  def show_persons(persons)
    if persons.length > 0      
      # persons.map {|p| show_person(p)}.join(', ').html_safe
      arr = []
      persons.each do |person|
        case person.class.name
        when 'Client'
          arr << show_client(person)
        when 'Teacher'
          arr << show_teacher(person)
        when 'Guardian'
          arr << show_guardian(person)
        when 'Supporter'
          arr << show_supporter(person)          
        when 'Manager'
          arr << show_manager(person)          
        else
          arr << show_person(person)
        end
      end
      arr.join(', ').html_safe
    else
      "n/a"
    end
  end

  def show_boolean(value)
  	(value) ? "ja" : "nein"
  end

  def list_items(items)

  	return "n/a" if items.blank?

  	str = ''
  	index = 0

  	items.each do |i|

      index += 1

      case i.class.name
      when 'Client'
        str += show_person(i)
      when 'Teacher'
        str += show_person(i)
      when 'Guardian'
        str += show_person(i)
      when 'Institution'
        str += show_institution(i)
      else
        str += i.name
      end

  	  str += ', ' unless index == items.size
  	end

  	str
  end

  def show_category(object)
  	case object.class.name
  	when 'Teacher'
  	  object.teacher_category.name
  	when 'Institution'
  	  object.institution_category.name
  	else
  	  "n/a"
  	end
  end

  def show_bday(object)
  	return "n/a" if object.bday.blank?
  	l(object.bday, format: :short)
  end

  def contact_data_count(person)
    count = 0
    count += 1 unless person.try(:phone).blank?
    count += 1 unless person.try(:email).blank?
    count += 1 unless person.try(:mobile).blank?
    count += 1 unless person.try(:fax).blank?
    count
  end

  def show_contact_data(person, with_wrapper = false)

    html = ''

    count = contact_data_count(person)

    if count == 0
      cols = 12
    else
      cols = 12 / count
    end

    prefix = with_wrapper ? '<div class="col-sm-12 col-md-' + cols.to_s + '">' : ''
    suffix = with_wrapper ? '</div>' : '&nbsp;'

    if count == 0
      html += prefix + '<em>keine Kontaktdaten verfügbar</em>' + suffix
      return html.html_safe
    end

    unless person.try(:phone).blank?
      html += prefix + '<i title="Telefon" class="fa fa-phone text-muted"></i> ' + person.phone + suffix
    end
    unless person.try(:email).blank?
      html += prefix + '<i title="E-Mail" class="fa fa-envelope text-muted"></i> ' + mail_to(person.email, person.email, class: "text-muted") + suffix
    end
    unless person.try(:mobile).blank?
      html += prefix + '<i title="Mobil" class="fa fa-mobile text-muted"></i> ' + person.mobile + suffix
    end
    unless person.try(:fax).blank?
      html += prefix + '<i title="Fax" class="fa fa-fax text-muted"></i> ' + person.fax + suffix
    end
    html.html_safe
  end

  def show_full_address(object)
    string = ""
    if (street = object.street && number = object.number)
      string += street + " " + number + ", "
    end
    if (zip = object.zip)
      string += zip + " "
    end
    if (city = object.city)
      string += city + " "
    end
  end

end
