class AdvancementPlanInstitutionStock < ActiveRecord::Base

  belongs_to :advancement_plan, :inverse_of => :advancement_plan_institution_stocks
  belongs_to :institution, :inverse_of => :advancement_plan_institution_stocks

  # all teacher_institution_relations were the institution is the same as this stocks institution ( Needed by auth )
  has_many :teacher_institution_relations, foreign_key: :institution_id, primary_key: :institution_id

  # all institution hierarchies were the parent_id is parent institution of this stocks institution ( Needed by auth )
  has_many :institution_hierarchies, foreign_key: :child_id,  primary_key: :institution_id

  scope :is_available, -> { where('stock > 0') }

  validates :stock,  numericality: { greater_than_or_equal_to: 0, only_integer: true }
  validates :stock,  presence: true

  before_validation :set_defaults_for_new, on: :create

  private
  def set_defaults_for_new
    if self.stock.blank?
      self.stock=0
    end
  end

end
