class EducationalCourseRule < ActiveRecord::Base

  belongs_to :educational_course, class_name: '::EducationalCourse',
           foreign_key: :educational_course_id,
           inverse_of: :educational_course_rules

  has_and_belongs_to_many :client_groups , class_name: '::ClientGroup',
                          inverse_of: :educational_course_rules

  validates_presence_of :name, :course_stage_name, :min_duration_years, :max_duration_years

  # these are not to be persisted, but for intermediate calculation.
  attr_accessor :client, :spent_time_days, :running_time_days
  attr_reader :violation_message

  def violated?
    return false unless client.present?
    if running_time_days.blank? && spent_time_days.present? # minimum should only be checked when this is not from current client_group
      if (min_duration_years * 365) > spent_time_days
        @violation_message = "Der Schüler #{client.full_name} sollte mindestens #{min_duration_years} Jahre in Klassenstufe #{name} bleiben.
Er hat am #{::I18n::l(DateTime.now,format: :short)} die Klasse gewechselt und war bis dahin erst #{spent_time_days} Tage in dieser Stufe"
      end
    end
    if spent_time_days.present?
      running_time_days = 0 if running_time_days.blank?
      if (max_duration_years * 365) < (spent_time_days + running_time_days)
        if running_time_days > 0
          @violation_message = "Der Schüler #{client.full_name} sollte höchstens #{max_duration_years} Jahre in Klassenstufe #{name} bleiben.
Bisherige Verweildauer #{spent_time_days} Tage (Zusätzlich in der aktuellen Klasse schon #{running_time_days} Tage)."
        else
          @violation_message = "Der Schüler #{client.full_name} sollte höchstens #{max_duration_years} Jahre in Klassenstufe #{name} bleiben.
Bisherige Verweildauer #{spent_time_days} Tage."
        end
      end
    end
    return @violation_message.present?
  end

  def inspect
    super + {:spent_time_days => spent_time_days, :running_time_days => running_time_days}.to_s
  end

end
