class InstitutionCategory < ActiveRecord::Base

  # prevent changes after create. It will raise problems if existing institution changes type
  attr_readonly :institution_type

  INSTITUTION_TYPES = {
      Institution::TYPE_SCHOOL => 'Schule',
      Institution::TYPE_EDUCATIONAL => 'Bildungseinrichtung',
      Institution::TYPE_EXTERN => 'Externe Einrichtung',
      Institution::TYPE_ORGANISATIONAL => 'Organisationseinheit',
  }
  INSTITUTION_TYPES_DESCRIPTION = {
      Institution::TYPE_SCHOOL => 'Schulen die unter einer Schulnummer geführt werden.',
      Institution::TYPE_EDUCATIONAL => 'Bildungseinrichtungen ohne Schulnummer',
      Institution::TYPE_EXTERN => 'Externe Einrichtung die keine Portfolios verwalten.',
      Institution::TYPE_ORGANISATIONAL => 'Übergeordnete Organisationseinrichtungen von Schulen und Bildungseinrichtungen. Verwalten keine Portfolios.',
  }

  #--- Associations
  has_many :institutions

  scope :for_institution_type, -> (type) { where('institution_type = ?',type)}

  validates :name, :institution_type, presence: true

  #--- Callback definitions
  before_destroy :is_destructable?

  def is_destructable?
    institutions.empty?
  end

end
