module Portfolio
  class EvaluationInvolvedGuardian < ::ActiveRecord::Base
    self.table_name = 'evaluation_involved_guardians'
    self.inheritance_column = nil

    has_many :target_results,
             as: :evaluative,
             foreign_key: :evaluative_id,
             class_name: '::Portfolio::ItemTargetResult',
             dependent: :destroy # refs #192

    belongs_to :portfolio_item_evaluation,
               foreign_key: :portfolio_item_evaluation_id,
               class_name: '::Portfolio::ItemEvaluation',
               inverse_of: :evaluation_involved_guardians

    belongs_to :guardian,
               foreign_key: :guardian_id,
               class_name: '::Guardian',
               inverse_of: nil

    # This sometimes(?) causes a silent ROLLBACK without validation errors/exception:
    # validates_uniqueness_of :portfolio_item_evaluation_id, :scope => :guardian_id

    # this has to be done when the result scheme of portfolio_item_evaluation changes.
    def handle_result_scheme_change!
      destroy_result!
      create_result!
    end

    # destroy all results for this person and this evaluation
    def destroy_result!
      portfolio_item_evaluation.portfolio_item_target.results.where( evaluative_id: guardian.id, evaluative_type: 'Guardian').destroy_all
    end

    # create a results for this person and this evaluation with the current result scheme
    def create_result!
      portfolio_item_evaluation.portfolio_item_target.results.create({result_scheme: portfolio_item_evaluation.result_scheme, evaluative: guardian})
    end

    # results are created immediately when the evaluation (and with it, this instance) is persisted.
    # See Portfolio::ItemEvaluation for creation of result for portfolio subject
    before_save do
      unless portfolio_item_evaluation.portfolio_item_target.results.where( evaluative_id: guardian.id, evaluative_type: 'Guardian').any?
        create_result!
      end
      true
    end

  end
end

