module Portfolio
  class EvaluationInvolvedPerson < ::ActiveRecord::Base
    self.table_name='evaluation_involved_persons'
    self.inheritance_column = nil

    belongs_to :portfolio_item_evaluation,
               class_name: '::Portfolio::ItemEvaluation',
               foreign_key: :portfolio_item_evaluation_id,
               inverse_of: :evaluation_involved_persons

    has_many :target_results,
             as: :evaluative,
             foreign_key: :evaluative_id,
             class_name: '::Portfolio::ItemTargetResult',
             dependent: :destroy # refs #192

    validates_uniqueness_of :name, scope: :portfolio_item_evaluation_id
    validates :portfolio_item_evaluation, presence: true
    validates :name, length: { minimum: 5}

    # this has to be done when the result scheme of portfolio_item_evaluation changes.
    def handle_result_scheme_change!
      destroy_result!
      create_result!
    end

    # destroy all results for this person and this evaluation
    def destroy_result!
      target_results.destroy_all
    end

    # create a results for this person and this evaluation with the current result scheme
    def create_result!
      target_results.create({result_scheme: portfolio_item_evaluation.result_scheme, portfolio_item_target: portfolio_item_evaluation.portfolio_item_target})
    end

    # results are created immediately when the evaluation (and with it, this instance) is persisted.
    # See Portfolio::ItemEvaluation for creation of result for portfolio subject
    after_save do
      unless target_results.any?
        create_result!
      end
      true
    end

    # results are destroyed, when this record is destroyed
    before_destroy do
      destroy_result!
      true
    end

  end
end

