module Portfolio
  class ItemEvaluationDbr < ::ActiveRecord::Base
    self.table_name = 'portfolio_item_evaluation_dbrs'
    self.inheritance_column = nil


    has_one   :portfolio_item_evaluation,
               foreign_key: :portfolio_item_evaluation_dbr_id,
               class_name: '::Portfolio::ItemEvaluation',
               inverse_of:  :portfolio_item_evaluation_dbr
    delegate :portfolio_item, to: :portfolio_item_evaluation
    delegate :portfolio, to: :portfolio_item
    delegate :portfolio_subject, to: :portfolio_item

    has_many  :characteristics,
                class_name: '::Portfolio::ItemEvaluationDbrCharacteristic',
                foreign_key: :portfolio_item_evaluation_dbr_id,
                inverse_of:  :dbr,
                dependent: :destroy
    accepts_nested_attributes_for :characteristics, reject_if: :all_blank, allow_destroy: true

    has_many  :results,
              class_name: '::Portfolio::ItemEvaluationDbrResult',
              foreign_key: :portfolio_item_evaluation_dbr_id,
              inverse_of:  :dbr,
              dependent: :destroy
    accepts_nested_attributes_for :results, allow_destroy: true

    # after_create do
    #   characteristics.each do |characteristic|
    #     lines.each_index  do |j|
    #       number_of_data_points.times do
    #         results.create(characteristic: characteristic, line_idx: j)
    #       end
    #     end
    #   end
    # end

    after_update do
      if baselines_amount_changed? && baselines_amount > baselines_amount_was
        # Wenn ein Dbr geändert wird und Baselines hinzukommen, bekommt jeder neue Graph soviele Datenpunkte wie im Formular angegeben.
        characteristics.each do |characteristic|
          if baselines_amount_was == 0 && baselines_amount ==1 # ["Interventionsphase"] -> ["Grundrate","Interventionsphase"]
            # idx 0 wird idx 1 und dann für idx 0 erzeugen
            unless results.where(characteristic: characteristic, line_idx: 1).any?
              results.where(characteristic: characteristic, line_idx: 0).update_all(line_idx: 1)
              number_of_data_points.times { results.create(characteristic: characteristic, line_idx: 0) }
            end
          end
          if baselines_amount_was == 0 && baselines_amount == 2 # ["Interventionsphase"] -> ["Grundrate","Interventionsphase","Grundrate","Interventionsphase"]
            # idx 0 wird idx 1 und dann für idx 0,2,3 erzeugen
            unless results.where(characteristic: characteristic, line_idx: 1).any?
              results.where(characteristic: characteristic, line_idx: 0).update_all(line_idx: 1)
              [0,2,3].each do |idx|
                number_of_data_points.times { results.create(characteristic: characteristic, line_idx: idx) }
              end
            end
          end
          # ["Grundrate","Interventionsphase"] -> ["Grundrate","Interventionsphase","Grundrate","Interventionsphase"]
          if baselines_amount_was == 1 && baselines_amount == 2
            # für idx 2,3 erzeugen
            unless results.where(characteristic: characteristic, line_idx: 2).any?
              [2,3].each do |idx|
                number_of_data_points.times { results.create(characteristic: characteristic, line_idx: idx) }
              end
            end
          end
        end
      end
      if baselines_amount_changed? && baselines_amount < baselines_amount_was
        # Wenn Baselines wegfallen werden alle Datenpunkte der betroffenen Graphen gelöscht
        characteristics.each do |characteristic|
          if baselines_amount_was == 2 && baselines_amount == 1 # ["Grundrate","Interventionsphase","Grundrate","Interventionsphase"] -> ["Grundrate","Interventionsphase"]
            # idx 2,3 werden gelöscht
            [2,3].each do |idx|
              results.where(characteristic: characteristic, line_idx: idx).destroy_all
            end
          end
          if baselines_amount_was == 2 && baselines_amount == 0 # ["Grundrate","Interventionsphase","Grundrate","Interventionsphase"] -> ["Interventionsphase"]
            # idx 0,2,3 werden gelöscht danach wird idx 1 zu idx 0
            [0,2,3].each do |idx|
              results.where(characteristic: characteristic, line_idx: idx).destroy_all
            end
            results.where(characteristic: characteristic, line_idx: 1).update_all(line_idx: 0)
          end
          if baselines_amount_was == 1 && baselines_amount == 0 # ["Grundrate","Interventionsphase"] -> ["Interventionsphase"]
            # idx 0 wird gelöscht danach wird idx 1 zu idx 0
            results.where(characteristic: characteristic, line_idx: 0).destroy_all
            results.where(characteristic: characteristic, line_idx: 1).update_all(line_idx: 0)
          end
        end
      end
      if number_of_data_points_changed?
        characteristics.each do |characteristic|
          lines.each_index  do |j|
            old_results = results.where(characteristic: characteristic, line_idx: j).order(id: :asc)
            if old_results.size < number_of_data_points
              (number_of_data_points - old_results.size).times do
                results.create(characteristic: characteristic, line_idx: j)
              end
            else
              _results = old_results.to_a
              (old_results.size - number_of_data_points).times do
                result = _results.pop
                if result && result.value.nil?
                  result.destroy
                else
                  break
                end
              end
            end
          end
        end
      end
    end

    # after_save do
    #   _results = results.to_a
    #   _existing_count = {}
    #   characteristics.each do |characteristic|
    #     _existing_count[characteristic] ||= {}
    #     lines.each_index  do |j|
    #       _existing_count[characteristic][j] = _results.select{|r|r.portfolio_item_evaluation_dbr_characteristic_id==characteristic.id && r.line_idx==j}.size
    #     end
    #   end
    #   characteristics.each do |characteristic|
    #     lines.each_index  do |j|
    #       (number_of_data_points - _existing_count[characteristic][j]).times do
    #          results.create(characteristic: characteristic, line_idx: j)
    #       end
    #     end
    #   end
    #   characteristics.each do |characteristic|
    #     results.select{|r|r.line_idx >=lines.length && r.portfolio_item_evaluation_dbr_characteristic_id==characteristic.id}.each(&:mark_for_destruction)
    #   end
    #   true
    # end

    def lines(baselines_amount = self.baselines_amount)
      if baselines_amount == 0
        return ['Interventionsphase']
      end
      if baselines_amount == 1
        ary = []
        baselines_amount.times do |i|
          ary << "Grundrate"
          ary << "Interventionsphase"
        end
        return ary
      end
      if baselines_amount > 1
        ary = []
        baselines_amount.times do |i|
          ary << "#{i+1}. Grundrate"
          ary << "#{i+1}. Interventionsphase"
        end
        return ary
      end
    end

    validates :range_begin, :range_end,:setting_social,:setting_time,:number_of_data_points, presence: true
    validates :range_begin , numericality:  { only_integer: true, greater_than_or_equal_to: 0 }
    validates :range_end , numericality:  { only_integer: true,  lesser_than_or_equal_to: 100 }
    validates :setting_social, :setting_time , length: { maximum: 280, minimum: 1}
    validates :number_of_data_points , numericality: { only_integer: true, greater_than: 0 }
    validates :baselines_amount , numericality: { only_integer: true, greater_than: -1, lesser_than: 3 }
    validate do
      if  portfolio_item_evaluation.portfolio_item_target.portfolio_dbrc_id.blank?
        errors.add(:characteristics, "Maximal 5 Merkmale können erfasst werden.") if (characteristics.size > 5)
        errors.add(:characteristics, "Mindestens 1 Merkmal sollte erfasst werden.") if (characteristics.size < 1)
      end
    end





  end
end


