module Portfolio
  class Step < ActiveRecord::Base
    self.table_name = 'portfolio_steps'
    self.inheritance_column = nil
    has_many :portfolio_step_results,
             foreign_key: :step_id,
             inverse_of: :portfolio_step,
             class_name: '::Portfolio::StepResult'

    after_initialize :init

    attr_reader :all_portfolio_matchers

    def init
      @all_portfolio_matchers = []
      unless portfolio_matchers.nil?
        @all_portfolio_matchers =  ::JSON.parse(portfolio_matchers).map do |object|
          klass = "::Portfolio::Conditions::#{matcher_name(object['type']).camelize}"
          begin
            instance = klass.constantize.new
            object['args'].each do |k, v|
              instance.send(k+'=', v) if instance.respond_to? k+'='
            end unless object['args'].nil?
          rescue ::NameError
            next
          end
          instance
        end
      end
    end

    def match_portfolio?(enumerator)
      return true if @all_portfolio_matchers.blank?
      return @all_portfolio_matchers.inject(true) do |and_match,matcher|
        and_match & matcher.match?(enumerator)
      end
    end



    def client_is_always_involved?
      return type == 'diagnostic'
    end
    alias :subject_is_always_involved? :client_is_always_involved?


    def include_level_raise
      return true if type=='parent_teacher_conference' #TODO: should be read from table, so it is configurable
    end

    # get the validators that ensure any requirements are met for an item that has this step
    #
    # @return ActiveModel::Validator
    def item_requirements_validator
      _requirements = requirements
      # _requirements = ::JSON.parse(requirements).map do |or_requirements|
      #   or_requirements.reject do |object|
      #     %w(advancement_plan measurement target_agreements).include?(object['type'])
      #   end
      # end.to_json unless requirements.nil?
      _requirements_description = requirements_description
      # _requirements_description = ::JSON.parse(requirements_description).reject do |str|
      #   str.include?("formale Fördermethode") || str.include?("Zielvereinbarung") || str.include?("freie Methode")
      # end.to_json unless requirements_description.nil?
      ::Portfolio::StepValidator.new(_requirements,_requirements_description)
    end

    # @return [Array]
    def hints
      item_requirements_validator.hints
    end


    # Check if a component is allowed for this step, according to the rule definition
    #
    # allowed?(:result) => true if the step may include a result
    # allowed?([:conference,:result]) => true if the step may include a result OR conference
    def allowed?(tokens)
      if tokens.respond_to? :inject
        tokens.inject(false) { |acc,el| acc || _allowed?(el) }
      else
        _allowed?(tokens)
      end
    end
    alias :allows_one_of? :allowed?


    private
    def restricted?(token)
      [:results,:evaluation,:parent_teacher_conference, :management_conference, :advancement_plan, :diagnostic, :diagnostic_measurement, :class_diagnostic, :measurement, :target_agreements, :questionnaire, :checklists].include?(token)
    end

    def _allowed?(token)
      raise ::ArgumentError.new("Token unknown #{token}") unless restricted? token
      #if token == :questionnaire
      #  optionals.split(/\s*,\s*/).include?(token.to_s)
      #end
      if token == :results
        return portfolio_step_results.any?
      end
      if token == :parent_teacher_conference
        token = :request_parent_teacher_conference
      end
      if token == :management_conference
        token = :request_management_conference
      end
      if optionals.present?
        optionals.split(/\s*,\s*/).include?(token.to_s)
      else
        false
      end
    end

    def matcher_name(name)
      map={
          'document' => 'specific_document_uploaded_matcher',
          'specific_document_uploaded' => 'specific_document_uploaded_matcher'
      }
      if map.key?(name)
        return map[name]
      end
      return name
    end
  end
end
