module Questionnaires
  class ItrfTeacher < Questionnaire

    def accepts_teacher?
      true
    end

    def self.questionnaire_name
      "ITRF (Volpe et al. 2018)"
    end

    # @return Hash[String]
    def documents
      {
         #'Fragebogen-Schüler' => Rails.public_path + '/questionnaires/itrf/ITRF-Kurzversion.pdf'
      }
    end

    def link
      nil
    end
    
    def result_texts
      [
          "Verhalten ist nicht problematisch",
          "Verhalten ist leicht problematisch",
          "Verhalten ist mäßig problematisch",
          "Verhalten ist stark problematisch"
      ]
    end

    def groups
      # ATTENTION: Do not change ids of Questions and QuestionGroups. Do not change values.
      values = [0,1,2,3]
      [
          Questionnaire::QuestionGroup.new(1,1,"Unproduktives Arbeitsverhalten",[
              Questionnaire::Question.new(1,1,"Stellt Unterrichtsaufgaben nicht rechtzeitig fertig",values, [
                Questionnaire::DrcItem.new(1,1,"Erledigt Aufgaben in der vorgegebenen Zeit"),
                Questionnaire::DrcItem.new(2,2,"Arbeitet mit X oder weniger Erinnerungen konzentriert an der Aufgabe")
              ]),
              Questionnaire::Question.new(2,2,"Beginnt mit der Aufgabenbearbeitung nicht selbstständig",values,[
                Questionnaire::DrcItem.new(5,5,"Beginnt Aufgaben mit X oder weniger Aufforderungen")
              ]),
              Questionnaire::Question.new(3,3,"Erledigt Hausaufgaben unvollständig",values, [
                Questionnaire::DrcItem.new(3,3,"Erledigt X Aufgaben, davon Y% korrekt"),
                Questionnaire::DrcItem.new(4,4,"Erledigt X% der zugewiesenen Aufgaben")
              ]),
              Questionnaire::Question.new(4,4,"Zeigt Unterrichtsaufgaben nicht selbstständig vor",values,[
                Questionnaire::DrcItem.new(6,6,"Reicht Aufgaben angemessen ein")
              ]),
              Questionnaire::Question.new(5,5,"Kontrolliert seine eigene Arbeit nicht",values,[
                Questionnaire::DrcItem.new(7,7,"Kontrolliert seine Aufgaben")
              ]),
              Questionnaire::Question.new(6,6,"Nimmt Materialien, die zu Hause benötigt werden, nicht mit (z.B. für die Hausaufgaben, Elternbriefe)",values,[
                Questionnaire::DrcItem.new(8,8,"Hat alle für die Hausaufgaben benötigten Materialien am Ende des Tages in seiner Schultasche")
              ]),
              Questionnaire::Question.new(7,7,"Kommt unvorbereitet zum Unterricht",values,[
                Questionnaire::DrcItem.new(9,9,"Kommt mit den erforderlichen Materialien zur Schule")
              ]),
              Questionnaire::Question.new(8,8,"Beteiligt sich nicht am Unterricht",values,[
                  Questionnaire::DrcItem.new(10,10,"Trägt angemessen zu Unterrichtsaktivitäten bei"),
                  Questionnaire::DrcItem.new(11,11,"Antwortet auf Lehrerfragen"),
                  Questionnaire::DrcItem.new(12,12,"Antwortet auf Mitschülerfragen")
              ])
          ]),
          Questionnaire::QuestionGroup.new(2,2,"Störendes Verhalten",[
              Questionnaire::Question.new(9,9,"Streitet und zankt mit Lehrkräften",values,[
                  Questionnaire::DrcItem.new(13,13,"Gibt weniger als X mal Widerworte")
              ]),
              Questionnaire::Question.new(10,10,"Verliert die Beherrschung",values,[
                  Questionnaire::DrcItem.new(14,14,"Fragt nach Hilfe, wenn er/sie frustriert ist"),
                  Questionnaire::DrcItem.new(15,15,"Weniger als X  Wutausbrüche")
              ]),
              Questionnaire::Question.new(11,11,"Stört andere",values,[
                  Questionnaire::DrcItem.new(16,16,"Unterbricht den Unterricht weniger als X-mal pro Stunde"),
                  Questionnaire::DrcItem.new(17,17,"Arbeitet still mit X oder weniger Aufforderungen"),
                  Questionnaire::DrcItem.new(18,18,"Macht X oder weniger unangemessene Geräusche"),
                  Questionnaire::DrcItem.new(19,19,"Weniger als X-mal themenferne Seitengespräche mit Mitschülern")
              ]),
              Questionnaire::Question.new(12,12,"Verwendet unangemessene Sprache",values,[
                  Questionnaire::DrcItem.new(20,20,"Flucht weniger als X-mal"),
                  Questionnaire::DrcItem.new(21,21,"Benutzt weniger als Xmal Schimpfwörter")
              ]),
              Questionnaire::Question.new(13,13,"Hat Konflikte mit Mitschülerinnen und Mitschülern",values,[
                  Questionnaire::DrcItem.new(21,21,"Weniger als X Streits mit Gleichaltrigen"),
                  Questionnaire::DrcItem.new(22,22,"Weniger als X verbale Auseinandersetzungen mit Gleichaltirgen")
              ]),
              Questionnaire::Question.new(14,14,"Kommandiert herum",values,[
                  Questionnaire::DrcItem.new(23,23,"Benötigt X oder weniger Aufforderung, um damit aufzuhören, Mitschüler zu kommandieren ")
              ]),
              Questionnaire::Question.new(15,15,"Macht unangebrachte Bemerkungen",values,[
                  Questionnaire::DrcItem.new(24,24,"Mindestens X relevante, nicht-redundante Kommentare")
              ]),
              Questionnaire::Question.new(16,16,"Respektiert nicht die Privatsphäre anderer",values,[
                  Questionnaire::DrcItem.new(25,25,"Dringt weniger als X-mal in den Platz anderer ein"),
                  Questionnaire::DrcItem.new(26,26,"Bleibt in seinem eigenen Bereich mit weniger als X Aufforderungen")
              ])
          ])
      ]
    end


    # @return Array[Questionnaire::Analysis]
    def analyses
      analyses=[]
      # Gesamtproblemwert
      all_questions_regarding_problems = questionnaire_results.select{|r| [1,2].include?(r.group_id) }
      filled_questions_regarding_problems = all_questions_regarding_problems.select{|r| r.result.present?}
      if filled_questions_regarding_problems.size == all_questions_regarding_problems.size # >= 12
        scaleing = (all_questions_regarding_problems.size.to_f / filled_questions_regarding_problems.size.to_f)
        value = filled_questions_regarding_problems.map(&:result).reduce(&:+) * scaleing
        analyses <<   Questionnaire::TernaryProblemAnalysis.new(1,1,"Gesamtproblemwert",value, left_maximum: 13, right_minimum: 13)
      end

      # Einzelne Bereiche
      all_questions_group_1 = questionnaire_results.select{|r| r.group_id == 1 }
      filled_questions_group_1 = all_questions_group_1.select{|r| r.result.present?}
      if filled_questions_group_1.size == all_questions_group_1.size # >= 4
        scaleing = (all_questions_group_1.size.to_f / filled_questions_group_1.size.to_f)
        value = filled_questions_group_1.map(&:result).reduce(&:+) * scaleing
        analyses <<   Questionnaire::TernaryProblemAnalysis.new(2,2,"Unproduktives Arbeitsverhalten",value, left_maximum: 10, right_minimum: 10)
      end
      all_questions_group_2 = questionnaire_results.select{|r| r.group_id == 2 }
      filled_questions_group_2 = all_questions_group_2.select{|r| r.result.present?}
      if filled_questions_group_2.size == all_questions_group_2.size #  >= 4
        scaleing = (all_questions_group_2.size.to_f / filled_questions_group_2.size.to_f)
        value = filled_questions_group_2.map(&:result).reduce(&:+) * scaleing
        analyses <<   Questionnaire::TernaryProblemAnalysis.new(3,3,"Störendes Verhalten",value, left_maximum: 5, right_minimum: 5)
      end
      analyses
    end



  end
end
