class SchoolStat < ActiveRecord::Base

  belongs_to :institution
  has_many :school_stat_portfolio_items

  def client_portfolio_items_from_twms_total
    return 0 unless school_stat_portfolio_items.select{|r|r.subject_type=='Client'}.any?
    school_stat_portfolio_items.select{|r|r.subject_type=='Client'}.map(&:from_twms_total).reduce(:+)
  end

  def client_portfolio_items_total
    return 0 unless school_stat_portfolio_items.select{|r|r.subject_type=='Client'}.any?
    school_stat_portfolio_items.select{|r|r.subject_type=='Client'}.map(&:total).reduce(:+)
  end

  def client_portfolio_items_avg
    return 0 unless school_stat_portfolio_items.select{|r|r.subject_type=='Client'}.any?
    school_stat_portfolio_items.select{|r|r.subject_type=='Client'}.map(&:avg).reduce(:+)
  end

  def client_group_portfolio_items_avg
    return 0 unless school_stat_portfolio_items.select{|r|r.subject_type=='ClientGroup'}.any?
    school_stat_portfolio_items.select{|r|r.subject_type=='ClientGroup'}.map(&:avg).reduce(:+)
  end

  def client_portfolio_items_from_twms_avg
    return 0 unless school_stat_portfolio_items.select{|r|r.subject_type=='Client'}.any?
    school_stat_portfolio_items.select{|r|r.subject_type=='Client'}.map(&:from_twms_avg).reduce(:+)
  end

  def client_group_portfolio_items_from_twms_avg
    return 0 unless school_stat_portfolio_items.select{|r|r.subject_type=='ClientGroup'}.any?
    school_stat_portfolio_items.select{|r|r.subject_type=='ClientGroup'}.map(&:from_twms_avg).reduce(:+)
  end

  def client_group_portfolio_items_from_twms_total
    return 0 unless school_stat_portfolio_items.select{|r|r.subject_type=='ClientGroup'}.any?
    school_stat_portfolio_items.select{|r|r.subject_type=='ClientGroup'}.map(&:from_twms_total).reduce(:+)
  end


  def client_group_portfolio_items_total
    return 0 unless school_stat_portfolio_items.select{|r|r.subject_type=='ClientGroup'}.any?
    school_stat_portfolio_items.select{|r|r.subject_type=='ClientGroup'}.map(&:total).reduce(:+)
  end

  def self.current_entry(institution)
    where(institution: institution).order(year: :desc, month: :desc).first
  end

  def self.last_entry(institution)
    where(institution: institution).order(year: :desc, month: :desc).second
  end

  def self.current_aggregate(institutions=nil)
    aggregate_schools(institutions).first
  end

  def self.last_aggregate(institutions=nil)
    aggregate_schools(institutions).second
  end

  def self.generate(schools = Institution.schools, month = Date.today.month, year = Date.today.year)
    schools = [schools] unless schools.respond_to? :each
    schools.each do |school|
      record = where(institution_id: school.id, month: month, year: year).first || new
      total_clients = school.clients.size
      total_client_groups = school.current_client_groups.size
      record.attributes={
         institution: school,
         month: month,
         year:  year,
         teachers_total: school.teachers.size,
         client_groups_total: school.current_client_groups.size,
         clients_total: total_clients,
         clients_fs_0: school.clients.where(portfolio_level: 0).size,
         clients_fs_1:  school.clients.where(portfolio_level: 1).size,
         clients_fs_2:  school.clients.where(portfolio_level: 2).size,
         clients_fs_3:  school.clients.where(portfolio_level: 3).size
       }
      record.save
      all_pi_count= Portfolio::Item.connection.select_all("SELECT
        count(portfolio_steps.name) AS \"count\",
        portfolio_steps.name
      FROM portfolio_items
        JOIN portfolios ON portfolios.id = portfolio_items.portfolio_id
        JOIN portfolio_steps ON portfolio_steps.id = portfolio_items.portfolio_step_id
        JOIN portfolio_item_involved_teachers ON portfolio_items.id = portfolio_item_involved_teachers.portfolio_item_id
      WHERE portfolios.subject_id IN (SELECT id
                                      FROM clients
                                      WHERE institution_id = #{school.id})
            AND portfolios.subject_type = 'Client'
      GROUP BY portfolio_steps.name")
      twms_pi_count =  Portfolio::Item.connection.select_all("SELECT
        count(portfolio_steps.name) as \"count\",
        portfolio_steps.name
      FROM portfolio_items
        JOIN portfolios ON portfolios.id = portfolio_items.portfolio_id
        JOIN portfolio_steps ON portfolio_steps.id = portfolio_items.portfolio_step_id
        JOIN portfolio_item_involved_teachers ON portfolio_items.id = portfolio_item_involved_teachers.portfolio_item_id
      WHERE portfolios.subject_id IN (SELECT id
                                      FROM clients
                                      WHERE institution_id = #{school.id})
            AND portfolio_item_involved_teachers.teacher_id IN
                (SELECT teacher_id
                 FROM teacher_institution_relations
                 WHERE teacher_id IN (SELECT teacher_id
                                      FROM teacher_institution_relations
                                      WHERE institution_id = #{school.id})
                 GROUP BY teacher_id
                 HAVING count(teacher_id) > 1)
            AND portfolios.subject_type = 'Client'
      GROUP BY portfolio_steps.name")
      agg={}
      all_pi_count.each do |c|
        agg[c['name']] = {cnt: c['count'], twms_cnt: 0}
      end
      twms_pi_count.each do |c|
        if agg[c['name']]
          agg[c['name']][:twms_cnt] = c['count']
        else
          agg[c['name']] = {twms_cnt: c['count'], cnt: 0}
        end
      end
      SchoolStatPortfolioItem.where(school_stat_id: record.id,subject_type: 'Client').delete_all
      agg.each {|name,hsh| SchoolStatPortfolioItem.create({
        school_stat_id: record.id,
        subject_type: 'Client',
        type: name,
        total: hsh[:cnt],
        from_twms_total:  hsh[:twms_cnt],
        avg: (hsh[:cnt]==0 || total_clients==0 ? 0 : hsh[:cnt].to_f  / total_clients.to_f).to_f,
        from_twms_avg:  (hsh[:twms_cnt]==0 || total_clients==0 ? 0 : hsh[:twms_cnt].to_f  / total_clients.to_f).to_f,
      }) }

      all_pi_count= Portfolio::Item.connection.select_all("SELECT
        count(portfolio_steps.name) AS \"count\",
        portfolio_steps.name
      FROM portfolio_items
        JOIN portfolios ON portfolios.id = portfolio_items.portfolio_id
        JOIN portfolio_steps ON portfolio_steps.id = portfolio_items.portfolio_step_id
        JOIN portfolio_item_involved_teachers ON portfolio_items.id = portfolio_item_involved_teachers.portfolio_item_id
      WHERE portfolios.subject_id IN (SELECT id
                                      FROM client_groups
                                      WHERE institution_id = #{school.id})
            AND portfolios.subject_type = 'ClientGroup'
      GROUP BY portfolio_steps.name")
      twms_pi_count =  Portfolio::Item.connection.select_all("SELECT
        count(portfolio_steps.name) as \"count\",
        portfolio_steps.name
      FROM portfolio_items
        JOIN portfolios ON portfolios.id = portfolio_items.portfolio_id
        JOIN portfolio_steps ON portfolio_steps.id = portfolio_items.portfolio_step_id
        JOIN portfolio_item_involved_teachers ON portfolio_items.id = portfolio_item_involved_teachers.portfolio_item_id
      WHERE portfolios.subject_id IN (SELECT id
                                      FROM client_groups
                                      WHERE institution_id = #{school.id})
            AND portfolio_item_involved_teachers.teacher_id IN
                (SELECT teacher_id
                 FROM teacher_institution_relations
                 WHERE teacher_id IN (SELECT teacher_id
                                      FROM teacher_institution_relations
                                      WHERE institution_id = #{school.id})
                 GROUP BY teacher_id
                 HAVING count(teacher_id) > 1)
            AND portfolios.subject_type = 'ClientGroup'
      GROUP BY portfolio_steps.name")
      agg={}
      all_pi_count.each do |c|
        agg[c['name']] = {cnt: c['count'], twms_cnt: 0}
      end
      twms_pi_count.each do |c|
        if agg[c['name']]
          agg[c['name']][:twms_cnt] = c['count']
        else
          agg[c['name']] = {twms_cnt: c['count'], cnt: 0}
        end
      end
      SchoolStatPortfolioItem.where(school_stat_id: record.id,subject_type: 'ClientGroup').delete_all
      agg.each {|name,hsh| SchoolStatPortfolioItem.create({
        school_stat_id: record.id,
        subject_type: 'ClientGroup',
        type: name,
        total: hsh[:cnt],
        from_twms_total:  hsh[:twms_cnt],
        avg: (hsh[:cnt]==0 || total_client_groups==0 ? 0 : hsh[:cnt].to_f  / total_client_groups.to_f).to_f,
        from_twms_avg:  (hsh[:twms_cnt]==0 || total_client_groups==0 ? 0 : hsh[:twms_cnt].to_f  / total_client_groups.to_f).to_f,
      })}
    end
  end


  def self.aggregate_schools(institutions = nil)
    where_clause='1=1'
    if institutions.present?
      where_clause="institution_id IN (#{institutions.ids.join(',')})"
    end
    aggregates= find_by_sql <<-SQL
      SELECT
      array_to_string(array_agg(institution_id),',') as institution_ids,
      count(distinct institution_id) as institution_total,
      "month",
      "year",
      sum(teachers_total) as teachers_total,
      sum(client_groups_total) as client_groups_total,
      sum(clients_total) as clients_total,
      sum(clients_fs_0) as clients_fs_0,
      sum(clients_fs_1) as clients_fs_1,
      sum(clients_fs_2) as clients_fs_2,
      sum(clients_fs_3) as clients_fs_3
      from school_stats
      where #{where_clause}
      group by school_stats."year",school_stats."month" order by school_stats."year" desc,school_stats."month" desc;
    SQL
    aggregates.each do |aggregate|
      aggregate.school_stat_portfolio_items = SchoolStatPortfolioItem.find_by_sql <<-SQL
        SELECT
        #{aggregate.institution_total} as institution_total,
        subject_type,
        "type",
        sum(total) as total,
        sum(from_twms_total) as from_twms_total,
        sum("avg")as "avg",
        sum("from_twms_avg") as "from_twms_avg"
        FROM school_stat_portfolio_items join school_stats on school_stats.id=school_stat_portfolio_items.school_stat_id
        where "month"=#{aggregate.month} and "year"=#{aggregate.year} and #{where_clause} group by "type",subject_type;
      SQL
    end
    aggregates
  end

end
