module SystemTasks
  class ClientClientGroupMissing < Base


    def _escalations
      [
          {
              Escalator::SendUserMessage => [target.teacher,target.try(:client_group).try(:teacher)],
              Escalator::SendEmail =>  [target.teacher,target.try(:client_group).try(:teacher)]
          },
          {
              Escalator::SendUserMessage => target.institution.teacher_institution_relations.where(is_school_admin:true).all.to_a,
              Escalator::SendEmail =>  target.institution.teacher_institution_relations.where(is_school_admin:true).all.to_a
          }
      ]
    end


    def is_manual_confirmable?
      false
    end

    class << self
      def subscribe_to
        [
            {
                klass: 'system_setting',
                callback: 'after_save',
                handler: 'system_settings_after_save'
            },
            {
                klass: 'client',
                callback: 'after_save',
                handler: 'clients_after_save'
            },
        ]
      end




      def system_settings_after_save(system_setting)
        semester = system_setting.semester
        if system_setting.semester_id_changed?
          delete_all
          Client.where(next_semester_client_group_id: nil).each do |client|
            create({
                       target: client,
                       client: client,
                       institution: nil,
                       label: client.full_name,
                       title:  "#{client.first_name} #{client.last_name} hat noch keine Klasse für das nächste Schuljahr",
                       message: "#{client.first_name} #{client.last_name} hat noch keine Klasse für das nächste Schuljahr",
                       start_at: semester.finish.ago(60 * 60 * 24 * 7 * 4),
                       due_at: semester.finish,
                       next_escalation: semester.finish.ago(60 * 60 * 24 * 7 * 4),
                       escalation_delay: 60 * 60 * 24 * 7,
                       resolve_location: Rails.application.routes.url_helpers.edit_next_semester_client_groups_clients_path
                   })
          end
        end
      end

      def clients_after_save(client)
        if client.next_semester_client_group_id_changed?
          if client.next_semester_client_group_id.blank? && !where(target: client).exists?
            semester = SystemSetting.get_instance.semester
            create({
                       target: client,
                       client: client,
                       institution: nil,
                       label: client.full_name,
                       title:  "#{client.first_name} #{client.last_name} hat noch keine Klasse für das nächste Schuljahr",
                       message: "#{client.first_name} #{client.last_name} hat noch keine Klasse für das nächste Schuljahr",
                       start_at: semester.finish.ago(60 * 60 * 24 * 7 * 4),
                       due_at: semester.finish,
                       next_escalation: semester.finish.ago(60 * 60 * 24 * 7 * 4),
                       escalation_delay: 60 * 60 * 24 * 7,
                       resolve_location: Rails.application.routes.url_helpers.edit_next_semester_client_groups_clients_path
                   })
          else
            where('target_type=? AND target_id=?','Client',client.id).delete_all
          end
        end
      end
    end




  end
end