module SystemTasks
  class ClientExpertiseEnd < Base

    def _escalations
      [
          {
              Escalator::SendUserMessage => [
                  target.expertise_manager,
                  target.expertise_school_inspector,
                  target.teacher,
                  target.client_group.try(&:teacher),
              ] + target.expertise_institution.teacher_institution_relations.all.to_a.select(&:is_management?).map(&:teacher),
              Escalator::SendEmail => [
                  target.expertise_manager,
                  target.client_group.try(&:teacher),
              ] + target.expertise_institution.teacher_institution_relations.all.to_a.select(&:is_management?).map(&:teacher)
          }
      ]
    end

    def is_manual_confirmable?
      true
    end

    class << self
      def subscribe_to
        [
            {
                klass: 'client',
                callback: 'after_save',
                handler: 'client_after_save'
            }
        ]
      end



      def client_after_save(client)
        if client.expertise_manager_result_changed?
          where(target: client).delete_all
          if client.expertise_manager_result.to_sym != :expertise_manager_result_empty
              create({
                   target: client,
                   client: client,
                   institution: nil,
                   label: client.full_name,
                   title:  "Das Gutachten für #{client.first_name} #{client.last_name} wurde abgeschlossen.",
                   message: "Die abschliessende Einschätzung wurde durch die Verwaltung abgegeben. Das Schülerportfolio kann jetzt auf Basis des Gutachtens weitergeführt werden.",
                   start_at: DateTime.now,
                   due_at: DateTime.now,
                   next_escalation: DateTime.now,
                   escalation_delay: 0,
                   resolve_location: Rails.application.routes.url_helpers.dashboard_client_path(client)
               })
          end
        end
      end
    end




  end
end