module SystemTasks
  class PortfolioReviewRequested < Base

    def _escalations
      [
          {
              Escalator::SendUserMessage => [target.teacher]
          },
          {
              Escalator::SendUserMessage => target.portfolio_item.involved_teachers + target.portfolio_item.evaluable_target_agreements.inject([]) do |memo,i|
                memo + i.evaluation.involved_teachers
              end + target.portfolio_item.portfolio_comments.inject([]) do |memo,i|
                memo + [i.author,i.teacher]
              end
          }
      ]
    end

    def is_manual_confirmable?
      true
    end

    class << self
      def subscribe_to
        [
            {
                klass: 'portfolio/comment',
                callback: 'after_create',
                handler: 'portfolio_comment_after_save'
            },
            {
                klass: 'portfolio/comment',
                callback: 'after_update',
                handler: 'portfolio_comment_after_save'
            }

        ]
      end


      def portfolio_comment_after_save(portfolio_comment)
        if portfolio_comment.teacher.present?
          where(target: portfolio_comment).delete_all
          if portfolio_comment.portfolio_item.portfolio.subject.is_a? ClientGroup
            _institution = portfolio_comment.portfolio_item.portfolio.subject_proxy.institution
            _client = nil
          end
          if portfolio_comment.portfolio_item.portfolio.subject.is_a? Client
            _institution = portfolio_comment.portfolio_item.portfolio.subject_proxy.institution
            _client = portfolio_comment.portfolio_item.portfolio.subject
          end
          create({
                     target: portfolio_comment,
                     client: _client,
                     institution: _institution,
                     start_at: DateTime.now,
                     label: portfolio_comment.portfolio_item.portfolio.subject_proxy.name,
                     title:  "#{portfolio_comment.author.full_name} hat ein Gutachten für einen Portfolioeintrag erbeten.",
                     message: "Es soll ein Gutachten durchgeführt werden. Gutachter: #{portfolio_comment.teacher.full_name}",
                     due_at: DateTime.now,
                     next_escalation: DateTime.now,
                     escalation_delay: 86400,
                     resolve_location: Rails.application.routes.url_helpers.portfolio_item_path(portfolio_comment.portfolio_item),
                 })
        end
      end

    end

  end
end