# JsonApiClient did not handle types with dashes correctly.
# I.e Type foo-bar was mapped on Class Foo-bar instead of FooBar
# Added sub('-', '_') for the purpose of class name resolution
JsonApiClient::Utils.module_eval do
  class << self
    alias_method :_super_compute_type, :compute_type
    def compute_type(klass, type_name)
      return type_name.constantize if type_name.match(/^::/)

      # Build a list of candidates to search for
      candidates = []
      # -- replaced "type_name.camelize" with "type_name.sub('-', '_').camelize"
      klass.name.scan(/::|$/) { candidates.unshift "#{$`}::#{type_name.gsub('-', '_').camelize}" }
      candidates << type_name.gsub('-', '_').camelize

      candidates.each do |candidate|
        begin
          constant = candidate.constantize
          return constant if candidate == constant.to_s
        rescue NameError => e
          # We don't want to swallow NoMethodError < NameError errors
          raise e unless e.instance_of?(NameError)
        end
      end
      raise NameError, "uninitialized constant #{candidates.first}"
    end
  end
end

module JsonApiClient
  module Errors
    class ValidationError < StandardError
    end
  end
end

module CsbApi
  # Base class for all Csb api result resouces
  class Base < ::JsonApiClient::Resource

    def self.version
      1 # THIS HAS TO BE INCREMENTED ON A MAJOR RELEASE
    end

    self.site = "#{ Rails.configuration.x.local_env["CSB_API_DOMAIN"]}/csb_api/v#{self.version}/"

    def self.custom_headers
      if Rails.env.development?
        super
      else
        super.merge({
            'X_CSB_API_KEY' => Rails.configuration.x.local_env["CSB_API_KEY"].to_s,
            'X_VSB_ID' => Rails.configuration.x.local_env["VSB_ID"].to_s,
            'X_VSB_API_VERSION' => self.version.to_s
        })
      end
    end

    def self.create!(attributes = {})
      create(attributes).tap do |resource|
        unless resource.persisted?
          raise ::JsonApiClient::Errors::ValidationError, resource.errors.full_messages.join(', ')
        end
      end
    end

    # get activerecord model from this resultset
    #
    # @return [ActiveRecord::Base] new model instance built from the result set data
    def build_model
      raise StandardError, "missing implementation of CsbApi::Base::build_model"
    end
    alias :populate_model :build_model
  end
end
