module CsbApi

  # Represents the csb api resultset type "diagnostic"
  #
  class Diagnostic < CsbApi::Base
    def self.table_name; "diagnostics"; end


    # populate Diagnostic activerecord instance from this result
    #
    # When any relationships of type (diagnostic-images|diagnostic-norms|diagnostic-characteristics)
    # are included (@see #JsonApiClient::Resource.includes) in this result,
    # the corresponding associations on Diagnostic are populated as well.
    #
    # When Diagnostic instance is omitted, a new instance is returned
    # When Diagnostic instance is set, it is populated and returned
    #
    # @param diagnostic [Diagnostic] the instance to populate
    # @return [Diagnostic] the populated instance
    def build_model(diagnostic = ::Diagnostic.new)
      diagnostic.attributes={
          title: read_attribute('title'),
          abbreviation: read_attribute('abbreviation'),
          catalog_id: read_attribute('id'),
          authors: read_attribute('authors') ,
          year: read_attribute('year'),
          subtitle: read_attribute('subtitle') ,
          min_level: read_attribute('min-level'),
          max_level: read_attribute('max-level'),
          age_from: read_attribute('age-from'),
          age_to: read_attribute('age-to'),
          short_description: read_attribute('short-description'),
          description: read_attribute('description') ,
          url: read_attribute('url') ,
          no_image_url: meta['no_image_url'],
          is_range_okologie: read_attribute('is-range-okologie') ,
          is_range_integration: read_attribute('is-range-integration') ,
          is_range_intensitat: read_attribute('is-range-intensitat'),
          diagnostic_type: read_attribute('diagnostic-type')
      }
      if relationships['portfolio-specializations'].present? && relationships['portfolio-specializations'].key?("data") # the records are included in the result set
        remotes = self.send('portfolio-specializations').index_by(&:id)
        diagnostic.portfolio_specialization_ids = ::PortfolioSpecialization.where(specialization_type: remotes.keys).pluck(:id)
      end
      if relationships['diagnostic-images'].present? && relationships['diagnostic-images'].key?("data") # the records are included in the result set
          remotes = self.send('diagnostic-images').index_by(&:name)
          diagnostic.diagnostic_imgs.each do |img| # update
            if remotes.key? img.name
              remotes[img.name].populate_model(img)
              remotes.delete img.name
            end
          end
          remotes.each_value do |resource|  # create
            diagnostic.diagnostic_imgs << resource.build_model
          end
      end
      if relationships['diagnostic-norms'].present? && relationships['diagnostic-norms'].key?("data") # the records are included in the result set
        remotes = self.send('diagnostic-norms').index_by(&:name)
        diagnostic.norm_scales.each do |img|# update
          if remotes.key? img.name
            remotes[img.name].populate_model(img)
            remotes.delete img.name
          end
        end
        remotes.each_value do |resource|# create
          diagnostic.norm_scales << resource.build_model
        end
      end
      if relationships['diagnostic-characteristics'].present? && relationships['diagnostic-characteristics'].key?("data") # the records are included in the result set
        remotes = self.send('diagnostic-characteristics').index_by(&:name)
        diagnostic.characteristics.each do |img|# update
          if remotes.key? img.name
            remotes[img.name].populate_model(img)
            remotes.delete img.name
          end
        end
        remotes.each_value do |resource|# create
          diagnostic.characteristics << resource.build_model
        end
      end
      return diagnostic
    end
    alias :populate_model :build_model

    # Represents the csb api resultset type "diagnostic-characteristic"
    #
    class DiagnosticCharacteristic < CsbApi::Base
      def self.table_name; "diagnostic-characteristics"; end


      # populate Characteristic activerecord instance from this result
      #
      # @param characteristic [Characteristic] the instance to populate
      # @return [Characteristic] the populated instance
      def build_model(characteristic = ::Characteristic.new)
        characteristic.attributes = {
            name: read_attribute('name'),
            is_positive: read_attribute('is-positive'),
        }
        return characteristic
      end

      alias :populate_model :build_model
    end

    # Represents the csb api resultset type "diagnostic-image"
    #
    class DiagnosticImage < CsbApi::Base
      def self.table_name; "diagnostic-images"; end

      # populate DiagnosticImg activerecord instance from this result
      #
      # @param image [DiagnosticImg] the instance to populate
      # @return [DiagnosticImg] the populated instance
      def build_model(image = ::DiagnosticImg.new)
        image.attributes = {
            name: read_attribute('name'),
            width_px: read_attribute('width-px'),
            height_px: read_attribute('height-px'),
            source_url: meta['url'],
            file_type: read_attribute('file-type')
        }
        return image
      end

      alias :populate_model :build_model
    end

    # Represents the csb api resultset type "diagnostic-norms"
    #
    class DiagnosticNorm < CsbApi::Base
      def self.table_name; "diagnostic-norms"; end

      # populate NormScale activerecord instance from this result
      #
      # @param scale [NormScale] the instance to populate
      # @return [NormScale] the populated instance
      def build_model(scale = ::NormScale.new)
        scale.attributes = {
            name: read_attribute('name'),
            range_from: read_attribute('range-from'),
            range_to: read_attribute('range-to'),
            avg: read_attribute('avg'),
            cut_off_low: read_attribute('cut-off-low'),
            cut_off_sub_avg: read_attribute('cut-off-sub-avg'),
            cut_off_above_avg: read_attribute('cut-off-above-avg'),
            cut_off_high: read_attribute('cut-off-high'),
            std_dev: read_attribute('std-dev')
        }
        return scale
      end

      alias :populate_model :build_model
    end


  end
end
