module CsbApi

  # Represents the csb api resultset type "diagnostic"
  #
  class OnlineDiagnostic < CsbApi::Base
    def self.table_name; "online-diagnostics"; end


    # populate Diagnostic activerecord instance from this result
    #
    # When any relationships of type (diagnostic-images|diagnostic-norms|diagnostic-characteristics)
    # are included (@see #JsonApiClient::Resource.includes) in this result,
    # the corresponding associations on Diagnostic are populated as well.
    #
    # When Diagnostic instance is omitted, a new instance is returned
    # When Diagnostic instance is set, it is populated and returned
    #
    # @param diagnostic [OnlineDiagnostic] the instance to populate
    # @return [OnlineDiagnostic] the populated instance
    def build_model(diagnostic = ::OnlineDiagnostic.new)
      diagnostic.attributes={
          id: read_attribute('id'),
          title: read_attribute('title'),
          abbreviation: read_attribute('abbreviation'),
          min_level: read_attribute('min-level'),
          max_level: read_attribute('max-level'),
          age_from: read_attribute('age-from'),
          age_to: read_attribute('age-to'),
          description: read_attribute('description')
      }

      if relationships['online-diagnostic-urls'].key? "data" # the records are included in the result set
          remotes = self.send('online-diagnostic-urls').index_by(&:name)
          diagnostic.online_diagnostic_urls.each do |url| # update
            if remotes.key? url.name
              remotes[url.name].populate_model(url)
              remotes.delete url.name
            end
          end
          remotes.each_value do |resource|  # create
            diagnostic.online_diagnostic_urls << resource.build_model
          end
      end
      return diagnostic
    end
    alias :populate_model :build_model

    # Represents the csb api resultset type "diagnostic-characteristic"
    #
    class OnlineDiagnosticUrl < CsbApi::Base
      def self.table_name; "online-diagnostic-urls"; end

      # populate Characteristic activerecord instance from this result
      #
      # @param url [OnlineDiagnosticUrl] the instance to populate
      # @return [OnlineDiagnosticUrl] the populated instance
      def build_model(url = ::OnlineDiagnosticUrl.new)
        url.attributes = {
            name: read_attribute('name'),
            url: read_attribute('url'),
        }
        return url
      end

      alias :populate_model :build_model
    end

  end
end
