module CsbApi
  class PortfolioRuleSet < CsbApi::Base
    def self.table_name; "portfolio-rule-sets"; end

    def rule_set_id
      read_attribute('id')
    end

    def build_definitions
      obj_ary = []
      portfolio_conditions = {}
      portfolio_steps = {}
      (JSON.parse Base64.decode64( read_attribute('definitions') )).each do |class_name, ary|
        case class_name
          when 'PortfolioStep'
            ary.each do |attributes|
              portfolio_steps[attributes['id']] = ::Portfolio::Step.new({
                 id:attributes['id'] ,
                 portfolio_rule_set_id:attributes['portfolio_rule_set_id'],
                 name:attributes['name'],
                 optionals:attributes['optionals'],
                 requirements:attributes['requirements'],
                 evaluation_time_span_min:attributes['evaluation_time_span_min'],
                 evaluation_time_span_max:attributes['evaluation_time_span_max'],
                 description:attributes['description'],
                 type:attributes['type'],
                 portfolio_matchers:attributes['portfolio_matchers'],
                 requirements_description:attributes['requirements_description']
             })
              obj_ary << portfolio_steps[attributes['id']]
            end
          when 'PortfolioStepResult'
            ary.each do |attributes|
              obj_ary << ::Portfolio::StepResult.new({
                 id:attributes['id'] ,
                 portfolio_rule_set_id:attributes['portfolio_rule_set_id'],
                 step_id:attributes['step_id'],
                 name:attributes['name'],
                 char:attributes['char'],
                 raises_level:attributes['raises_level']
             })
            end
          when 'PortfolioRule'
            ary.each do |attributes|
              obj_ary << ::Portfolio::Rule.new({
                 id:attributes['id'] ,
                 portfolio_rule_set_id:attributes['portfolio_rule_set_id'],
                 position:attributes['position'],
                 time_span:attributes['time_span'],
                 level:attributes['level'],
                 description:attributes['description'],
                 notifiers:attributes['notifiers']
             })
            end
          when 'PortfolioRuleStep'
            ary.each do |attributes|
              obj_ary << ::Portfolio::RuleStep.new({
                 id:attributes['id'] ,
                 portfolio_rule_set_id:attributes['portfolio_rule_set_id'],
                 rule_id:attributes['rule_id'],
                 step_id:attributes['step_id'],
                 allowed:attributes['allowed']
             })
            end
          when 'PortfolioDocumentType'
            ary.each do |attributes|
              obj_ary << ::Portfolio::DocumentType.new({
                   id:attributes['id'] ,
                   portfolio_rule_set_id: attributes['portfolio_rule_set_id'],
                   name:attributes['name'],
                   title:attributes['title']
               })
            end
          when 'PortfolioCondition'
            ary.each do |attributes|
              portfolio_conditions[attributes['id']] = ::Portfolio::Condition.new({
                  id:attributes['id'] ,
                  portfolio_rule_set_id:attributes['portfolio_rule_set_id'],
                  rule_id:attributes['rule_id'],
                  item_matchers:attributes['item_matchers'],
                  actions:attributes['actions'],
                  exit_portfolio:attributes['exit_portfolio'],
                  next_position:attributes['next_position'],
                  description:attributes['description'],
                  title:attributes['title'],
                  portfolio_matchers:attributes['portfolio_matchers']
              })
              obj_ary <<  portfolio_conditions[attributes['id']]
            end
          when 'PortfolioTemplateDocument'
            ary.each do |attributes|
              obj_ary << ::Portfolio::TemplateDocument.new({
                 id: attributes['id'] ,
                 portfolio_rule_set_id: attributes['portfolio_rule_set_id'],
                 rule_id:attributes['rule_id'],
                 url:attributes['url'],
                 name:attributes['name'],
             })
            end
          when 'PortfolioConditionsStep'
            ary.each do |attributes|
              obj_ary << ::Portfolio::ConditionsStep.new({
                 id:attributes['id'] ,
                 portfolio_rule_set_id: attributes['portfolio_rule_set_id'],
                 condition_id:attributes['condition_id'],
                 step_id:attributes['step_id']
             })
            end
        end
      end
      obj_ary
    end


  end
end
