class DbrPlotterWidget < ActionWidget::Base

    property :portfolio_item_evaluation_dbr, required: true

    def render(&block)
      view.capture(self,&block)
    end

    def line_pairs
      unless @lps
        if @portfolio_item_evaluation_dbr.baselines_amount == 0
          @lps =  [LinePair.new(view, {portfolio_item_evaluation_dbr: @portfolio_item_evaluation_dbr, intervention_line: 0})]
        else
          line_pairs = []
          @portfolio_item_evaluation_dbr.baselines_amount.times do |i|
            line_pairs << LinePair.new(view, {portfolio_item_evaluation_dbr: @portfolio_item_evaluation_dbr, base_line: i*2 , intervention_line: i*2+1})
          end
          @lps = line_pairs
        end
      end
      @lps
    end

    class LinePair
      attr_accessor :portfolio_item_evaluation_dbr
      attr_accessor :base_line
      attr_accessor :intervention_line
      attr_accessor :available_indexes
      attr_accessor :indexes
      attr_accessor :color
      attr_accessor :view
      def initialize(view,opt={})
        @colors = ['#85802b', '#00749F', '#73C774', '#C7754C', '#17BDB8']
        @available_indexes = [PNDOverlapIndex,PETOverlapIndex]
        @view=view
        opt.each do |k,v|
          send("#{k}=",v)
        end
      end
      def plots
        if @base_line
          base_line_data = @portfolio_item_evaluation_dbr.results.select(:id,:value,:portfolio_item_evaluation_dbr_characteristic_id).where(line_idx: @base_line).order(:id).includes(:characteristic).all.to_a.group_by{|result| result.characteristic}
          intervention_line_data = @portfolio_item_evaluation_dbr.results.select(:id,:value,:portfolio_item_evaluation_dbr_characteristic_id).where(line_idx: @intervention_line).order(:id).includes(:characteristic).all.to_a.group_by{|result| result.characteristic}

          colors = @colors.clone
          base_line_plot = Plot.new(@view)
          base_line_data.each do  |characteristic,results|
            base_line_plot.data_series << DataSeries.new(
                {
                    data: results,
                    characteristic: characteristic,
                    color: colors.shift
                }
            )
          end
          base_line_plot_tick_length = base_line_plot.data_series.inject(0){|memo,serie|[memo,serie.data.length].max}
          base_line_plot.jqplot_options = {
              legend:{
                  show: false
              },
              axes: {
                  xaxis:  {
                      label: @portfolio_item_evaluation_dbr.lines[@base_line],
                      min: 1,
                      max: _calculate_max(1,base_line_plot_tick_length,20),
                      renderer: '$.jqplot.CategoryAxisRenderer',
                      numberTicks: _calculate_tick_number(1,base_line_plot_tick_length,20),
                      #ticks: Array(1..base_line_plot_tick_length),
                      tickOptions: {
                          formatString: '%d'
                      }
                  },
                  yaxis: {
                      label:false,
                      min: @portfolio_item_evaluation_dbr.range_begin,
                      max: _calculate_max(@portfolio_item_evaluation_dbr.range_begin,@portfolio_item_evaluation_dbr.range_end),
                      rendererOptions: {
                          forceTickAt0: true
                      },
                      numberTicks: _calculate_tick_number(@portfolio_item_evaluation_dbr.range_begin,@portfolio_item_evaluation_dbr.range_end),
                      tickOptions: {
                          formatString: '%d'
                      }
                  }
              }
          }
          colors = @colors.clone
          intervention_line_plot = Plot.new(view)
          intervention_line_data.each do  |characteristic,results|
            intervention_line_plot.data_series << DataSeries.new(
                {
                    data: results,
                    characteristic: characteristic,
                    color: colors.shift,
                    first_tick: base_line_plot_tick_length+1
                }
            )
          end
          intervention_line_plot.jqplot_options = {
              legend:{
                  show: true,  renderer: '$.jqplot.EnhancedLegendRenderer', rendererOptions: { seriesToggle: true }
              },
              axes: {
                  xaxis:  {
                      label: @portfolio_item_evaluation_dbr.lines[@intervention_line],
                      renderer: '$.jqplot.CategoryAxisRenderer',
                      min: base_line_plot_tick_length+1,
                      max: _calculate_max(base_line_plot_tick_length+1,base_line_plot_tick_length + intervention_line_plot.data_series.inject(0){|memo,serie|[memo,serie.data.length].max},20),
                      #ticks: Array((base_line_plot_tick_length+1)..(base_line_plot_tick_length + intervention_line_plot.data_series.inject(0){|memo,serie|[memo,serie.data.length].max})),
                      numberTicks: _calculate_tick_number(base_line_plot_tick_length+1,base_line_plot_tick_length + intervention_line_plot.data_series.inject(0){|memo,serie|[memo,serie.data.length].max},20),
                      tickOptions: {
                          formatString: '%d'
                      }
                  },
                  yaxis: {
                      show: false,
                      showTicks: false,
                      min: @portfolio_item_evaluation_dbr.range_begin,
                      max: _calculate_max(@portfolio_item_evaluation_dbr.range_begin,@portfolio_item_evaluation_dbr.range_end),
                      rendererOptions: {
                          forceTickAt0: true
                      },
                      numberTicks: _calculate_tick_number(@portfolio_item_evaluation_dbr.range_begin,@portfolio_item_evaluation_dbr.range_end),
                      tickOptions: {
                          formatString: '%d'
                      }
                  }
              }
          }
          intervention_line_plot.push_js(
          <<-METHOD
              $(document).on('click','##{intervention_line_plot.dom_id} tr.jqplot-table-legend',function(){
                  var base_line_plot = _vsb_jqplot_registry['#{base_line_plot.dom_id}']
                  var intervention_line_plot = _vsb_jqplot_registry['#{intervention_line_plot.dom_id}']
                  if(intervention_line_plot && base_line_plot){
                    base_line_plot.series[$(this).index()].show = !base_line_plot.series[$(this).index()].show
                    base_line_plot.drawSeries({},$(this).index());
                  }
              });
          METHOD
          )
          @indexes = @available_indexes.map do |klass|
            klass.new({
                base_line_plot: base_line_plot,
                intervention_line_plot: intervention_line_plot
            })
          end
          return [base_line_plot, intervention_line_plot]
        else
          intervention_line_data = @portfolio_item_evaluation_dbr.results.select(:id,:value,:portfolio_item_evaluation_dbr_characteristic_id).where(line_idx: @intervention_line).order(:id).includes(:characteristic).all.to_a.group_by{|result| result.characteristic}
          colors = @colors
          intervention_line_plot = Plot.new(view)
          intervention_line_data.each do  |characteristic,results|
            intervention_line_plot.data_series << DataSeries.new({
                data: results,
                characteristic: characteristic,
                color: colors.shift
            })
          end
          intervention_line_plot.jqplot_options = {
              legend:{
                  show: true,  renderer: '$.jqplot.EnhancedLegendRenderer', rendererOptions: { seriesToggle: true }
              },
              axes: {
                  xaxis:  {
                      label: @portfolio_item_evaluation_dbr.lines[@intervention_line],
                      renderer: '$.jqplot.CategoryAxisRenderer',
                      min: 1,
                      max: _calculate_max(1,intervention_line_plot.data_series.inject(0){|memo,serie|[memo,serie.data.length].max},20),
                      #ticks: Array(1..intervention_line_plot.data_series.inject(0){|memo,serie|[memo,serie.data.length].max}),
                      numberTicks: _calculate_tick_number(1,intervention_line_plot.data_series.inject(0){|memo,serie|[memo,serie.data.length].max},20),
                      tickOptions: {
                          formatString: '%d'
                      }
                  },
                  yaxis: {
                      show: false,
                      min: @portfolio_item_evaluation_dbr.range_begin,
                      max: _calculate_max(@portfolio_item_evaluation_dbr.range_begin,@portfolio_item_evaluation_dbr.range_end),
                      rendererOptions: {
                          forceTickAt0: true
                      },
                      numberTicks: _calculate_tick_number(@portfolio_item_evaluation_dbr.range_begin,@portfolio_item_evaluation_dbr.range_end),
                      tickOptions: {
                          formatString: '%d'
                      }
                  }
              }
          }
          return [intervention_line_plot]
        end
      end
      private
      def _calculate_tick_number(_min,_max,_max_tick_number= 10)
        _divisors=(2.._max_tick_number).to_a.reverse
        _numberTicks = _divisors.select{|d| (_max-_min) % d == 0 }.first
        if _numberTicks == nil
          _max = _max + 1
          _numberTicks = _divisors.select{|d| (_max-_min) % d == 0 }.first
        end
        _numberTicks + 1
      end
      def _calculate_max(_min,_max,_max_tick_number= 10)
        _divisors=(2.._max_tick_number).to_a.reverse
        _numberTicks = _divisors.select{|d| (_max-_min) % d == 0 }.first
        if _numberTicks == nil
          _max = _max + 1
          _numberTicks = _divisors.select{|d| (_max-_min) % d == 0 }.first
        end
        _max
      end
    end

    class Plot
      attr_accessor :data_series
      attr_accessor :data_range
      attr_accessor :height
      attr_accessor :width
      attr_accessor :jqplot_options
      attr_accessor :push_js
      attr_accessor :view
      attr_accessor :dom_id
      def initialize(view,opt={})
        @view=view
        @height=300
        @width="100%"
        @dom_id = SecureRandom.hex(12)
        @data_range = []
        @data_series=[]
        @jqplot_options={}
        @push_js = []
        opt.each do |k,v|
          send("#{k}=",v)
        end
      end
      def push_js(js)
        @push_js ||= []
        @push_js << js
      end
      def push_on_jqplot_hooks(hook,method)
        @push_on_jqplot_hooks[hook] ||= []
        @push_on_jqplot_hooks[hook].push(method)
      end
      def draw
        @data_series.each do |series|
          deep_merge_into_jqplot_options(series.options)
        end
        height = @height.is_a?(String) ? @height : "#{@height}px"
        width = @width.is_a?(String) ? @width : "#{@width}px"
        _content = [@view.content_tag( :div, nil, data: {series: @data_series.map(&:points), options: @jqplot_options, role: 'vsb-jqplot'},
                                      id: @dom_id, style: "height:#{height};width:#{width}")]

        @push_js.each do |js|
          _content << @view.javascript_tag( js )
        end
        _content.join(' ').html_safe
      end
      def deep_merge_into_jqplot_options(options)
        @jqplot_options = deep_merge_hashes(@jqplot_options,options)
      end
      private
      def deep_merge_hashes(a,b)
        merger = proc { |key, v1, v2| Hash === v1 && Hash === v2 ? v1.merge(v2, &merger) : Array === v1 && Array === v2 ? v1 | v2 : [:undefined, nil, :nil].include?(v2) ? v1 : v2 }
        a.merge(b.to_h,&merger)
      end
    end

    class DataSeries
      attr_accessor :data
      attr_accessor :characteristic
      attr_accessor :color
      attr_accessor :first_tick
      attr_reader :last_tick
      def initialize(opt={})
        @first_tick = 1
        opt.each {|k,v|send("#{k}=",v)}
        @last_tick = @first_tick + (@data.length-1)
      end
      def points
        @data.each_with_index.map { |v,i| [i+@first_tick,v.value] }
      end
      def options
        {series: [{label: @characteristic.name, color: @color,
                   lineWidth: 1,
                   fillAndStroke: true, fill: true,
                   fillAlpha: 0.2, shadowAlpha: 0,
                   showMarker: true,
                   markerOptions: {
                       show: true,
                       style: "filledCircle",
                       size: 3}}]}
      end
    end

    class OverlapIndex
      attr_accessor :name
      attr_accessor :control_element_dom_id
      attr_accessor :secondary_control_element_dom_class
      attr_accessor :show_initially
      attr_accessor :values
      attr_accessor :base_line_plot
      attr_accessor :intervention_line_plot
      def initialize(opt={})
        @control_element_dom_id = SecureRandom.hex(12)
        @secondary_control_element_dom_class = "ovrlp-idx-ctrl-#{@control_element_dom_id}"
        @show_initially = false
        init
        opt.each do |k,v|
          send("#{k}=",v)
        end
        apply
        @values = calculate
        apply_js
      end
      def init

      end
      def calculate
        raise 'Implement'
      end
      def apply
        raise 'Implement'
      end
      def apply_js
        @intervention_line_plot.push_js(
            <<-METHOD
              $(document).on('click','##{@intervention_line_plot.dom_id} tr.jqplot-table-legend',function(){
                  var base_line_plot = _vsb_jqplot_registry['#{@base_line_plot.dom_id}']
                  var intervention_line_plot = _vsb_jqplot_registry['#{@intervention_line_plot.dom_id}']
                  if(intervention_line_plot && base_line_plot){
                    var control_element = $('##{@control_element_dom_id}');
                    var current_characteristic_status = control_element.data('jqplot-index-toggled-by-characteristic-'+$(this).index());
                    var current_index_status = control_element.data('jqplot-index-toggled-by-control-element');
                    if(current_characteristic_status == undefined){
                      current_characteristic_status = true;
                    }
                    if(current_index_status == undefined){
                      current_index_status = #{@show_initially};
                    }
                    var current_status = !current_characteristic_status && current_index_status;
                    control_element.data('jqplot-index-toggled-by-characteristic-'+$(this).index(),!current_characteristic_status);

                    var co = intervention_line_plot.plugins.canvasOverlay;
                    var obj = co.get("#{self.class.name}-"+$(this).index());
                    obj.options.show = current_status;
                    co.draw(intervention_line_plot);

                    var co = base_line_plot.plugins.canvasOverlay;
                    var obj = co.get("#{self.class.name}-"+$(this).index());
                    obj.options.show = current_status;
                    co.draw(base_line_plot);
                  }
              });
        METHOD
        )
        @intervention_line_plot.push_js(
            <<-METHOD
              $(document).on('click','##{@control_element_dom_id},.#{@secondary_control_element_dom_class}',function(){
                  var base_line_plot = _vsb_jqplot_registry['#{@base_line_plot.dom_id}']
                  var intervention_line_plot = _vsb_jqplot_registry['#{@intervention_line_plot.dom_id}']
                  if(intervention_line_plot && base_line_plot){
                    var control_element = $('##{@control_element_dom_id}');
                    var current_index_status = control_element.data('jqplot-index-toggled-by-control-element');
                    if(current_index_status == undefined){
                      current_index_status = #{@show_initially};
                    }
                    control_element.data('jqplot-index-toggled-by-control-element',!current_index_status)
                    $('##{@intervention_line_plot.dom_id} tr.jqplot-table-legend').each(function(){
                      var current_characteristic_status = control_element.data('jqplot-index-toggled-by-characteristic-'+$(this).index())
                      if(current_characteristic_status == undefined){
                        current_characteristic_status = true;
                      }
                      var current_status = current_characteristic_status && !current_index_status;
                      var co = intervention_line_plot.plugins.canvasOverlay;
                      var obj = co.get("#{self.class.name}-"+$(this).index());
                      obj.options.show = current_status;
                      co.draw(intervention_line_plot);
                      var co = base_line_plot.plugins.canvasOverlay;
                      var obj = co.get("#{self.class.name}-"+$(this).index());
                      obj.options.show = current_status;
                      co.draw(base_line_plot);
                    });

                  }
              });
        METHOD
        )
      end
      class IndexValue
        attr_accessor :value, :characteristic
        def initialize(value,characteristic)
          @value=value;
          @characteristic=characteristic
        end
        def display_value
          raise 'Implement'
        end
        def color
          raise 'Implement'
        end
        def interpretation
          raise 'Implement'
        end
      end
    end

    class PETOverlapIndex < OverlapIndex
      def init
        @name='PET (Percentage of data points exceeding the trend)'
      end
      def calculate
        values = []
        @base_line_plot.data_series.each_with_index do |serie,index|
          slr = SimpleLinearRegression.new(
              Array(1..(serie.data.map(&:value).select(&:present?).length)),
              serie.data.map(&:value).select(&:present?)
          )
          _positive = serie.characteristic.increase_is_positive
          _count_number_of_points_exceeding = 0;
          @intervention_line_plot.data_series[index].data.each_with_index do |result,i|
            next if result.value.nil?
            if _positive
              if (result.value > slr.fx(i+@intervention_line_plot.data_series[index].first_tick))
                _count_number_of_points_exceeding += 1
              end
            else
              if (result.value < slr.fx(i+@intervention_line_plot.data_series[index].first_tick))
                _count_number_of_points_exceeding += 1
              end
            end
          end
          _all_points = @intervention_line_plot.data_series[index].data.length
          if _all_points > 0
            values << PNDIndexValue.new(_count_number_of_points_exceeding.to_f / _all_points.to_f,serie.characteristic)
          else
            values << PNDIndexValue.new(0,serie.characteristic)
          end
        end
        values
      end
      def apply
        @base_line_plot.data_series.each_with_index do |serie,index|
          intervention_serie = @intervention_line_plot.data_series[index]
          baseline_serie = serie
          slr = SimpleLinearRegression.new(
              Array(1..(baseline_serie.data.map(&:value).select(&:present?).length)),
              baseline_serie.data.map(&:value).select(&:present?)
          )
          base_startX = baseline_serie.first_tick
          base_endX = baseline_serie.last_tick
          base_startY = slr.fx(base_startX)
          base_endY = slr.fx(base_endX)
          line = {canvasOverlay: {
              show: true,
              objects: [
                  {line: {
                      start: [base_startX,base_startY],
                      stop: [base_endX,base_endY],
                      name: "#{self.class.name}-#{index}",
                      lineWidth: 2,
                      color: baseline_serie.color,
                      shadow: false,
                      xOffset: 0,
                      yOffset: 0,
                      show: @show_initially
                  }}
              ]
          }}
          @base_line_plot.deep_merge_into_jqplot_options(line)

          intervention_startX = intervention_serie.first_tick
          intervention_endX = intervention_serie.last_tick
          intervention_startY = slr.fx(intervention_startX)
          intervention_endY = slr.fx(intervention_endX)
          line = {canvasOverlay: {
              show: true,
              objects: [
                  {line: {
                      start: [intervention_startX,intervention_startY],
                      stop: [intervention_endX,intervention_endY],
                      name: "#{self.class.name}-#{index}",
                      lineWidth: 2,
                      color: intervention_serie.color,
                      shadow: false,
                      xOffset: 0,
                      yOffset: 0,
                      show: @show_initially
                  }}
              ]
          }}
          @intervention_line_plot.deep_merge_into_jqplot_options(line)
        end
      end
      class PNDIndexValue < IndexValue
        def display_value
          "#{'%.2f'%(@value*100)}%"
        end
        def color
          _pnd_col = 'danger'
          if @value >= 0.5 && @value < 0.7
            _pnd_col = 'info'
          end
          if @value >= 0.7 && @value < 0.9
            _pnd_col = 'warning'
          end
          if @value >= 0.9
            _pnd_col = 'success'
          end
          _pnd_col
        end
        def interpretation
          _pnd_col = 'keine Wirkung'
          if @value >= 0.5 && @value < 0.7
            _pnd_col = 'leichte Wirkung'
          end
          if @value >= 0.7 && @value < 0.9
            _pnd_col = 'moderate Wirkung'
          end
          if @value >= 0.9
            _pnd_col = 'starke Wirkung'
          end
          _pnd_col
        end
      end
      class SimpleLinearRegression
        attr_reader :slope, :y_intercept
        def initialize(xs, ys)
          @xs, @ys = xs, ys
          if @xs.length != @ys.length
            raise "Unbalanced data. xs need to be same length as ys"
          end
          @mean_xs =  _mean(@xs)
          @mean_ys =  _mean(@ys)
          @slope = _slope
          @y_intercept = _y_intercept
        end

        def fx(x)
          @y_intercept + @slope * x
        end

        private

        def _y_intercept
          @mean_ys - (_slope * @mean_xs)
        end

        def _slope
          x_mean = @mean_xs
          y_mean = @mean_ys

          numerator = (0...@xs.length).reduce(0) do |sum, i|
            sum + ((@xs[i] - x_mean) * (@ys[i] - y_mean))
          end

          denominator = @xs.reduce(0) do |sum, x|
            sum + ((x - x_mean) ** 2)
          end

          denominator == 0 ? 0 : (numerator / denominator)
        end

        def _mean(values)
          total = values.reduce(0) { |sum, x| x + sum }
          Float(total) / Float(values.length)
        end
      end
    end

    class PNDOverlapIndex < OverlapIndex
      def init
        @name='PND (Percentage of non overlapping data points)'
      end
      def calculate
        values = []
        @base_line_plot.data_series.each_with_index do |serie,index|
          _positive = serie.characteristic.increase_is_positive
          _extreme_baseline_point = nil
          serie.data.each do |result|
            next if result.value.nil?
            _extreme_baseline_point ||= result.value
            if _positive
              _extreme_baseline_point = [_extreme_baseline_point,result.value].max unless result.value.blank?
            else
              _extreme_baseline_point = [_extreme_baseline_point,result.value].min unless result.value.blank?
            end
          end
          _count_number_of_points_exceeding = 0;
          @intervention_line_plot.data_series[index].data.each do |result|
            next if result.value.nil?
            if _positive
              _count_number_of_points_exceeding += 1 if result.value.present? && _extreme_baseline_point.present? && ( result.value > _extreme_baseline_point )
            else
              _count_number_of_points_exceeding += 1 if result.value.present? && _extreme_baseline_point.present? && ( result.value < _extreme_baseline_point )
            end
          end
          _all_points = @intervention_line_plot.data_series[index].data.length
          if _all_points > 0
            values << PNDIndexValue.new(_count_number_of_points_exceeding.to_f / _all_points.to_f,serie.characteristic)
          else
            values << PNDIndexValue.new(0,serie.characteristic)
          end
        end
        values
      end
      def apply
        @base_line_plot.data_series.each_with_index do |series,index|
          if series.characteristic.increase_is_positive
            _reference_value = series.data.map(&:value).select(&:present?).max
          else
            _reference_value = series.data.map(&:value).select(&:present?).min
          end
          h_line = {canvasOverlay: {
              show: true,
              objects: [
                  {horizontalLine: {
                      name: "#{self.class.name}-#{index}",
                      y: _reference_value,
                      lineWidth: 2,
                      color: series.color,
                      shadow: false,
                      xOffset: 0,
                      show: @show_initially
                  }}
              ]
          }}
          @base_line_plot.deep_merge_into_jqplot_options(h_line)
          @intervention_line_plot.deep_merge_into_jqplot_options(h_line)
        end
      end
      class PNDIndexValue < IndexValue
        def display_value
          "#{'%.2f'%(@value*100)}%"
        end
        def color
          _pnd_col = 'danger'
          if @value >= 0.5 && @value < 0.7
            _pnd_col = 'info'
          end
          if @value >= 0.7 && @value < 0.9
            _pnd_col = 'warning'
          end
          if @value >= 0.9
            _pnd_col = 'success'
          end
          _pnd_col
        end
        def interpretation
          _pnd_col = 'keine Wirkung'
          if @value >= 0.5 && @value < 0.7
            _pnd_col = 'leichte Wirkung'
          end
          if @value >= 0.7 && @value < 0.9
            _pnd_col = 'moderate Wirkung'
          end
          if @value >= 0.9
            _pnd_col = 'starke Wirkung'
          end
          _pnd_col
        end
      end
    end

end
