class PanelWidget < ActionWidget::Base

    property :type, default: 'default', converts: :to_s

    def render(&block)
      _content = view.capture(self,&block)
      content_tag(:div, options.merge( { class: %W(panel panel-#{type}) } ){|k,o,v| o+v if k==:class }, {}, false ) do
        (@panel_header ? @panel_header.render : ''.html_safe) + _content
      end
    end

    def header(_options = {}, &block)
      _options.merge!({
         :content => block
      })
      @panel_header = PanelHeader.new(view, _options) and return
    end

    def body(*args, &block)
      _options= args.extract_options!
      content = view.capture(self,&block) if block
      content = args.shift unless block
      content_tag(:div, content, _options.merge({ class: %w(panel-body)}){|k,o,v| o+v if k==:class },  false )
    end

    def footer(*args, &block)
      _options= args.extract_options!
      content = view.capture(self,&block) if block
      content = args.shift unless block
      content_tag(:div, content, _options.merge({class: %w(panel-footer)}){|k,o,v| o+v if k==:class },  false )
    end

    class PanelHeader < ActionWidget::Base
      property :content, default: nil
      property :title

      def render
        @panel_header_button_html = ''.html_safe
        @panel_header_buttons = []
        _content = (content ? view.capture(self,&content) : ''.html_safe)
        _content ||= ''.html_safe
        content_tag(:div, options.merge({class: %W(panel-heading)}){|k,o,v| o+v if k==:class }, {}, false) do
          _content  +
          content_tag(:div, {class: %w(btn-group btn-group-sm pull-right)}, {}, false ) do
            @panel_header_button_html +
            (@panel_header_buttons.any? ? (@panel_header_buttons.collect do |button|
              button.render
            end.join.html_safe) : ''.html_safe)
          end +
          content_tag(:h3, @title, {class: %w(panel-title)}, false )
        end
      end

      def buttons(&block)
        (@panel_header_button_html = view.capture(self,&block)) and return
      end

      def link_button(_options = {}, &block)
        _options.merge!({:content => block})
        @panel_header_buttons << PanelHeaderLinkButton.new(view, _options) and return
      end

      def button(_options = {}, &block)
        _options.merge!({:content => block})
        @panel_header_buttons << PanelHeaderButtonButton.new(view, _options) and return
      end

      def title(&block)
        @title = view.capture(self,&block) and return
      end

      class PanelHeaderButton < ActionWidget::Base
        property :type_class, accepts: %w(success warning), default: 'success', converts: :to_s
        property :icon, required: true, converts: :to_s
        property :content, default: nil
        private
        def css_classes
          css_classes = []
          css_classes << "btn-#{type_class}"
          css_classes
        end
      end # class PanelHeaderButton

      class PanelHeaderButtonButton < PanelHeaderButton
        property :type, required: true, converts: :to_s
        def render
          _content = (content ? view.capture(self,&content) : ''.html_safe)
          content_tag(:button, options.merge({class: %w(btn btn-sm) + css_classes, type: type}){|k,o,v| o+v if k==:class }, {}, false ) do
            _content + content_tag(:i, nil, class: "glyphicon glyphicon-#{icon}")
          end
        end
      end # class PanelHeaderButtonButton

      class PanelHeaderLinkButton < PanelHeaderButton
        property :href, required: true, converts: :to_s
        def render
          content_tag(:a, options.merge({class: %w(btn btn-sm) + css_classes, role: 'button', href: href}){|k,o,v| o+v if k==:class }, {}, false ) do
            (content ? view.capture(self,&content) : ''.html_safe) +
                content_tag(:i, nil, class: "glyphicon glyphicon-#{icon}")
          end
        end
      end # class PanelHeaderLinkButton

    end # class PanelHeader
end
