class AddToClientGroups < ActiveRecord::Migration
  def change

    # the associations between clients and client groups.
    # There is also FK client_group_id in client, which is always set to the client group of the current semester
    # Updates on client_groups_clients in current semester trigger update of client.client_group_id, others don't
    # When semester changes, client.client_group_id is also updated.
    create_table :client_groups_clients do |t|
      t.references :client, :null => false
      t.references :client_group, :null => false
      t.references :semester, :null => false
    end

    # a client may only be in one class in a semester
    add_index :client_groups_clients, [:client_id, :semester_id], :unique => true

    # a teacher may only be the class teacher of one class in a semester
    add_index :client_groups, [ :teacher_id, :semester_id ], :unique => true

    # this is client group of teacher in current semester, updates here are triggered
    # There is also the FK client_groups.teacher_id, updates on it in current semester trigger update on teacher.client_group_id
    # When semester changes, teacher.client_group_id is also updated.
    add_reference :teachers, :client_group

    remove_column :client_groups, :active


  end
end
