class CreateInstituitonHierarchies < ActiveRecord::Migration
  def down
    execute 'DROP TRIGGER IF EXISTS institutions_maintain_tree_consistency ON institutions;'
    execute 'DROP FUNCTION IF EXISTS institution_hierarchies_update()'
    execute 'DROP TABLE IF EXISTS institution_hierarchies'
    add_foreign_key :institutions, :institutions, column: :parent_id
  end
  def up
    create_table :institution_hierarchies, id: false do |t|
      t.integer :parent_id, index: true
      t.integer :child_id, index: true
    end
    remove_foreign_key :institutions, column: :parent_id # integrity is ensured by trigger below
    execute 'WITH RECURSIVE institution_hierarchies_cte(child_id,parent_id) AS (
      SELECT institutions.id, institutions.parent_id
      FROM institutions WHERE  institutions.parent_id IS NOT NULL
      UNION
      SELECT institution_hierarchies_cte.child_id, institutions.parent_id
      FROM institution_hierarchies_cte JOIN institutions  ON institution_hierarchies_cte.parent_id = institutions.id
      WHERE institutions.parent_id IS NOT NULL
    )  INSERT INTO institution_hierarchies SELECT institution_hierarchies_cte.parent_id,institution_hierarchies_cte.child_id FROM institution_hierarchies_cte;'
    execute "
      CREATE OR REPLACE FUNCTION institution_hierarchies_update() RETURNS TRIGGER
      AS $institution_hierarchies_update$
          BEGIN
              IF (TG_OP = 'DELETE') THEN
                DELETE FROM institution_hierarchies WHERE child_id=OLD.id OR parent_id=OLD.id;
                UPDATE institutions SET parent_id=OLD.parent_id WHERE parent_id=OLD.id;
              ELSIF (TG_OP = 'UPDATE') THEN
                -- Rebuild the complete hierarchy, consider rebuilding partly when performance degrades
                DELETE FROM institution_hierarchies;
                WITH RECURSIVE institution_hierarchies_cte(child_id,parent_id) AS (
                  SELECT institutions.id, institutions.parent_id
                  FROM institutions WHERE  institutions.parent_id IS NOT NULL
                  UNION
                  SELECT institution_hierarchies_cte.child_id,  institutions.parent_id
                  FROM institution_hierarchies_cte JOIN institutions  ON institution_hierarchies_cte.parent_id = institutions.id
                  WHERE institutions.parent_id IS NOT NULL
                )  INSERT INTO institution_hierarchies SELECT institution_hierarchies_cte.parent_id,institution_hierarchies_cte.child_id FROM institution_hierarchies_cte;
              ELSIF (TG_OP = 'INSERT') THEN
                -- Rebuild the complete hierarchy, consider rebuilding partly when performance degrades
                DELETE FROM institution_hierarchies;
                WITH RECURSIVE institution_hierarchies_cte(child_id,parent_id) AS (
                  SELECT institutions.id, institutions.parent_id
                  FROM institutions WHERE  institutions.parent_id IS NOT NULL
                  UNION
                  SELECT institution_hierarchies_cte.child_id,  institutions.parent_id
                  FROM institution_hierarchies_cte JOIN institutions  ON institution_hierarchies_cte.parent_id = institutions.id
                  WHERE institutions.parent_id IS NOT NULL
                )  INSERT INTO institution_hierarchies SELECT institution_hierarchies_cte.parent_id,institution_hierarchies_cte.child_id FROM institution_hierarchies_cte;
              END IF;
              RETURN NULL;
          END;
      $institution_hierarchies_update$ LANGUAGE plpgsql;
      CREATE TRIGGER institutions_maintain_tree_consistency
      AFTER INSERT OR UPDATE OR DELETE ON institutions
          FOR EACH ROW EXECUTE PROCEDURE institution_hierarchies_update();"

  end
end
