class NotificationRef < ActiveRecord::Migration
  def up

    add_column :client_supporter_relations, :author_id, :integer
    add_column :client_supporter_relations, :author_type, :string
    add_column :client_supporter_relations, :editor_id, :integer
    add_column :client_supporter_relations, :editor_type, :string

    create_table :system_tasks do |t|
      t.references :target, polymorphic: true
      t.references :client, index: true # there could be a target, that belongs to a client, but is in fact no client
      t.references :institution, index: true # there could be a target, that belongs to an institution, but is in fact no institution
      t.integer :escalation_level # the current escalation level.
      t.datetime :next_escalation, index: true # the datetime, when the task is escalated again
      t.integer :escalation_delay # wait that many seconds between each escalation
      t.string :type # sti
      t.string :title
      t.string :message
      t.string :label
      t.datetime :start_at, index: true
      t.datetime :due_at, index: true
      t.string :resolve_location
    end
    add_index :system_tasks, [:target_id, :target_type]


    create_table :user_messages do |t|
      t.references :recipient, polymorphic: true # this is the actual recipient (teacher,manager)
      t.references :sender, polymorphic: true # this can be a user (teacher,manager) or is null when system message
      t.references :system_task, index: true
      t.integer :message_box # this can be 'new','read','deleted','sent'
      t.integer :message_type # 'out','in'
      t.string :subject_text
      t.text :content
      t.integer :prio
      t.datetime :due_at
      t.timestamps
    end
    add_index :user_messages, [:recipient_id, :recipient_type]
    add_index :user_messages, [:sender_id, :sender_type]
    execute "ALTER TABLE user_messages ADD CONSTRAINT fk_um_on_st_id FOREIGN KEY (system_task_id)  REFERENCES system_tasks (id) ON DELETE CASCADE ON UPDATE CASCADE;"

    # for now, mapping notifications on system tasks with message sending is too complicated. All current notifications are dropped.
    # I hope this is not a problem.

  end
  def down
    remove_column :client_supporter_relations, :author_id
    remove_column :client_supporter_relations, :author_type
    remove_column :client_supporter_relations, :editor_id
    remove_column :client_supporter_relations, :editor_type
    drop_table :user_messages
    drop_table :system_tasks
  end
end
