--
-- PostgreSQL database dump
--

-- Dumped from database version 11.1
-- Dumped by pg_dump version 11.1

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET client_min_messages = warning;
SET row_security = off;

--
-- Name: public; Type: SCHEMA; Schema: -; Owner: -
--

CREATE SCHEMA public;


--
-- Name: SCHEMA public; Type: COMMENT; Schema: -; Owner: -
--

COMMENT ON SCHEMA public IS 'standard public schema';


--
-- Name: institution_document_hierarchies_update(); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION public.institution_document_hierarchies_update() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
          BEGIN
              IF (TG_OP = 'DELETE') THEN
                DELETE FROM institution_document_hierarchies WHERE child_id=OLD.id OR parent_id=OLD.id;
                UPDATE institution_documents SET parent_id=OLD.parent_id WHERE parent_id=OLD.id;
              ELSIF (TG_OP = 'UPDATE') THEN
                -- Rebuild the complete hierarchy, consider rebuilding partly when performance degrades
                DELETE FROM institution_document_hierarchies;
                WITH RECURSIVE institution_document_hierarchies_cte(child_id,parent_id,level) AS (
                  SELECT institution_documents.id, institution_documents.parent_id, 1
                  FROM institution_documents WHERE institution_documents.parent_id IS NOT NULL
                  UNION
                  SELECT institution_document_hierarchies_cte.child_id, institution_documents.parent_id, institution_document_hierarchies_cte.level + 1
                  FROM institution_document_hierarchies_cte JOIN institution_documents  ON institution_document_hierarchies_cte.parent_id = institution_documents.id
                  WHERE institution_documents.parent_id IS NOT NULL
                )  INSERT INTO institution_document_hierarchies SELECT institution_document_hierarchies_cte.parent_id,institution_document_hierarchies_cte.child_id,institution_document_hierarchies_cte.level FROM institution_document_hierarchies_cte;
              ELSIF (TG_OP = 'INSERT') THEN
                -- Rebuild the complete hierarchy, consider rebuilding partly when performance degrades
                DELETE FROM institution_document_hierarchies;
                WITH RECURSIVE institution_document_hierarchies_cte(child_id,parent_id,level) AS (
                  SELECT institution_documents.id, institution_documents.parent_id, 1
                  FROM institution_documents WHERE institution_documents.parent_id IS NOT NULL
                  UNION
                  SELECT institution_document_hierarchies_cte.child_id, institution_documents.parent_id, institution_document_hierarchies_cte.level + 1
                  FROM institution_document_hierarchies_cte JOIN institution_documents  ON institution_document_hierarchies_cte.parent_id = institution_documents.id
                  WHERE institution_documents.parent_id IS NOT NULL
                )  INSERT INTO institution_document_hierarchies SELECT institution_document_hierarchies_cte.parent_id,institution_document_hierarchies_cte.child_id,institution_document_hierarchies_cte.level FROM institution_document_hierarchies_cte;
              END IF;
              RETURN NULL;
          END;
      $$;


--
-- Name: institution_hierarchies_update(); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION public.institution_hierarchies_update() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
          BEGIN
              IF (TG_OP = 'DELETE') THEN
                DELETE FROM institution_hierarchies WHERE child_id=OLD.id OR parent_id=OLD.id;
                UPDATE institutions SET parent_id=OLD.parent_id WHERE parent_id=OLD.id;
              ELSIF (TG_OP = 'UPDATE') THEN
                -- Rebuild the complete hierarchy, consider rebuilding partly when performance degrades
                DELETE FROM institution_hierarchies;
                WITH RECURSIVE institution_hierarchies_cte(child_id,parent_id) AS (
                  SELECT institutions.id, institutions.parent_id
                  FROM institutions WHERE  institutions.parent_id IS NOT NULL
                  UNION
                  SELECT institution_hierarchies_cte.child_id,  institutions.parent_id
                  FROM institution_hierarchies_cte JOIN institutions  ON institution_hierarchies_cte.parent_id = institutions.id
                  WHERE institutions.parent_id IS NOT NULL
                )  INSERT INTO institution_hierarchies (parent_id,child_id) SELECT institution_hierarchies_cte.parent_id,institution_hierarchies_cte.child_id FROM institution_hierarchies_cte;
              ELSIF (TG_OP = 'INSERT') THEN
                -- Rebuild the complete hierarchy, consider rebuilding partly when performance degrades
                DELETE FROM institution_hierarchies;
                WITH RECURSIVE institution_hierarchies_cte(child_id,parent_id) AS (
                  SELECT institutions.id, institutions.parent_id
                  FROM institutions WHERE  institutions.parent_id IS NOT NULL
                  UNION
                  SELECT institution_hierarchies_cte.child_id,  institutions.parent_id
                  FROM institution_hierarchies_cte JOIN institutions  ON institution_hierarchies_cte.parent_id = institutions.id
                  WHERE institutions.parent_id IS NOT NULL
                )  INSERT INTO institution_hierarchies (parent_id,child_id) SELECT institution_hierarchies_cte.parent_id,institution_hierarchies_cte.child_id FROM institution_hierarchies_cte;
              END IF;
              RETURN NULL;
          END;
      $$;


SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: queue_classic_jobs; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.queue_classic_jobs (
    id bigint NOT NULL,
    q_name text NOT NULL,
    method text NOT NULL,
    args json NOT NULL,
    locked_at timestamp with time zone,
    locked_by integer,
    created_at timestamp with time zone DEFAULT now(),
    scheduled_at timestamp with time zone DEFAULT now(),
    CONSTRAINT queue_classic_jobs_method_check CHECK ((length(method) > 0)),
    CONSTRAINT queue_classic_jobs_q_name_check CHECK ((length(q_name) > 0))
);


--
-- Name: lock_head(character varying); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION public.lock_head(tname character varying) RETURNS SETOF public.queue_classic_jobs
    LANGUAGE plpgsql
    AS $_$
BEGIN
  RETURN QUERY EXECUTE 'SELECT * FROM lock_head($1,10)' USING tname;
END;
$_$;


--
-- Name: lock_head(character varying, integer); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION public.lock_head(q_name character varying, top_boundary integer) RETURNS SETOF public.queue_classic_jobs
    LANGUAGE plpgsql
    AS $_$
DECLARE
  unlocked bigint;
  relative_top integer;
  job_count integer;
BEGIN
  -- The purpose is to release contention for the first spot in the table.
  -- The select count(*) is going to slow down dequeue performance but allow
  -- for more workers. Would love to see some optimization here...

  EXECUTE 'SELECT count(*) FROM '
    || '(SELECT * FROM queue_classic_jobs '
    || ' WHERE locked_at IS NULL'
    || ' AND q_name = '
    || quote_literal(q_name)
    || ' AND scheduled_at <= '
    || quote_literal(now())
    || ' LIMIT '
    || quote_literal(top_boundary)
    || ') limited'
  INTO job_count;

  SELECT TRUNC(random() * (top_boundary - 1))
  INTO relative_top;

  IF job_count < top_boundary THEN
    relative_top = 0;
  END IF;

  LOOP
    BEGIN
      EXECUTE 'SELECT id FROM queue_classic_jobs '
        || ' WHERE locked_at IS NULL'
        || ' AND q_name = '
        || quote_literal(q_name)
        || ' AND scheduled_at <= '
        || quote_literal(now())
        || ' ORDER BY id ASC'
        || ' LIMIT 1'
        || ' OFFSET ' || quote_literal(relative_top)
        || ' FOR UPDATE NOWAIT'
      INTO unlocked;
      EXIT;
    EXCEPTION
      WHEN lock_not_available THEN
        -- do nothing. loop again and hope we get a lock
    END;
  END LOOP;

  RETURN QUERY EXECUTE 'UPDATE queue_classic_jobs '
    || ' SET locked_at = (CURRENT_TIMESTAMP),'
    || ' locked_by = (select pg_backend_pid())'
    || ' WHERE id = $1'
    || ' AND locked_at is NULL'
    || ' RETURNING *'
  USING unlocked;

  RETURN;
END;
$_$;


--
-- Name: queue_classic_notify(); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION public.queue_classic_notify() RETURNS trigger
    LANGUAGE plpgsql
    AS $$ begin
  perform pg_notify(new.q_name, '');
  return null;
end $$;


--
-- Name: addresses; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.addresses (
    id integer NOT NULL,
    street character varying,
    city character varying,
    region character varying,
    zip character varying,
    country character varying,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    number character varying,
    latitude double precision,
    longitude double precision
);


--
-- Name: addresses_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.addresses_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: addresses_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.addresses_id_seq OWNED BY public.addresses.id;


--
-- Name: advancement_plan_borrows; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.advancement_plan_borrows (
    id integer NOT NULL,
    advancement_plan_id integer,
    teacher_id integer,
    institution_id integer,
    from_date date,
    to_date date,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    returned timestamp without time zone
);


--
-- Name: advancement_plan_borrows_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.advancement_plan_borrows_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: advancement_plan_borrows_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.advancement_plan_borrows_id_seq OWNED BY public.advancement_plan_borrows.id;


--
-- Name: advancement_plan_imgs; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.advancement_plan_imgs (
    id integer NOT NULL,
    name character varying NOT NULL,
    advancement_plan_id character varying NOT NULL,
    width_px integer NOT NULL,
    height_px integer NOT NULL,
    source_url character varying NOT NULL,
    file_type character varying NOT NULL,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    is_local boolean
);


--
-- Name: advancement_plan_imgs_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.advancement_plan_imgs_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: advancement_plan_imgs_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.advancement_plan_imgs_id_seq OWNED BY public.advancement_plan_imgs.id;


--
-- Name: advancement_plan_institution_stocks; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.advancement_plan_institution_stocks (
    id integer NOT NULL,
    advancement_plan_id integer,
    institution_id integer,
    stock integer,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL
);


--
-- Name: advancement_plan_institution_stocks_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.advancement_plan_institution_stocks_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: advancement_plan_institution_stocks_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.advancement_plan_institution_stocks_id_seq OWNED BY public.advancement_plan_institution_stocks.id;


--
-- Name: advancement_plans; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.advancement_plans (
    id integer NOT NULL,
    catalog_id character varying NOT NULL,
    title character varying NOT NULL,
    authors character varying,
    year character varying,
    subtitle character varying,
    abbreviation character varying,
    min_level integer,
    max_level integer,
    short_description text,
    description text,
    url character varying,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    age_from character varying,
    age_to character varying,
    no_image_url character varying,
    cover_image character varying
);


--
-- Name: advancement_plans_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.advancement_plans_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: advancement_plans_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.advancement_plans_id_seq OWNED BY public.advancement_plans.id;


--
-- Name: app_versions; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.app_versions (
    id integer NOT NULL,
    current_version character varying,
    next_version character varying,
    manual_update boolean DEFAULT false,
    auto_update boolean DEFAULT false,
    ensure_single_row integer DEFAULT 0
);


--
-- Name: app_versions_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.app_versions_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: app_versions_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.app_versions_id_seq OWNED BY public.app_versions.id;


--
-- Name: auth_items; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.auth_items (
    id integer NOT NULL,
    user_type character varying,
    type character varying,
    is_default_item boolean DEFAULT false,
    is_su_item boolean DEFAULT true
);


--
-- Name: auth_items_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.auth_items_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: auth_items_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.auth_items_id_seq OWNED BY public.auth_items.id;


--
-- Name: auth_items_roles; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.auth_items_roles (
    id integer NOT NULL,
    auth_item_id integer,
    auth_role_id integer
);


--
-- Name: auth_items_roles_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.auth_items_roles_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: auth_items_roles_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.auth_items_roles_id_seq OWNED BY public.auth_items_roles.id;


--
-- Name: auth_roles; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.auth_roles (
    id integer NOT NULL,
    name character varying,
    description character varying,
    user_type character varying,
    is_default_role boolean
);


--
-- Name: auth_roles_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.auth_roles_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: auth_roles_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.auth_roles_id_seq OWNED BY public.auth_roles.id;


--
-- Name: auth_roles_users; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.auth_roles_users (
    id integer NOT NULL,
    user_id integer,
    auth_role_id integer
);


--
-- Name: auth_roles_users_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.auth_roles_users_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: auth_roles_users_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.auth_roles_users_id_seq OWNED BY public.auth_roles_users.id;


--
-- Name: career_items; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.career_items (
    id integer NOT NULL,
    description text,
    start_at date NOT NULL,
    end_at date,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    client_id integer,
    teacher_id integer,
    client_group_id integer,
    change_type integer NOT NULL,
    portfolio_level integer,
    institution_id integer,
    teacher_name character varying,
    client_group_name character varying,
    institution_name character varying,
    effective_date date
);


--
-- Name: career_items_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.career_items_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: career_items_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.career_items_id_seq OWNED BY public.career_items.id;


--
-- Name: characteristics; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.characteristics (
    id integer NOT NULL,
    name character varying,
    is_positive boolean,
    diagnostic_id integer,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL
);


--
-- Name: characteristics_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.characteristics_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: characteristics_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.characteristics_id_seq OWNED BY public.characteristics.id;


--
-- Name: checklist_group_tpls; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.checklist_group_tpls (
    id integer NOT NULL,
    checklist_tpl_id integer NOT NULL,
    portfolio_specialization_id integer,
    is_mandatory boolean DEFAULT false NOT NULL,
    name character varying NOT NULL
);


--
-- Name: checklist_group_tpls_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.checklist_group_tpls_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: checklist_group_tpls_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.checklist_group_tpls_id_seq OWNED BY public.checklist_group_tpls.id;


--
-- Name: checklist_groups; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.checklist_groups (
    id integer NOT NULL,
    checklist_id integer NOT NULL,
    name character varying NOT NULL,
    is_mandatory boolean DEFAULT false NOT NULL,
    portfolio_specialization_id integer
);


--
-- Name: checklist_groups_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.checklist_groups_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: checklist_groups_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.checklist_groups_id_seq OWNED BY public.checklist_groups.id;


--
-- Name: checklist_question_tpls; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.checklist_question_tpls (
    id integer NOT NULL,
    name character varying NOT NULL,
    checklist_tpl_id integer NOT NULL,
    checklist_group_tpl_id integer NOT NULL,
    portfolio_specialization_id integer,
    is_checkable boolean NOT NULL,
    has_freetext boolean NOT NULL,
    has_portfolio_item_references boolean NOT NULL,
    is_mandatory boolean DEFAULT false NOT NULL,
    accepts_upload boolean DEFAULT false NOT NULL
);


--
-- Name: checklist_question_tpls_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.checklist_question_tpls_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: checklist_question_tpls_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.checklist_question_tpls_id_seq OWNED BY public.checklist_question_tpls.id;


--
-- Name: checklist_questions; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.checklist_questions (
    id integer NOT NULL,
    name character varying NOT NULL,
    checklist_id integer NOT NULL,
    portfolio_specialization_id integer,
    checklist_group_id integer,
    is_checkable boolean NOT NULL,
    has_freetext boolean NOT NULL,
    has_portfolio_item_references boolean NOT NULL,
    accepts_upload boolean NOT NULL,
    is_checked boolean,
    is_mandatory boolean NOT NULL,
    file character varying,
    freetext character varying
);


--
-- Name: checklist_questions_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.checklist_questions_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: checklist_questions_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.checklist_questions_id_seq OWNED BY public.checklist_questions.id;


--
-- Name: checklist_questions_portfolio_items; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.checklist_questions_portfolio_items (
    checklist_question_id integer NOT NULL,
    portfolio_item_id integer
);


--
-- Name: checklist_tpls; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.checklist_tpls (
    id integer NOT NULL,
    name character varying NOT NULL,
    checklist_type character varying NOT NULL,
    portfolio_specialization_id integer,
    is_active boolean DEFAULT true NOT NULL
);


--
-- Name: checklist_tpls_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.checklist_tpls_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: checklist_tpls_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.checklist_tpls_id_seq OWNED BY public.checklist_tpls.id;


--
-- Name: checklists; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.checklists (
    id integer NOT NULL,
    checklist_tpl_id integer,
    portfolio_item_id integer,
    teacher_id integer,
    manager_id integer,
    name character varying NOT NULL,
    checklist_type character varying,
    portfolio_specialization_id integer
);


--
-- Name: checklists_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.checklists_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: checklists_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.checklists_id_seq OWNED BY public.checklists.id;


--
-- Name: ckeditor_assets; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.ckeditor_assets (
    id integer NOT NULL,
    data_file_name character varying NOT NULL,
    data_content_type character varying,
    data_file_size integer,
    type character varying(30),
    width integer,
    height integer,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL
);


--
-- Name: ckeditor_assets_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.ckeditor_assets_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: ckeditor_assets_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.ckeditor_assets_id_seq OWNED BY public.ckeditor_assets.id;


--
-- Name: client_duplicate_detection_requests; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.client_duplicate_detection_requests (
    id integer NOT NULL,
    client_duplicate_request_id integer NOT NULL,
    vsb_id character varying NOT NULL,
    client_duplicate_detection_query_id integer NOT NULL,
    bday date NOT NULL,
    first_name character varying NOT NULL,
    last_name character varying NOT NULL,
    gender character varying NOT NULL,
    retry_count integer DEFAULT 0,
    result_code integer DEFAULT 0,
    announced_duplicate_count integer,
    announcement_result_code integer DEFAULT 0,
    created_at timestamp without time zone,
    updated_at timestamp without time zone
);


--
-- Name: client_duplicate_detection_requests_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.client_duplicate_detection_requests_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: client_duplicate_detection_requests_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.client_duplicate_detection_requests_id_seq OWNED BY public.client_duplicate_detection_requests.id;


--
-- Name: client_duplicate_detections; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.client_duplicate_detections (
    id integer NOT NULL,
    client_duplicate_detection_request_id integer NOT NULL,
    bday date NOT NULL,
    client_id integer,
    client_duplicate_request_id integer,
    duplicate_type character varying NOT NULL,
    first_name character varying NOT NULL,
    last_name character varying NOT NULL,
    gender character varying NOT NULL,
    institution_name character varying,
    client_group_name character varying,
    retry_count integer DEFAULT 0,
    result_code integer DEFAULT 0,
    created_at timestamp without time zone,
    updated_at timestamp without time zone
);


--
-- Name: client_duplicate_detections_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.client_duplicate_detections_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: client_duplicate_detections_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.client_duplicate_detections_id_seq OWNED BY public.client_duplicate_detections.id;


--
-- Name: client_duplicate_requests; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.client_duplicate_requests (
    id integer NOT NULL,
    first_name character varying NOT NULL,
    last_name character varying NOT NULL,
    bday date NOT NULL,
    gender character varying NOT NULL,
    request text NOT NULL,
    result_code integer DEFAULT 0 NOT NULL,
    retry_count integer DEFAULT 0 NOT NULL,
    client_duplicate_responses_count integer DEFAULT 0 NOT NULL,
    announced_client_duplicate_responses_count integer,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL
);


--
-- Name: client_duplicate_requests_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.client_duplicate_requests_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: client_duplicate_requests_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.client_duplicate_requests_id_seq OWNED BY public.client_duplicate_requests.id;


--
-- Name: client_duplicate_responses; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.client_duplicate_responses (
    id integer NOT NULL,
    client_duplicate_request_id integer,
    vsb_id character varying NOT NULL,
    first_name character varying NOT NULL,
    last_name character varying NOT NULL,
    bday date NOT NULL,
    gender character varying NOT NULL,
    institution_name character varying,
    client_group_name character varying,
    duplicate_type character varying NOT NULL,
    client_id integer
);


--
-- Name: client_duplicate_responses_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.client_duplicate_responses_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: client_duplicate_responses_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.client_duplicate_responses_id_seq OWNED BY public.client_duplicate_responses.id;


--
-- Name: client_educational_course_histories; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.client_educational_course_histories (
    id integer NOT NULL,
    client_id integer,
    course_stage_name character varying,
    duration_days integer,
    created_at timestamp without time zone,
    updated_at timestamp without time zone
);


--
-- Name: client_educational_course_histories_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.client_educational_course_histories_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: client_educational_course_histories_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.client_educational_course_histories_id_seq OWNED BY public.client_educational_course_histories.id;


--
-- Name: client_group_histories; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.client_group_histories (
    id integer NOT NULL,
    client_group_id integer,
    teacher_id integer,
    description text,
    start_date date,
    end_date date,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL
);


--
-- Name: client_group_histories_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.client_group_histories_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: client_group_histories_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.client_group_histories_id_seq OWNED BY public.client_group_histories.id;


--
-- Name: client_groups; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.client_groups (
    id integer NOT NULL,
    name character varying,
    description text,
    teacher_id integer,
    institution_id integer,
    clients_total integer,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    semester_id integer,
    special_education_hours integer DEFAULT 0,
    normal_education_hours integer DEFAULT 0,
    running_portfolio_id integer,
    portfolio_level integer DEFAULT 0,
    predecessor_client_group_id integer
);


--
-- Name: client_groups_educational_course_rules; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.client_groups_educational_course_rules (
    client_group_id integer,
    educational_course_rule_id integer
);


--
-- Name: client_groups_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.client_groups_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: client_groups_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.client_groups_id_seq OWNED BY public.client_groups.id;


--
-- Name: client_guardian_relations; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.client_guardian_relations (
    id integer NOT NULL,
    client_id integer,
    guardian_id integer,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    has_custody boolean,
    category integer
);


--
-- Name: client_guardian_relations_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.client_guardian_relations_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: client_guardian_relations_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.client_guardian_relations_id_seq OWNED BY public.client_guardian_relations.id;


--
-- Name: client_phonetics; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.client_phonetics (
    id integer NOT NULL,
    client_id integer,
    last_name_koelner_phonetic_hash character varying,
    last_name_double_metaphone_pri_hash character varying,
    last_name_double_metaphone_alt_hash character varying,
    first_name_koelner_phonetic_hash character varying,
    first_name_double_metaphone_pri_hash character varying,
    first_name_double_metaphone_alt_hash character varying
);


--
-- Name: client_phonetics_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.client_phonetics_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: client_phonetics_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.client_phonetics_id_seq OWNED BY public.client_phonetics.id;


--
-- Name: client_supporter_relations; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.client_supporter_relations (
    id integer NOT NULL,
    client_id integer,
    supporter_id integer,
    description text,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    author_id integer,
    author_type character varying,
    editor_id integer,
    editor_type character varying
);


--
-- Name: client_supporter_relations_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.client_supporter_relations_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: client_supporter_relations_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.client_supporter_relations_id_seq OWNED BY public.client_supporter_relations.id;


--
-- Name: clients; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.clients (
    id integer NOT NULL,
    first_name character varying,
    last_name character varying,
    gender integer,
    description text,
    bday date,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    deleted_at timestamp without time zone,
    birth_place character varying,
    nationality character varying,
    school_attendance_since date,
    school_attendance_since_article integer,
    school_attendance_postponed boolean,
    denomination character varying,
    language character varying,
    institution_id integer,
    teacher_id integer,
    client_group_id integer,
    portfolio_level integer DEFAULT 0 NOT NULL,
    full_name_search character varying,
    address_id integer,
    next_semester_client_group_id integer,
    client_duplicate_request_id integer,
    is_former_client boolean DEFAULT false,
    running_portfolio_id integer,
    client_group_last_change timestamp without time zone,
    initial_special_ed_necessary boolean DEFAULT false NOT NULL,
    expertise_manager_id integer,
    expertise_institution_id integer,
    expertise_teacher_id integer,
    expertise_school_inspector_id integer,
    expertise_teacher_result integer DEFAULT 0,
    expertise_institution_result integer DEFAULT 0,
    expertise_inspector_result integer DEFAULT 0,
    expertise_manager_result integer DEFAULT 0,
    expertise_teacher_result_text text,
    expertise_institution_result_text text,
    expertise_inspector_result_text text,
    expertise_manager_result_text text
);


--
-- Name: clients_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.clients_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: clients_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.clients_id_seq OWNED BY public.clients.id;


--
-- Name: diagnostic_borrows; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.diagnostic_borrows (
    id integer NOT NULL,
    diagnostic_id integer,
    teacher_id integer,
    institution_id integer,
    from_date date,
    to_date date,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    returned timestamp without time zone
);


--
-- Name: diagnostic_borrows_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.diagnostic_borrows_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: diagnostic_borrows_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.diagnostic_borrows_id_seq OWNED BY public.diagnostic_borrows.id;


--
-- Name: diagnostic_imgs; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.diagnostic_imgs (
    id integer NOT NULL,
    name character varying NOT NULL,
    diagnostic_id integer NOT NULL,
    width_px integer NOT NULL,
    height_px integer NOT NULL,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    source_url character varying NOT NULL,
    file_type character varying NOT NULL,
    is_local boolean
);


--
-- Name: diagnostic_imgs_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.diagnostic_imgs_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: diagnostic_imgs_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.diagnostic_imgs_id_seq OWNED BY public.diagnostic_imgs.id;


--
-- Name: diagnostic_institution_stocks; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.diagnostic_institution_stocks (
    id integer NOT NULL,
    diagnostic_id integer,
    institution_id integer,
    stock integer,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL
);


--
-- Name: diagnostic_institution_stocks_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.diagnostic_institution_stocks_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: diagnostic_institution_stocks_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.diagnostic_institution_stocks_id_seq OWNED BY public.diagnostic_institution_stocks.id;


--
-- Name: diagnostics; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.diagnostics (
    id integer NOT NULL,
    catalog_id character varying NOT NULL,
    title character varying NOT NULL,
    authors character varying,
    year character varying,
    subtitle character varying,
    abbreviation character varying,
    min_level integer,
    max_level integer,
    short_description text,
    description text,
    url character varying,
    is_range_okologie boolean NOT NULL,
    is_range_integration boolean NOT NULL,
    is_range_intensitat boolean NOT NULL,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    age_from character varying,
    age_to character varying,
    no_image_url character varying,
    cover_image character varying,
    diagnostic_type character varying
);


--
-- Name: diagnostics_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.diagnostics_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: diagnostics_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.diagnostics_id_seq OWNED BY public.diagnostics.id;


--
-- Name: diagnostics_portfolio_specializations; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.diagnostics_portfolio_specializations (
    diagnostic_id integer NOT NULL,
    portfolio_specialization_id integer NOT NULL
);


--
-- Name: documents; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.documents (
    id integer NOT NULL,
    category integer,
    file character varying,
    attachable_id integer,
    attachable_type character varying,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL
);


--
-- Name: documents_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.documents_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: documents_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.documents_id_seq OWNED BY public.documents.id;


--
-- Name: educational_course_rules; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.educational_course_rules (
    id integer NOT NULL,
    course_stage_name character varying,
    name character varying,
    min_duration_years integer,
    max_duration_years integer,
    educational_course_id character varying NOT NULL,
    created_at timestamp without time zone,
    updated_at timestamp without time zone
);


--
-- Name: educational_course_rules_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.educational_course_rules_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: educational_course_rules_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.educational_course_rules_id_seq OWNED BY public.educational_course_rules.id;


--
-- Name: educational_courses; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.educational_courses (
    id character varying NOT NULL,
    name character varying,
    valid_from date
);


--
-- Name: educational_courses_institutions; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.educational_courses_institutions (
    educational_course_id character varying NOT NULL,
    institution_id integer
);


--
-- Name: evaluation_involved_guardians; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.evaluation_involved_guardians (
    id integer NOT NULL,
    portfolio_item_evaluation_id integer NOT NULL,
    guardian_id integer NOT NULL
);


--
-- Name: evaluation_involved_guardians_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.evaluation_involved_guardians_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: evaluation_involved_guardians_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.evaluation_involved_guardians_id_seq OWNED BY public.evaluation_involved_guardians.id;


--
-- Name: evaluation_involved_persons; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.evaluation_involved_persons (
    id integer NOT NULL,
    name character varying NOT NULL,
    portfolio_item_evaluation_id integer NOT NULL
);


--
-- Name: evaluation_involved_persons_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.evaluation_involved_persons_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: evaluation_involved_persons_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.evaluation_involved_persons_id_seq OWNED BY public.evaluation_involved_persons.id;


--
-- Name: evaluation_involved_supporters; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.evaluation_involved_supporters (
    id integer NOT NULL,
    portfolio_item_evaluation_id integer NOT NULL,
    supporter_id integer NOT NULL
);


--
-- Name: evaluation_involved_supporters_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.evaluation_involved_supporters_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: evaluation_involved_supporters_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.evaluation_involved_supporters_id_seq OWNED BY public.evaluation_involved_supporters.id;


--
-- Name: evaluation_involved_teachers; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.evaluation_involved_teachers (
    id integer NOT NULL,
    portfolio_item_evaluation_id integer,
    teacher_id integer
);


--
-- Name: evaluation_involved_teachers_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.evaluation_involved_teachers_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: evaluation_involved_teachers_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.evaluation_involved_teachers_id_seq OWNED BY public.evaluation_involved_teachers.id;


--
-- Name: guardians; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.guardians (
    id integer NOT NULL,
    first_name character varying,
    last_name character varying,
    gender integer,
    email character varying,
    phone character varying,
    mobile character varying,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    address_id integer,
    first_name_phonetic_code character varying,
    last_name_phonetic_code character varying
);


--
-- Name: guardians_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.guardians_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: guardians_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.guardians_id_seq OWNED BY public.guardians.id;


--
-- Name: institution_categories; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.institution_categories (
    id integer NOT NULL,
    name character varying,
    description text,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    institution_type character varying,
    region character varying,
    vid character varying,
    normal_education_hours_weekly integer,
    special_education_hours_weekly integer,
    spare_hours_weekly integer,
    allocation_formula_special_ed_level_1 integer DEFAULT 0,
    allocation_formula_special_ed_level_2 integer DEFAULT 0,
    allocation_formula_special_ed_level_3 integer DEFAULT 0
);


--
-- Name: institution_categories_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.institution_categories_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: institution_categories_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.institution_categories_id_seq OWNED BY public.institution_categories.id;


--
-- Name: institution_document_hierarchies; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.institution_document_hierarchies (
    parent_id integer,
    child_id integer,
    level integer
);


--
-- Name: institution_documents; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.institution_documents (
    id integer NOT NULL,
    institution_id integer NOT NULL,
    file character varying,
    author_id integer NOT NULL,
    author_type character varying NOT NULL,
    description text,
    created_at timestamp without time zone,
    updated_at timestamp without time zone,
    parent_id integer,
    step_type character varying,
    step_type_description character varying
);


--
-- Name: institution_documents_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.institution_documents_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: institution_documents_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.institution_documents_id_seq OWNED BY public.institution_documents.id;


--
-- Name: institution_hierarchies; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.institution_hierarchies (
    id integer NOT NULL,
    parent_id integer,
    child_id integer
);


--
-- Name: institution_hierarchies_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.institution_hierarchies_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: institution_hierarchies_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.institution_hierarchies_id_seq OWNED BY public.institution_hierarchies.id;


--
-- Name: institutions; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.institutions (
    id integer NOT NULL,
    name character varying,
    school_no character varying,
    email character varying,
    fax character varying,
    website character varying,
    comment text,
    description text,
    institution_category_id integer,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    parent_id integer,
    address_id integer,
    phone character varying,
    is_root boolean,
    allocation_formula_special_ed_level_1 integer,
    allocation_formula_special_ed_level_2 integer,
    allocation_formula_special_ed_level_3 integer,
    institution_type character varying NOT NULL,
    logo character varying
);


--
-- Name: institutions_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.institutions_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: institutions_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.institutions_id_seq OWNED BY public.institutions.id;


--
-- Name: managers; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.managers (
    id integer NOT NULL,
    first_name character varying,
    last_name character varying,
    gender integer,
    email character varying,
    phone character varying,
    mobile character varying,
    fax character varying,
    website character varying,
    institution_id integer,
    can_log_in boolean DEFAULT true,
    is_school_inspector boolean DEFAULT false
);


--
-- Name: managers_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.managers_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: managers_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.managers_id_seq OWNED BY public.managers.id;


--
-- Name: norm_scales; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.norm_scales (
    id integer NOT NULL,
    name character varying,
    range_from double precision,
    range_to double precision,
    std_dev double precision,
    avg double precision,
    cut_off_low double precision,
    cut_off_sub_avg double precision,
    cut_off_above_avg double precision,
    cut_off_high double precision,
    catalog_fields character varying,
    diagnostic_id integer,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL
);


--
-- Name: norm_scales_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.norm_scales_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: norm_scales_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.norm_scales_id_seq OWNED BY public.norm_scales.id;


--
-- Name: notifications; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.notifications (
    id integer NOT NULL,
    content text,
    start_at timestamp without time zone,
    notificationable_id integer,
    notificationable_type character varying,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    prio integer,
    identifier character varying,
    due_at timestamp without time zone,
    deleted_at timestamp without time zone,
    institution_id integer,
    client_id integer,
    secondary_notificationable_id integer,
    secondary_notificationable_type character varying
);


--
-- Name: notifications_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.notifications_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: notifications_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.notifications_id_seq OWNED BY public.notifications.id;


--
-- Name: online_diagnostic_urls; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.online_diagnostic_urls (
    id integer NOT NULL,
    online_diagnostic_id character varying NOT NULL,
    name character varying,
    url character varying,
    created_at timestamp without time zone,
    updated_at timestamp without time zone
);


--
-- Name: online_diagnostic_urls_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.online_diagnostic_urls_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: online_diagnostic_urls_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.online_diagnostic_urls_id_seq OWNED BY public.online_diagnostic_urls.id;


--
-- Name: online_diagnostics; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.online_diagnostics (
    id character varying NOT NULL,
    title character varying,
    abbreviation character varying,
    min_level integer,
    max_level integer,
    description character varying,
    remote_id integer,
    age_from integer,
    age_to integer,
    created_at timestamp without time zone,
    updated_at timestamp without time zone
);


--
-- Name: portfolio_comments; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_comments (
    id integer NOT NULL,
    portfolio_item_id integer NOT NULL,
    comment text NOT NULL,
    file character varying,
    teacher_id integer,
    teacher_choose_reviewer boolean,
    teacher_perform_review boolean,
    item_blocked boolean,
    author_id integer,
    author_type character varying,
    created_at timestamp without time zone,
    updated_at timestamp without time zone
);


--
-- Name: portfolio_comments_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_comments_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_comments_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_comments_id_seq OWNED BY public.portfolio_comments.id;


--
-- Name: portfolio_conditions; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_conditions (
    id bigint NOT NULL,
    rule_id bigint,
    item_matchers text,
    actions text,
    exit_portfolio boolean,
    next_position integer,
    description character varying,
    title character varying,
    portfolio_matchers character varying,
    portfolio_rule_set_id character varying
);


--
-- Name: portfolio_conditions_steps; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_conditions_steps (
    id bigint NOT NULL,
    condition_id bigint,
    step_id bigint,
    portfolio_rule_set_id character varying
);


--
-- Name: portfolio_dbrcs; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_dbrcs (
    id integer NOT NULL,
    portfolio_item_id integer NOT NULL,
    client_id integer NOT NULL,
    questionnaire_id integer,
    questionnaire_result_id integer,
    data_points_per_day_print integer DEFAULT 1 NOT NULL,
    first_day_print date,
    saturday_print boolean DEFAULT true NOT NULL,
    sunday_print boolean DEFAULT false NOT NULL
);


--
-- Name: portfolio_dbrcs_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_dbrcs_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_dbrcs_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_dbrcs_id_seq OWNED BY public.portfolio_dbrcs.id;


--
-- Name: portfolio_document_types; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_document_types (
    id bigint NOT NULL,
    name character varying,
    created_at timestamp without time zone NOT NULL,
    title character varying,
    portfolio_rule_set_id character varying
);


--
-- Name: portfolio_documents; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_documents (
    id integer NOT NULL,
    portfolio_item_id integer,
    document_type character varying,
    file_name character varying,
    created_at timestamp without time zone,
    updated_at timestamp without time zone,
    portfolio_document_type_id bigint
);


--
-- Name: portfolio_documents_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_documents_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_documents_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_documents_id_seq OWNED BY public.portfolio_documents.id;


--
-- Name: portfolio_item_advancement_plans; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_advancement_plans (
    id integer NOT NULL,
    portfolio_item_id integer,
    advancement_plan_id integer,
    content text,
    begin date,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    advancement_plan_borrow_id integer
);


--
-- Name: portfolio_item_advancement_plans_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_advancement_plans_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_advancement_plans_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_advancement_plans_id_seq OWNED BY public.portfolio_item_advancement_plans.id;


--
-- Name: portfolio_item_class_diagnostics; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_class_diagnostics (
    id integer NOT NULL,
    begin date,
    content text,
    diagnostic_id character varying NOT NULL,
    portfolio_item_id integer,
    results_closed boolean DEFAULT false,
    age_from integer,
    age_to integer,
    created_at timestamp without time zone,
    updated_at timestamp without time zone
);


--
-- Name: portfolio_item_class_diagnostics_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_class_diagnostics_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_class_diagnostics_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_class_diagnostics_id_seq OWNED BY public.portfolio_item_class_diagnostics.id;


--
-- Name: portfolio_item_diagnostic_informal_result_documents; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_diagnostic_informal_result_documents (
    id integer NOT NULL,
    file_name character varying,
    portfolio_item_diagnostic_informal_result_id integer,
    created_at timestamp without time zone,
    updated_at timestamp without time zone
);


--
-- Name: portfolio_item_diagnostic_informal_result_documents_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_diagnostic_informal_result_documents_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_diagnostic_informal_result_documents_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_diagnostic_informal_result_documents_id_seq OWNED BY public.portfolio_item_diagnostic_informal_result_documents.id;


--
-- Name: portfolio_item_diagnostic_informal_result_guardians; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_diagnostic_informal_result_guardians (
    id integer NOT NULL,
    guardian_id integer,
    portfolio_item_diagnostic_informal_result_id integer
);


--
-- Name: portfolio_item_diagnostic_informal_result_guardians_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_diagnostic_informal_result_guardians_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_diagnostic_informal_result_guardians_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_diagnostic_informal_result_guardians_id_seq OWNED BY public.portfolio_item_diagnostic_informal_result_guardians.id;


--
-- Name: portfolio_item_diagnostic_informal_result_people; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_diagnostic_informal_result_people (
    id integer NOT NULL,
    name character varying,
    portfolio_item_diagnostic_informal_result_id integer
);


--
-- Name: portfolio_item_diagnostic_informal_result_people_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_diagnostic_informal_result_people_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_diagnostic_informal_result_people_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_diagnostic_informal_result_people_id_seq OWNED BY public.portfolio_item_diagnostic_informal_result_people.id;


--
-- Name: portfolio_item_diagnostic_informal_result_supporters; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_diagnostic_informal_result_supporters (
    id integer NOT NULL,
    supporter_id integer,
    portfolio_item_diagnostic_informal_result_id integer
);


--
-- Name: portfolio_item_diagnostic_informal_result_supporters_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_diagnostic_informal_result_supporters_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_diagnostic_informal_result_supporters_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_diagnostic_informal_result_supporters_id_seq OWNED BY public.portfolio_item_diagnostic_informal_result_supporters.id;


--
-- Name: portfolio_item_diagnostic_informal_result_teachers; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_diagnostic_informal_result_teachers (
    id integer NOT NULL,
    teacher_id integer,
    portfolio_item_diagnostic_informal_result_id integer
);


--
-- Name: portfolio_item_diagnostic_informal_result_teachers_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_diagnostic_informal_result_teachers_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_diagnostic_informal_result_teachers_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_diagnostic_informal_result_teachers_id_seq OWNED BY public.portfolio_item_diagnostic_informal_result_teachers.id;


--
-- Name: portfolio_item_diagnostic_informal_results; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_diagnostic_informal_results (
    id integer NOT NULL,
    result text,
    diagnostic_result_acceptor_id integer,
    diagnostic_result_acceptor_type character varying,
    subject_involved boolean,
    created_at timestamp without time zone,
    updated_at timestamp without time zone
);


--
-- Name: portfolio_item_diagnostic_informal_results_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_diagnostic_informal_results_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_diagnostic_informal_results_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_diagnostic_informal_results_id_seq OWNED BY public.portfolio_item_diagnostic_informal_results.id;


--
-- Name: portfolio_item_diagnostic_measurements; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_diagnostic_measurements (
    id integer NOT NULL,
    begin date,
    content text,
    portfolio_item_id integer,
    results_closed boolean DEFAULT false,
    created_at timestamp without time zone,
    updated_at timestamp without time zone
);


--
-- Name: portfolio_item_diagnostic_measurements_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_diagnostic_measurements_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_diagnostic_measurements_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_diagnostic_measurements_id_seq OWNED BY public.portfolio_item_diagnostic_measurements.id;


--
-- Name: portfolio_item_diagnostic_results; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_diagnostic_results (
    id integer NOT NULL,
    characteristic_id integer,
    norm_scale_id integer,
    result double precision,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    portfolio_item_diagnostic_informal_result_id integer
);


--
-- Name: portfolio_item_diagnostic_results_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_diagnostic_results_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_diagnostic_results_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_diagnostic_results_id_seq OWNED BY public.portfolio_item_diagnostic_results.id;


--
-- Name: portfolio_item_diagnostics; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_diagnostics (
    id integer NOT NULL,
    portfolio_item_id integer,
    diagnostic_id integer NOT NULL,
    begin date,
    content text,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    results_closed boolean DEFAULT false,
    diagnostic_borrow_id integer
);


--
-- Name: portfolio_item_diagnostics_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_diagnostics_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_diagnostics_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_diagnostics_id_seq OWNED BY public.portfolio_item_diagnostics.id;


--
-- Name: portfolio_item_evaluation_dbr_characteristics; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_evaluation_dbr_characteristics (
    id integer NOT NULL,
    portfolio_item_evaluation_dbr_id integer,
    name character varying,
    increase_is_positive boolean
);


--
-- Name: portfolio_item_evaluation_dbr_characteristics_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_evaluation_dbr_characteristics_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_evaluation_dbr_characteristics_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_evaluation_dbr_characteristics_id_seq OWNED BY public.portfolio_item_evaluation_dbr_characteristics.id;


--
-- Name: portfolio_item_evaluation_dbr_results; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_evaluation_dbr_results (
    id integer NOT NULL,
    portfolio_item_evaluation_dbr_id integer,
    portfolio_item_evaluation_dbr_characteristic_id integer,
    "time" timestamp without time zone,
    value double precision,
    line_idx integer DEFAULT 0
);


--
-- Name: portfolio_item_evaluation_dbr_results_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_evaluation_dbr_results_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_evaluation_dbr_results_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_evaluation_dbr_results_id_seq OWNED BY public.portfolio_item_evaluation_dbr_results.id;


--
-- Name: portfolio_item_evaluation_dbrs; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_evaluation_dbrs (
    id integer NOT NULL,
    range_begin integer,
    range_end integer,
    setting_social character varying,
    setting_time character varying,
    number_of_data_points integer,
    baselines_amount integer DEFAULT 0
);


--
-- Name: portfolio_item_evaluation_dbrs_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_evaluation_dbrs_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_evaluation_dbrs_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_evaluation_dbrs_id_seq OWNED BY public.portfolio_item_evaluation_dbrs.id;


--
-- Name: portfolio_item_evaluations; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_evaluations (
    id integer NOT NULL,
    additions text,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    end_date date NOT NULL,
    start_date date,
    result_scheme character varying DEFAULT 'Portfolio::ItemTargetResult::Binary'::character varying NOT NULL,
    client_involved boolean DEFAULT false NOT NULL,
    portfolio_item_target_id integer,
    portfolio_item_evaluation_dbr_id integer
);


--
-- Name: portfolio_item_evaluations_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_evaluations_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_evaluations_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_evaluations_id_seq OWNED BY public.portfolio_item_evaluations.id;


--
-- Name: portfolio_item_involved_guardians; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_involved_guardians (
    id integer NOT NULL,
    guardian_id integer NOT NULL,
    portfolio_item_id integer NOT NULL,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL
);


--
-- Name: portfolio_item_involved_guardians_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_involved_guardians_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_involved_guardians_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_involved_guardians_id_seq OWNED BY public.portfolio_item_involved_guardians.id;


--
-- Name: portfolio_item_involved_people; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_involved_people (
    id integer NOT NULL,
    name character varying NOT NULL,
    portfolio_item_id integer NOT NULL
);


--
-- Name: portfolio_item_involved_people_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_involved_people_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_involved_people_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_involved_people_id_seq OWNED BY public.portfolio_item_involved_people.id;


--
-- Name: portfolio_item_involved_supporters; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_involved_supporters (
    id integer NOT NULL,
    portfolio_item_id integer NOT NULL,
    supporter_id integer NOT NULL
);


--
-- Name: portfolio_item_involved_supporters_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_involved_supporters_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_involved_supporters_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_involved_supporters_id_seq OWNED BY public.portfolio_item_involved_supporters.id;


--
-- Name: portfolio_item_involved_teachers; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_involved_teachers (
    id integer NOT NULL,
    teacher_id integer NOT NULL,
    portfolio_item_id integer NOT NULL,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    class_teacher boolean DEFAULT false,
    management boolean DEFAULT false,
    special_ed boolean DEFAULT false,
    support_teacher boolean DEFAULT false
);


--
-- Name: portfolio_item_involved_teachers_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_involved_teachers_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_involved_teachers_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_involved_teachers_id_seq OWNED BY public.portfolio_item_involved_teachers.id;


--
-- Name: portfolio_item_measurements; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_measurements (
    id integer NOT NULL,
    portfolio_item_id integer NOT NULL,
    content text,
    begin date,
    created_at timestamp without time zone,
    updated_at timestamp without time zone
);


--
-- Name: portfolio_item_measurements_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_measurements_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_measurements_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_measurements_id_seq OWNED BY public.portfolio_item_measurements.id;


--
-- Name: portfolio_item_target_results; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_target_results (
    id integer NOT NULL,
    result_scheme character varying DEFAULT 'Portfolio::ItemTargetResult::Binary'::character varying NOT NULL,
    result_value integer,
    is_successful boolean DEFAULT false NOT NULL,
    result_comment text,
    portfolio_item_target_id integer NOT NULL,
    evaluative_id integer NOT NULL,
    evaluative_type character varying NOT NULL,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL
);


--
-- Name: portfolio_item_target_results_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_target_results_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_target_results_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_target_results_id_seq OWNED BY public.portfolio_item_target_results.id;


--
-- Name: portfolio_item_targets; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_item_targets (
    id integer NOT NULL,
    content text NOT NULL,
    result_comment text,
    is_successful boolean DEFAULT false NOT NULL,
    evaluate boolean DEFAULT false NOT NULL,
    portfolio_item_id integer NOT NULL,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    portfolio_dbrc_id integer,
    drc_item_id integer
);


--
-- Name: portfolio_item_targets_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_item_targets_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_item_targets_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_item_targets_id_seq OWNED BY public.portfolio_item_targets.id;


--
-- Name: portfolio_items; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_items (
    id integer NOT NULL,
    portfolio_step_id bigint NOT NULL,
    level integer DEFAULT 0 NOT NULL,
    portfolio_specialization_id integer,
    start date NOT NULL,
    content text,
    target_agreement text,
    parent_teacher_conference boolean DEFAULT false NOT NULL,
    management_conference boolean DEFAULT false NOT NULL,
    portfolio_step_result_id bigint,
    client_id integer,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    "position" integer,
    parent_teacher_conference_date date,
    management_conference_date date,
    raise_portfolio_level boolean DEFAULT false NOT NULL,
    client_involved boolean DEFAULT false NOT NULL,
    content_is_attached boolean DEFAULT false NOT NULL,
    new_portfolio_level integer,
    new_portfolio_level_date date,
    creator_involved boolean,
    author_id integer,
    author_type character varying,
    editor_id integer,
    editor_type character varying,
    closed boolean DEFAULT false,
    portfolio_id integer,
    discarded boolean DEFAULT false NOT NULL,
    is_range_okologie boolean DEFAULT false,
    is_range_integration boolean DEFAULT false,
    is_range_intensitaet boolean DEFAULT false,
    guardian_consent integer,
    guardian_consent_comment text,
    guardian_location_preference integer,
    guardian_location_preference_comment text
);


--
-- Name: portfolio_items_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_items_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_items_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_items_id_seq OWNED BY public.portfolio_items.id;


--
-- Name: portfolio_rule_steps; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_rule_steps (
    id bigint NOT NULL,
    rule_id bigint,
    step_id bigint,
    allowed boolean,
    portfolio_rule_set_id character varying
);


--
-- Name: portfolio_rules; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_rules (
    id bigint NOT NULL,
    "position" integer,
    time_span integer,
    level integer,
    description text,
    created_at timestamp without time zone NOT NULL,
    notifiers character varying,
    portfolio_rule_set_id character varying
);


--
-- Name: portfolio_specializations; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_specializations (
    id integer NOT NULL,
    name character varying,
    abbreviation character varying,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    specialization_type character varying
);


--
-- Name: portfolio_specializations_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolio_specializations_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolio_specializations_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolio_specializations_id_seq OWNED BY public.portfolio_specializations.id;


--
-- Name: portfolio_step_results; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_step_results (
    id bigint NOT NULL,
    name character varying,
    step_id bigint,
    created_at timestamp without time zone NOT NULL,
    "char" character varying,
    raises_level boolean,
    portfolio_rule_set_id character varying
);


--
-- Name: portfolio_steps; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_steps (
    id bigint NOT NULL,
    name character varying,
    optionals character varying,
    requirements character varying,
    evaluation_time_span_min integer,
    evaluation_time_span_max integer,
    description text,
    created_at timestamp without time zone NOT NULL,
    type character varying,
    portfolio_matchers character varying,
    requirements_description character varying,
    portfolio_rule_set_id character varying
);


--
-- Name: portfolio_template_documents; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolio_template_documents (
    id bigint NOT NULL,
    rule_id bigint,
    portfolio_rule_set_id character varying,
    url character varying,
    name character varying
);


--
-- Name: portfolios; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.portfolios (
    id integer NOT NULL,
    subject_id integer,
    subject_type character varying,
    rule_set_id character varying,
    portfolio_level integer,
    rule_set_date date,
    created_at timestamp without time zone,
    updated_at timestamp without time zone
);


--
-- Name: portfolios_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.portfolios_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: portfolios_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.portfolios_id_seq OWNED BY public.portfolios.id;


--
-- Name: questionnaire_results; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.questionnaire_results (
    id integer NOT NULL,
    result integer,
    questionnaire_id integer NOT NULL,
    question_order integer NOT NULL,
    question_id integer NOT NULL,
    group_id integer NOT NULL,
    created_at timestamp without time zone,
    updated_at timestamp without time zone
);


--
-- Name: questionnaire_results_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.questionnaire_results_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: questionnaire_results_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.questionnaire_results_id_seq OWNED BY public.questionnaire_results.id;


--
-- Name: questionnaires; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.questionnaires (
    id integer NOT NULL,
    type character varying NOT NULL,
    portfolio_item_id integer NOT NULL,
    teacher_id integer,
    client_id integer,
    guardian_id integer,
    supporter_id integer,
    person_name character varying,
    teacher_name character varying,
    client_name character varying,
    guardian_name character varying,
    supporter_name character varying,
    created_at timestamp without time zone,
    updated_at timestamp without time zone,
    client_mnemonic character varying,
    src_questionnaire_id integer
);


--
-- Name: questionnaires_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.questionnaires_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: questionnaires_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.questionnaires_id_seq OWNED BY public.questionnaires.id;


--
-- Name: queue_classic_jobs_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.queue_classic_jobs_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: queue_classic_jobs_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.queue_classic_jobs_id_seq OWNED BY public.queue_classic_jobs.id;


--
-- Name: schema_migrations; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.schema_migrations (
    version character varying NOT NULL
);


--
-- Name: school_stat_portfolio_items; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.school_stat_portfolio_items (
    id integer NOT NULL,
    school_stat_id integer NOT NULL,
    subject_type character varying NOT NULL,
    type character varying NOT NULL,
    total integer NOT NULL,
    avg double precision NOT NULL,
    created_at timestamp without time zone,
    updated_at timestamp without time zone,
    from_twms_total integer,
    from_twms_avg double precision
);


--
-- Name: school_stat_portfolio_items_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.school_stat_portfolio_items_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: school_stat_portfolio_items_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.school_stat_portfolio_items_id_seq OWNED BY public.school_stat_portfolio_items.id;


--
-- Name: school_stats; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.school_stats (
    id integer NOT NULL,
    institution_id integer NOT NULL,
    month integer NOT NULL,
    year integer NOT NULL,
    teachers_total integer NOT NULL,
    client_groups_total integer NOT NULL,
    clients_total integer NOT NULL,
    clients_fs_0 integer NOT NULL,
    clients_fs_1 integer NOT NULL,
    clients_fs_2 integer NOT NULL,
    clients_fs_3 integer NOT NULL,
    created_at timestamp without time zone,
    updated_at timestamp without time zone
);


--
-- Name: school_stats_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.school_stats_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: school_stats_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.school_stats_id_seq OWNED BY public.school_stats.id;


--
-- Name: semesters; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.semesters (
    id integer NOT NULL,
    name character varying,
    lessons_start date,
    lessons_end date,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    lessons_half date,
    start date,
    finish date,
    csb_updated_at timestamp without time zone,
    csb_id integer
);


--
-- Name: semesters_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.semesters_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: semesters_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.semesters_id_seq OWNED BY public.semesters.id;


--
-- Name: supporters; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.supporters (
    id integer NOT NULL,
    first_name character varying,
    last_name character varying,
    gender integer,
    email character varying,
    phone character varying,
    mobile character varying,
    description text,
    institution_id integer,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    title integer,
    "position" character varying,
    fax character varying
);


--
-- Name: supporters_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.supporters_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: supporters_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.supporters_id_seq OWNED BY public.supporters.id;


--
-- Name: system_settings; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.system_settings (
    id integer NOT NULL,
    region character varying,
    name character varying,
    semester_id integer,
    setup_finished boolean DEFAULT false,
    version character varying,
    upgrade_auto boolean DEFAULT false,
    upgrade_to character varying,
    upgrade_lock boolean DEFAULT false
);


--
-- Name: system_settings_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.system_settings_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: system_settings_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.system_settings_id_seq OWNED BY public.system_settings.id;


--
-- Name: system_tasks; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.system_tasks (
    id integer NOT NULL,
    target_id integer,
    target_type character varying,
    client_id integer,
    institution_id integer,
    escalation_level integer,
    next_escalation timestamp without time zone,
    escalation_delay integer,
    type character varying,
    title character varying,
    message character varying,
    label character varying,
    start_at timestamp without time zone,
    due_at timestamp without time zone,
    resolve_location character varying
);


--
-- Name: system_tasks_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.system_tasks_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: system_tasks_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.system_tasks_id_seq OWNED BY public.system_tasks.id;


--
-- Name: teacher_categories; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.teacher_categories (
    id integer NOT NULL,
    name character varying,
    description text,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    is_special_ed boolean DEFAULT false NOT NULL,
    is_support_teacher boolean DEFAULT false NOT NULL
);


--
-- Name: teacher_categories_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.teacher_categories_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: teacher_categories_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.teacher_categories_id_seq OWNED BY public.teacher_categories.id;


--
-- Name: teacher_institution_categories; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.teacher_institution_categories (
    id integer NOT NULL,
    name character varying NOT NULL,
    description character varying,
    is_management boolean DEFAULT false NOT NULL
);


--
-- Name: teacher_institution_categories_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.teacher_institution_categories_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: teacher_institution_categories_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.teacher_institution_categories_id_seq OWNED BY public.teacher_institution_categories.id;


--
-- Name: teacher_institution_relations; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.teacher_institution_relations (
    id integer NOT NULL,
    teacher_id integer,
    institution_id integer,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    special_education_part_time integer,
    normal_education_part_time integer,
    teacher_institution_category_id integer,
    portfolio_specialization_id integer,
    spare_time integer DEFAULT 0,
    is_school_admin boolean DEFAULT false NOT NULL
);


--
-- Name: teacher_institution_relations_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.teacher_institution_relations_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: teacher_institution_relations_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.teacher_institution_relations_id_seq OWNED BY public.teacher_institution_relations.id;


--
-- Name: teachers; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.teachers (
    id integer NOT NULL,
    first_name character varying,
    last_name character varying,
    gender integer,
    email character varying,
    phone character varying,
    mobile character varying,
    fax character varying,
    website character varying,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    teacher_category_id integer,
    deleted_at timestamp without time zone,
    can_log_in boolean DEFAULT true
);


--
-- Name: teachers_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.teachers_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: teachers_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.teachers_id_seq OWNED BY public.teachers.id;


--
-- Name: user_messages; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.user_messages (
    id integer NOT NULL,
    recipient_id integer,
    recipient_type character varying,
    sender_id integer,
    sender_type character varying,
    system_task_id integer,
    message_box integer,
    message_type integer,
    subject_text character varying,
    content text,
    prio integer,
    due_at timestamp without time zone,
    created_at timestamp without time zone,
    updated_at timestamp without time zone
);


--
-- Name: user_messages_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.user_messages_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: user_messages_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.user_messages_id_seq OWNED BY public.user_messages.id;


--
-- Name: users; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.users (
    id integer NOT NULL,
    email character varying DEFAULT ''::character varying NOT NULL,
    encrypted_password character varying DEFAULT ''::character varying NOT NULL,
    reset_password_token character varying,
    reset_password_sent_at timestamp without time zone,
    remember_created_at timestamp without time zone,
    sign_in_count integer DEFAULT 0 NOT NULL,
    current_sign_in_at timestamp without time zone,
    last_sign_in_at timestamp without time zone,
    current_sign_in_ip inet,
    last_sign_in_ip inet,
    created_at timestamp without time zone NOT NULL,
    updated_at timestamp without time zone NOT NULL,
    super_admin boolean DEFAULT false,
    dev boolean DEFAULT false,
    identifiable_id integer,
    identifiable_type character varying,
    username character varying
);


--
-- Name: users_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.users_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: users_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.users_id_seq OWNED BY public.users.id;


--
-- Name: addresses id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.addresses ALTER COLUMN id SET DEFAULT nextval('public.addresses_id_seq'::regclass);


--
-- Name: advancement_plan_borrows id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.advancement_plan_borrows ALTER COLUMN id SET DEFAULT nextval('public.advancement_plan_borrows_id_seq'::regclass);


--
-- Name: advancement_plan_imgs id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.advancement_plan_imgs ALTER COLUMN id SET DEFAULT nextval('public.advancement_plan_imgs_id_seq'::regclass);


--
-- Name: advancement_plan_institution_stocks id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.advancement_plan_institution_stocks ALTER COLUMN id SET DEFAULT nextval('public.advancement_plan_institution_stocks_id_seq'::regclass);


--
-- Name: advancement_plans id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.advancement_plans ALTER COLUMN id SET DEFAULT nextval('public.advancement_plans_id_seq'::regclass);


--
-- Name: app_versions id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.app_versions ALTER COLUMN id SET DEFAULT nextval('public.app_versions_id_seq'::regclass);


--
-- Name: auth_items id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.auth_items ALTER COLUMN id SET DEFAULT nextval('public.auth_items_id_seq'::regclass);


--
-- Name: auth_items_roles id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.auth_items_roles ALTER COLUMN id SET DEFAULT nextval('public.auth_items_roles_id_seq'::regclass);


--
-- Name: auth_roles id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.auth_roles ALTER COLUMN id SET DEFAULT nextval('public.auth_roles_id_seq'::regclass);


--
-- Name: auth_roles_users id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.auth_roles_users ALTER COLUMN id SET DEFAULT nextval('public.auth_roles_users_id_seq'::regclass);


--
-- Name: career_items id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.career_items ALTER COLUMN id SET DEFAULT nextval('public.career_items_id_seq'::regclass);


--
-- Name: characteristics id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.characteristics ALTER COLUMN id SET DEFAULT nextval('public.characteristics_id_seq'::regclass);


--
-- Name: checklist_group_tpls id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_group_tpls ALTER COLUMN id SET DEFAULT nextval('public.checklist_group_tpls_id_seq'::regclass);


--
-- Name: checklist_groups id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_groups ALTER COLUMN id SET DEFAULT nextval('public.checklist_groups_id_seq'::regclass);


--
-- Name: checklist_question_tpls id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_question_tpls ALTER COLUMN id SET DEFAULT nextval('public.checklist_question_tpls_id_seq'::regclass);


--
-- Name: checklist_questions id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_questions ALTER COLUMN id SET DEFAULT nextval('public.checklist_questions_id_seq'::regclass);


--
-- Name: checklist_tpls id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_tpls ALTER COLUMN id SET DEFAULT nextval('public.checklist_tpls_id_seq'::regclass);


--
-- Name: checklists id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklists ALTER COLUMN id SET DEFAULT nextval('public.checklists_id_seq'::regclass);


--
-- Name: ckeditor_assets id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.ckeditor_assets ALTER COLUMN id SET DEFAULT nextval('public.ckeditor_assets_id_seq'::regclass);


--
-- Name: client_duplicate_detection_requests id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_duplicate_detection_requests ALTER COLUMN id SET DEFAULT nextval('public.client_duplicate_detection_requests_id_seq'::regclass);


--
-- Name: client_duplicate_detections id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_duplicate_detections ALTER COLUMN id SET DEFAULT nextval('public.client_duplicate_detections_id_seq'::regclass);


--
-- Name: client_duplicate_requests id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_duplicate_requests ALTER COLUMN id SET DEFAULT nextval('public.client_duplicate_requests_id_seq'::regclass);


--
-- Name: client_duplicate_responses id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_duplicate_responses ALTER COLUMN id SET DEFAULT nextval('public.client_duplicate_responses_id_seq'::regclass);


--
-- Name: client_educational_course_histories id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_educational_course_histories ALTER COLUMN id SET DEFAULT nextval('public.client_educational_course_histories_id_seq'::regclass);


--
-- Name: client_group_histories id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_group_histories ALTER COLUMN id SET DEFAULT nextval('public.client_group_histories_id_seq'::regclass);


--
-- Name: client_groups id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_groups ALTER COLUMN id SET DEFAULT nextval('public.client_groups_id_seq'::regclass);


--
-- Name: client_guardian_relations id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_guardian_relations ALTER COLUMN id SET DEFAULT nextval('public.client_guardian_relations_id_seq'::regclass);


--
-- Name: client_phonetics id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_phonetics ALTER COLUMN id SET DEFAULT nextval('public.client_phonetics_id_seq'::regclass);


--
-- Name: client_supporter_relations id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_supporter_relations ALTER COLUMN id SET DEFAULT nextval('public.client_supporter_relations_id_seq'::regclass);


--
-- Name: clients id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.clients ALTER COLUMN id SET DEFAULT nextval('public.clients_id_seq'::regclass);


--
-- Name: diagnostic_borrows id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.diagnostic_borrows ALTER COLUMN id SET DEFAULT nextval('public.diagnostic_borrows_id_seq'::regclass);


--
-- Name: diagnostic_imgs id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.diagnostic_imgs ALTER COLUMN id SET DEFAULT nextval('public.diagnostic_imgs_id_seq'::regclass);


--
-- Name: diagnostic_institution_stocks id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.diagnostic_institution_stocks ALTER COLUMN id SET DEFAULT nextval('public.diagnostic_institution_stocks_id_seq'::regclass);


--
-- Name: diagnostics id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.diagnostics ALTER COLUMN id SET DEFAULT nextval('public.diagnostics_id_seq'::regclass);


--
-- Name: documents id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.documents ALTER COLUMN id SET DEFAULT nextval('public.documents_id_seq'::regclass);


--
-- Name: educational_course_rules id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.educational_course_rules ALTER COLUMN id SET DEFAULT nextval('public.educational_course_rules_id_seq'::regclass);


--
-- Name: evaluation_involved_guardians id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.evaluation_involved_guardians ALTER COLUMN id SET DEFAULT nextval('public.evaluation_involved_guardians_id_seq'::regclass);


--
-- Name: evaluation_involved_persons id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.evaluation_involved_persons ALTER COLUMN id SET DEFAULT nextval('public.evaluation_involved_persons_id_seq'::regclass);


--
-- Name: evaluation_involved_supporters id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.evaluation_involved_supporters ALTER COLUMN id SET DEFAULT nextval('public.evaluation_involved_supporters_id_seq'::regclass);


--
-- Name: evaluation_involved_teachers id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.evaluation_involved_teachers ALTER COLUMN id SET DEFAULT nextval('public.evaluation_involved_teachers_id_seq'::regclass);


--
-- Name: guardians id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.guardians ALTER COLUMN id SET DEFAULT nextval('public.guardians_id_seq'::regclass);


--
-- Name: institution_categories id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.institution_categories ALTER COLUMN id SET DEFAULT nextval('public.institution_categories_id_seq'::regclass);


--
-- Name: institution_documents id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.institution_documents ALTER COLUMN id SET DEFAULT nextval('public.institution_documents_id_seq'::regclass);


--
-- Name: institution_hierarchies id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.institution_hierarchies ALTER COLUMN id SET DEFAULT nextval('public.institution_hierarchies_id_seq'::regclass);


--
-- Name: institutions id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.institutions ALTER COLUMN id SET DEFAULT nextval('public.institutions_id_seq'::regclass);


--
-- Name: managers id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.managers ALTER COLUMN id SET DEFAULT nextval('public.managers_id_seq'::regclass);


--
-- Name: norm_scales id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.norm_scales ALTER COLUMN id SET DEFAULT nextval('public.norm_scales_id_seq'::regclass);


--
-- Name: notifications id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.notifications ALTER COLUMN id SET DEFAULT nextval('public.notifications_id_seq'::regclass);


--
-- Name: online_diagnostic_urls id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.online_diagnostic_urls ALTER COLUMN id SET DEFAULT nextval('public.online_diagnostic_urls_id_seq'::regclass);


--
-- Name: portfolio_comments id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_comments ALTER COLUMN id SET DEFAULT nextval('public.portfolio_comments_id_seq'::regclass);


--
-- Name: portfolio_dbrcs id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_dbrcs ALTER COLUMN id SET DEFAULT nextval('public.portfolio_dbrcs_id_seq'::regclass);


--
-- Name: portfolio_documents id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_documents ALTER COLUMN id SET DEFAULT nextval('public.portfolio_documents_id_seq'::regclass);


--
-- Name: portfolio_item_advancement_plans id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_advancement_plans ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_advancement_plans_id_seq'::regclass);


--
-- Name: portfolio_item_class_diagnostics id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_class_diagnostics ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_class_diagnostics_id_seq'::regclass);


--
-- Name: portfolio_item_diagnostic_informal_result_documents id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostic_informal_result_documents ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_diagnostic_informal_result_documents_id_seq'::regclass);


--
-- Name: portfolio_item_diagnostic_informal_result_guardians id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostic_informal_result_guardians ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_diagnostic_informal_result_guardians_id_seq'::regclass);


--
-- Name: portfolio_item_diagnostic_informal_result_people id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostic_informal_result_people ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_diagnostic_informal_result_people_id_seq'::regclass);


--
-- Name: portfolio_item_diagnostic_informal_result_supporters id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostic_informal_result_supporters ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_diagnostic_informal_result_supporters_id_seq'::regclass);


--
-- Name: portfolio_item_diagnostic_informal_result_teachers id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostic_informal_result_teachers ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_diagnostic_informal_result_teachers_id_seq'::regclass);


--
-- Name: portfolio_item_diagnostic_informal_results id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostic_informal_results ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_diagnostic_informal_results_id_seq'::regclass);


--
-- Name: portfolio_item_diagnostic_measurements id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostic_measurements ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_diagnostic_measurements_id_seq'::regclass);


--
-- Name: portfolio_item_diagnostic_results id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostic_results ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_diagnostic_results_id_seq'::regclass);


--
-- Name: portfolio_item_diagnostics id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostics ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_diagnostics_id_seq'::regclass);


--
-- Name: portfolio_item_evaluation_dbr_characteristics id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_evaluation_dbr_characteristics ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_evaluation_dbr_characteristics_id_seq'::regclass);


--
-- Name: portfolio_item_evaluation_dbr_results id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_evaluation_dbr_results ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_evaluation_dbr_results_id_seq'::regclass);


--
-- Name: portfolio_item_evaluation_dbrs id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_evaluation_dbrs ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_evaluation_dbrs_id_seq'::regclass);


--
-- Name: portfolio_item_evaluations id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_evaluations ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_evaluations_id_seq'::regclass);


--
-- Name: portfolio_item_involved_guardians id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_involved_guardians ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_involved_guardians_id_seq'::regclass);


--
-- Name: portfolio_item_involved_people id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_involved_people ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_involved_people_id_seq'::regclass);


--
-- Name: portfolio_item_involved_supporters id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_involved_supporters ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_involved_supporters_id_seq'::regclass);


--
-- Name: portfolio_item_involved_teachers id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_involved_teachers ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_involved_teachers_id_seq'::regclass);


--
-- Name: portfolio_item_measurements id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_measurements ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_measurements_id_seq'::regclass);


--
-- Name: portfolio_item_target_results id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_target_results ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_target_results_id_seq'::regclass);


--
-- Name: portfolio_item_targets id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_targets ALTER COLUMN id SET DEFAULT nextval('public.portfolio_item_targets_id_seq'::regclass);


--
-- Name: portfolio_items id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_items ALTER COLUMN id SET DEFAULT nextval('public.portfolio_items_id_seq'::regclass);


--
-- Name: portfolio_specializations id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_specializations ALTER COLUMN id SET DEFAULT nextval('public.portfolio_specializations_id_seq'::regclass);


--
-- Name: portfolios id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolios ALTER COLUMN id SET DEFAULT nextval('public.portfolios_id_seq'::regclass);


--
-- Name: questionnaire_results id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.questionnaire_results ALTER COLUMN id SET DEFAULT nextval('public.questionnaire_results_id_seq'::regclass);


--
-- Name: questionnaires id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.questionnaires ALTER COLUMN id SET DEFAULT nextval('public.questionnaires_id_seq'::regclass);


--
-- Name: queue_classic_jobs id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.queue_classic_jobs ALTER COLUMN id SET DEFAULT nextval('public.queue_classic_jobs_id_seq'::regclass);


--
-- Name: school_stat_portfolio_items id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.school_stat_portfolio_items ALTER COLUMN id SET DEFAULT nextval('public.school_stat_portfolio_items_id_seq'::regclass);


--
-- Name: school_stats id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.school_stats ALTER COLUMN id SET DEFAULT nextval('public.school_stats_id_seq'::regclass);


--
-- Name: semesters id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.semesters ALTER COLUMN id SET DEFAULT nextval('public.semesters_id_seq'::regclass);


--
-- Name: supporters id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.supporters ALTER COLUMN id SET DEFAULT nextval('public.supporters_id_seq'::regclass);


--
-- Name: system_settings id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.system_settings ALTER COLUMN id SET DEFAULT nextval('public.system_settings_id_seq'::regclass);


--
-- Name: system_tasks id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.system_tasks ALTER COLUMN id SET DEFAULT nextval('public.system_tasks_id_seq'::regclass);


--
-- Name: teacher_categories id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.teacher_categories ALTER COLUMN id SET DEFAULT nextval('public.teacher_categories_id_seq'::regclass);


--
-- Name: teacher_institution_categories id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.teacher_institution_categories ALTER COLUMN id SET DEFAULT nextval('public.teacher_institution_categories_id_seq'::regclass);


--
-- Name: teacher_institution_relations id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.teacher_institution_relations ALTER COLUMN id SET DEFAULT nextval('public.teacher_institution_relations_id_seq'::regclass);


--
-- Name: teachers id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.teachers ALTER COLUMN id SET DEFAULT nextval('public.teachers_id_seq'::regclass);


--
-- Name: user_messages id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.user_messages ALTER COLUMN id SET DEFAULT nextval('public.user_messages_id_seq'::regclass);


--
-- Name: users id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.users ALTER COLUMN id SET DEFAULT nextval('public.users_id_seq'::regclass);


--
-- Name: addresses addresses_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.addresses
    ADD CONSTRAINT addresses_pkey PRIMARY KEY (id);


--
-- Name: advancement_plan_borrows advancement_plan_borrows_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.advancement_plan_borrows
    ADD CONSTRAINT advancement_plan_borrows_pkey PRIMARY KEY (id);


--
-- Name: advancement_plan_imgs advancement_plan_imgs_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.advancement_plan_imgs
    ADD CONSTRAINT advancement_plan_imgs_pkey PRIMARY KEY (id);


--
-- Name: advancement_plan_institution_stocks advancement_plan_institution_stocks_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.advancement_plan_institution_stocks
    ADD CONSTRAINT advancement_plan_institution_stocks_pkey PRIMARY KEY (id);


--
-- Name: advancement_plans advancement_plans_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.advancement_plans
    ADD CONSTRAINT advancement_plans_pkey PRIMARY KEY (id);


--
-- Name: app_versions app_versions_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.app_versions
    ADD CONSTRAINT app_versions_pkey PRIMARY KEY (id);


--
-- Name: auth_items auth_items_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.auth_items
    ADD CONSTRAINT auth_items_pkey PRIMARY KEY (id);


--
-- Name: auth_items_roles auth_items_roles_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.auth_items_roles
    ADD CONSTRAINT auth_items_roles_pkey PRIMARY KEY (id);


--
-- Name: auth_roles auth_roles_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.auth_roles
    ADD CONSTRAINT auth_roles_pkey PRIMARY KEY (id);


--
-- Name: auth_roles_users auth_roles_users_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.auth_roles_users
    ADD CONSTRAINT auth_roles_users_pkey PRIMARY KEY (id);


--
-- Name: career_items career_items_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.career_items
    ADD CONSTRAINT career_items_pkey PRIMARY KEY (id);


--
-- Name: characteristics characteristics_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.characteristics
    ADD CONSTRAINT characteristics_pkey PRIMARY KEY (id);


--
-- Name: checklist_group_tpls checklist_group_tpls_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_group_tpls
    ADD CONSTRAINT checklist_group_tpls_pkey PRIMARY KEY (id);


--
-- Name: checklist_groups checklist_groups_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_groups
    ADD CONSTRAINT checklist_groups_pkey PRIMARY KEY (id);


--
-- Name: checklist_question_tpls checklist_question_tpls_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_question_tpls
    ADD CONSTRAINT checklist_question_tpls_pkey PRIMARY KEY (id);


--
-- Name: checklist_questions checklist_questions_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_questions
    ADD CONSTRAINT checklist_questions_pkey PRIMARY KEY (id);


--
-- Name: checklist_tpls checklist_tpls_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_tpls
    ADD CONSTRAINT checklist_tpls_pkey PRIMARY KEY (id);


--
-- Name: checklists checklists_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklists
    ADD CONSTRAINT checklists_pkey PRIMARY KEY (id);


--
-- Name: ckeditor_assets ckeditor_assets_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.ckeditor_assets
    ADD CONSTRAINT ckeditor_assets_pkey PRIMARY KEY (id);


--
-- Name: client_duplicate_detection_requests client_duplicate_detection_requests_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_duplicate_detection_requests
    ADD CONSTRAINT client_duplicate_detection_requests_pkey PRIMARY KEY (id);


--
-- Name: client_duplicate_detections client_duplicate_detections_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_duplicate_detections
    ADD CONSTRAINT client_duplicate_detections_pkey PRIMARY KEY (id);


--
-- Name: client_duplicate_requests client_duplicate_requests_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_duplicate_requests
    ADD CONSTRAINT client_duplicate_requests_pkey PRIMARY KEY (id);


--
-- Name: client_duplicate_responses client_duplicate_responses_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_duplicate_responses
    ADD CONSTRAINT client_duplicate_responses_pkey PRIMARY KEY (id);


--
-- Name: client_educational_course_histories client_educational_course_histories_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_educational_course_histories
    ADD CONSTRAINT client_educational_course_histories_pkey PRIMARY KEY (id);


--
-- Name: client_group_histories client_group_histories_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_group_histories
    ADD CONSTRAINT client_group_histories_pkey PRIMARY KEY (id);


--
-- Name: client_groups client_groups_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_groups
    ADD CONSTRAINT client_groups_pkey PRIMARY KEY (id);


--
-- Name: client_guardian_relations client_guardian_relations_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_guardian_relations
    ADD CONSTRAINT client_guardian_relations_pkey PRIMARY KEY (id);


--
-- Name: client_phonetics client_phonetics_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_phonetics
    ADD CONSTRAINT client_phonetics_pkey PRIMARY KEY (id);


--
-- Name: client_supporter_relations client_supporter_relations_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_supporter_relations
    ADD CONSTRAINT client_supporter_relations_pkey PRIMARY KEY (id);


--
-- Name: clients clients_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.clients
    ADD CONSTRAINT clients_pkey PRIMARY KEY (id);


--
-- Name: diagnostic_borrows diagnostic_borrows_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.diagnostic_borrows
    ADD CONSTRAINT diagnostic_borrows_pkey PRIMARY KEY (id);


--
-- Name: diagnostic_imgs diagnostic_imgs_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.diagnostic_imgs
    ADD CONSTRAINT diagnostic_imgs_pkey PRIMARY KEY (id);


--
-- Name: diagnostic_institution_stocks diagnostic_institution_stocks_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.diagnostic_institution_stocks
    ADD CONSTRAINT diagnostic_institution_stocks_pkey PRIMARY KEY (id);


--
-- Name: diagnostics diagnostics_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.diagnostics
    ADD CONSTRAINT diagnostics_pkey PRIMARY KEY (id);


--
-- Name: documents documents_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.documents
    ADD CONSTRAINT documents_pkey PRIMARY KEY (id);


--
-- Name: educational_course_rules educational_course_rules_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.educational_course_rules
    ADD CONSTRAINT educational_course_rules_pkey PRIMARY KEY (id);


--
-- Name: educational_courses educational_courses_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.educational_courses
    ADD CONSTRAINT educational_courses_pkey PRIMARY KEY (id);


--
-- Name: evaluation_involved_guardians evaluation_involved_guardians_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.evaluation_involved_guardians
    ADD CONSTRAINT evaluation_involved_guardians_pkey PRIMARY KEY (id);


--
-- Name: evaluation_involved_persons evaluation_involved_persons_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.evaluation_involved_persons
    ADD CONSTRAINT evaluation_involved_persons_pkey PRIMARY KEY (id);


--
-- Name: evaluation_involved_supporters evaluation_involved_supporters_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.evaluation_involved_supporters
    ADD CONSTRAINT evaluation_involved_supporters_pkey PRIMARY KEY (id);


--
-- Name: evaluation_involved_teachers evaluation_involved_teachers_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.evaluation_involved_teachers
    ADD CONSTRAINT evaluation_involved_teachers_pkey PRIMARY KEY (id);


--
-- Name: guardians guardians_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.guardians
    ADD CONSTRAINT guardians_pkey PRIMARY KEY (id);


--
-- Name: institution_categories institution_categories_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.institution_categories
    ADD CONSTRAINT institution_categories_pkey PRIMARY KEY (id);


--
-- Name: institution_documents institution_documents_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.institution_documents
    ADD CONSTRAINT institution_documents_pkey PRIMARY KEY (id);


--
-- Name: institution_hierarchies institution_hierarchies_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.institution_hierarchies
    ADD CONSTRAINT institution_hierarchies_pkey PRIMARY KEY (id);


--
-- Name: institutions institutions_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.institutions
    ADD CONSTRAINT institutions_pkey PRIMARY KEY (id);


--
-- Name: managers managers_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.managers
    ADD CONSTRAINT managers_pkey PRIMARY KEY (id);


--
-- Name: norm_scales norm_scales_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.norm_scales
    ADD CONSTRAINT norm_scales_pkey PRIMARY KEY (id);


--
-- Name: notifications notifications_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.notifications
    ADD CONSTRAINT notifications_pkey PRIMARY KEY (id);


--
-- Name: online_diagnostic_urls online_diagnostic_urls_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.online_diagnostic_urls
    ADD CONSTRAINT online_diagnostic_urls_pkey PRIMARY KEY (id);


--
-- Name: online_diagnostics online_diagnostics_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.online_diagnostics
    ADD CONSTRAINT online_diagnostics_pkey PRIMARY KEY (id);


--
-- Name: portfolio_comments portfolio_comments_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_comments
    ADD CONSTRAINT portfolio_comments_pkey PRIMARY KEY (id);


--
-- Name: portfolio_conditions portfolio_conditions_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_conditions
    ADD CONSTRAINT portfolio_conditions_pkey PRIMARY KEY (id);


--
-- Name: portfolio_conditions_steps portfolio_conditions_steps_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_conditions_steps
    ADD CONSTRAINT portfolio_conditions_steps_pkey PRIMARY KEY (id);


--
-- Name: portfolio_dbrcs portfolio_dbrcs_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_dbrcs
    ADD CONSTRAINT portfolio_dbrcs_pkey PRIMARY KEY (id);


--
-- Name: portfolio_document_types portfolio_document_types_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_document_types
    ADD CONSTRAINT portfolio_document_types_pkey PRIMARY KEY (id);


--
-- Name: portfolio_documents portfolio_documents_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_documents
    ADD CONSTRAINT portfolio_documents_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_advancement_plans portfolio_item_advancement_plans_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_advancement_plans
    ADD CONSTRAINT portfolio_item_advancement_plans_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_class_diagnostics portfolio_item_class_diagnostics_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_class_diagnostics
    ADD CONSTRAINT portfolio_item_class_diagnostics_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_diagnostic_informal_result_documents portfolio_item_diagnostic_informal_result_documents_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostic_informal_result_documents
    ADD CONSTRAINT portfolio_item_diagnostic_informal_result_documents_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_diagnostic_informal_result_guardians portfolio_item_diagnostic_informal_result_guardians_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostic_informal_result_guardians
    ADD CONSTRAINT portfolio_item_diagnostic_informal_result_guardians_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_diagnostic_informal_result_people portfolio_item_diagnostic_informal_result_people_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostic_informal_result_people
    ADD CONSTRAINT portfolio_item_diagnostic_informal_result_people_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_diagnostic_informal_result_supporters portfolio_item_diagnostic_informal_result_supporters_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostic_informal_result_supporters
    ADD CONSTRAINT portfolio_item_diagnostic_informal_result_supporters_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_diagnostic_informal_result_teachers portfolio_item_diagnostic_informal_result_teachers_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostic_informal_result_teachers
    ADD CONSTRAINT portfolio_item_diagnostic_informal_result_teachers_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_diagnostic_informal_results portfolio_item_diagnostic_informal_results_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostic_informal_results
    ADD CONSTRAINT portfolio_item_diagnostic_informal_results_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_diagnostic_measurements portfolio_item_diagnostic_measurements_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostic_measurements
    ADD CONSTRAINT portfolio_item_diagnostic_measurements_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_diagnostic_results portfolio_item_diagnostic_results_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostic_results
    ADD CONSTRAINT portfolio_item_diagnostic_results_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_diagnostics portfolio_item_diagnostics_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostics
    ADD CONSTRAINT portfolio_item_diagnostics_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_evaluation_dbr_characteristics portfolio_item_evaluation_dbr_characteristics_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_evaluation_dbr_characteristics
    ADD CONSTRAINT portfolio_item_evaluation_dbr_characteristics_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_evaluation_dbr_results portfolio_item_evaluation_dbr_results_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_evaluation_dbr_results
    ADD CONSTRAINT portfolio_item_evaluation_dbr_results_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_evaluation_dbrs portfolio_item_evaluation_dbrs_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_evaluation_dbrs
    ADD CONSTRAINT portfolio_item_evaluation_dbrs_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_evaluations portfolio_item_evaluations_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_evaluations
    ADD CONSTRAINT portfolio_item_evaluations_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_involved_guardians portfolio_item_involved_guardians_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_involved_guardians
    ADD CONSTRAINT portfolio_item_involved_guardians_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_involved_people portfolio_item_involved_people_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_involved_people
    ADD CONSTRAINT portfolio_item_involved_people_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_involved_supporters portfolio_item_involved_supporters_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_involved_supporters
    ADD CONSTRAINT portfolio_item_involved_supporters_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_involved_teachers portfolio_item_involved_teachers_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_involved_teachers
    ADD CONSTRAINT portfolio_item_involved_teachers_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_measurements portfolio_item_measurements_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_measurements
    ADD CONSTRAINT portfolio_item_measurements_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_target_results portfolio_item_target_results_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_target_results
    ADD CONSTRAINT portfolio_item_target_results_pkey PRIMARY KEY (id);


--
-- Name: portfolio_item_targets portfolio_item_targets_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_targets
    ADD CONSTRAINT portfolio_item_targets_pkey PRIMARY KEY (id);


--
-- Name: portfolio_items portfolio_items_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_items
    ADD CONSTRAINT portfolio_items_pkey PRIMARY KEY (id);


--
-- Name: portfolio_rule_steps portfolio_rule_steps_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_rule_steps
    ADD CONSTRAINT portfolio_rule_steps_pkey PRIMARY KEY (id);


--
-- Name: portfolio_rules portfolio_rules_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_rules
    ADD CONSTRAINT portfolio_rules_pkey PRIMARY KEY (id);


--
-- Name: portfolio_specializations portfolio_specializations_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_specializations
    ADD CONSTRAINT portfolio_specializations_pkey PRIMARY KEY (id);


--
-- Name: portfolio_step_results portfolio_step_results_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_step_results
    ADD CONSTRAINT portfolio_step_results_pkey PRIMARY KEY (id);


--
-- Name: portfolio_steps portfolio_steps_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_steps
    ADD CONSTRAINT portfolio_steps_pkey PRIMARY KEY (id);


--
-- Name: portfolio_template_documents portfolio_template_documents_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_template_documents
    ADD CONSTRAINT portfolio_template_documents_pkey PRIMARY KEY (id);


--
-- Name: portfolios portfolios_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolios
    ADD CONSTRAINT portfolios_pkey PRIMARY KEY (id);


--
-- Name: questionnaire_results questionnaire_results_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.questionnaire_results
    ADD CONSTRAINT questionnaire_results_pkey PRIMARY KEY (id);


--
-- Name: questionnaires questionnaires_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.questionnaires
    ADD CONSTRAINT questionnaires_pkey PRIMARY KEY (id);


--
-- Name: queue_classic_jobs queue_classic_jobs_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.queue_classic_jobs
    ADD CONSTRAINT queue_classic_jobs_pkey PRIMARY KEY (id);


--
-- Name: school_stat_portfolio_items school_stat_portfolio_items_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.school_stat_portfolio_items
    ADD CONSTRAINT school_stat_portfolio_items_pkey PRIMARY KEY (id);


--
-- Name: school_stats school_stats_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.school_stats
    ADD CONSTRAINT school_stats_pkey PRIMARY KEY (id);


--
-- Name: semesters semesters_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.semesters
    ADD CONSTRAINT semesters_pkey PRIMARY KEY (id);


--
-- Name: supporters supporters_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.supporters
    ADD CONSTRAINT supporters_pkey PRIMARY KEY (id);


--
-- Name: system_settings system_settings_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.system_settings
    ADD CONSTRAINT system_settings_pkey PRIMARY KEY (id);


--
-- Name: system_tasks system_tasks_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.system_tasks
    ADD CONSTRAINT system_tasks_pkey PRIMARY KEY (id);


--
-- Name: teacher_categories teacher_categories_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.teacher_categories
    ADD CONSTRAINT teacher_categories_pkey PRIMARY KEY (id);


--
-- Name: teacher_institution_categories teacher_institution_categories_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.teacher_institution_categories
    ADD CONSTRAINT teacher_institution_categories_pkey PRIMARY KEY (id);


--
-- Name: teacher_institution_relations teacher_institution_relations_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.teacher_institution_relations
    ADD CONSTRAINT teacher_institution_relations_pkey PRIMARY KEY (id);


--
-- Name: teachers teachers_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.teachers
    ADD CONSTRAINT teachers_pkey PRIMARY KEY (id);


--
-- Name: user_messages user_messages_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.user_messages
    ADD CONSTRAINT user_messages_pkey PRIMARY KEY (id);


--
-- Name: users users_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.users
    ADD CONSTRAINT users_pkey PRIMARY KEY (id);


--
-- Name: idx_apb_on_ap_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_apb_on_ap_id ON public.advancement_plan_borrows USING btree (advancement_plan_id);


--
-- Name: idx_apis_on_ap_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_apis_on_ap_id ON public.advancement_plan_institution_stocks USING btree (advancement_plan_id);


--
-- Name: idx_cdd_on_cddr_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_cdd_on_cddr_id ON public.client_duplicate_detections USING btree (client_duplicate_detection_request_id);


--
-- Name: idx_cdd_on_cdr_id; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX idx_cdd_on_cdr_id ON public.client_duplicate_detections USING btree (client_duplicate_request_id);


--
-- Name: idx_cdd_on_cl_id; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX idx_cdd_on_cl_id ON public.client_duplicate_detections USING btree (client_id);


--
-- Name: idx_cddr_on_cddq_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_cddr_on_cddq_id ON public.client_duplicate_detection_requests USING btree (client_duplicate_detection_query_id);


--
-- Name: idx_cddr_on_cdr_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_cddr_on_cdr_id ON public.client_duplicate_detection_requests USING btree (client_duplicate_request_id);


--
-- Name: idx_cddr_on_v_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_cddr_on_v_id ON public.client_duplicate_detection_requests USING btree (vsb_id);


--
-- Name: idx_cdr_on_cdd_id_v_id; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX idx_cdr_on_cdd_id_v_id ON public.client_duplicate_responses USING btree (vsb_id, client_id, duplicate_type);


--
-- Name: idx_cdres_on_cdreq_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_cdres_on_cdreq_id ON public.client_duplicate_responses USING btree (client_duplicate_request_id);


--
-- Name: idx_cdres_on_v_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_cdres_on_v_id ON public.client_duplicate_responses USING btree (vsb_id);


--
-- Name: idx_cqpi_on_cq; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_cqpi_on_cq ON public.checklist_questions_portfolio_items USING btree (checklist_question_id);


--
-- Name: idx_cqpi_on_pi; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_cqpi_on_pi ON public.checklist_questions_portfolio_items USING btree (portfolio_item_id);


--
-- Name: idx_eci_on_ec_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_eci_on_ec_id ON public.educational_courses_institutions USING btree (educational_course_id);


--
-- Name: idx_ecr_on_csn_and_ec_id; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX idx_ecr_on_csn_and_ec_id ON public.educational_course_rules USING btree (course_stage_name, educational_course_id);


--
-- Name: idx_ecr_on_ec_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_ecr_on_ec_id ON public.educational_course_rules USING btree (educational_course_id);


--
-- Name: idx_eig_on_g_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_eig_on_g_id ON public.evaluation_involved_guardians USING btree (guardian_id);


--
-- Name: idx_eig_on_pie_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_eig_on_pie_id ON public.evaluation_involved_guardians USING btree (portfolio_item_evaluation_id);


--
-- Name: idx_eip_on_pit_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_eip_on_pit_id ON public.evaluation_involved_persons USING btree (portfolio_item_evaluation_id);


--
-- Name: idx_eis_on_pie_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_eis_on_pie_id ON public.evaluation_involved_supporters USING btree (portfolio_item_evaluation_id);


--
-- Name: idx_eis_on_s_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_eis_on_s_id ON public.evaluation_involved_supporters USING btree (supporter_id);


--
-- Name: idx_id_on_i_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_id_on_i_id ON public.institution_documents USING btree (institution_id);


--
-- Name: idx_notifications_on_type_and_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_notifications_on_type_and_id ON public.notifications USING btree (notificationable_id, notificationable_type);


--
-- Name: idx_odu_on_od_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_odu_on_od_id ON public.online_diagnostic_urls USING btree (online_diagnostic_id);


--
-- Name: idx_picd_on_od_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_picd_on_od_id ON public.portfolio_item_class_diagnostics USING btree (diagnostic_id);


--
-- Name: idx_pid_on_ap_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pid_on_ap_id ON public.portfolio_item_advancement_plans USING btree (advancement_plan_borrow_id);


--
-- Name: idx_pid_on_db_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pid_on_db_id ON public.portfolio_item_diagnostics USING btree (diagnostic_borrow_id);


--
-- Name: idx_pidir_on_dia_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pidir_on_dia_id ON public.portfolio_item_diagnostic_informal_results USING btree (diagnostic_result_acceptor_type, diagnostic_result_acceptor_id);


--
-- Name: idx_pidird_on_pidir_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pidird_on_pidir_id ON public.portfolio_item_diagnostic_informal_result_documents USING btree (portfolio_item_diagnostic_informal_result_id);


--
-- Name: idx_pidirg_on_g_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pidirg_on_g_id ON public.portfolio_item_diagnostic_informal_result_guardians USING btree (guardian_id);


--
-- Name: idx_pidirg_on_pidir_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pidirg_on_pidir_id ON public.portfolio_item_diagnostic_informal_result_guardians USING btree (portfolio_item_diagnostic_informal_result_id);


--
-- Name: idx_pidirp_on_pidir_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pidirp_on_pidir_id ON public.portfolio_item_diagnostic_informal_result_people USING btree (portfolio_item_diagnostic_informal_result_id);


--
-- Name: idx_pidirs_on_pidir_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pidirs_on_pidir_id ON public.portfolio_item_diagnostic_informal_result_supporters USING btree (portfolio_item_diagnostic_informal_result_id);


--
-- Name: idx_pidirs_on_s_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pidirs_on_s_id ON public.portfolio_item_diagnostic_informal_result_supporters USING btree (supporter_id);


--
-- Name: idx_pidirt_on_pidir_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pidirt_on_pidir_id ON public.portfolio_item_diagnostic_informal_result_teachers USING btree (portfolio_item_diagnostic_informal_result_id);


--
-- Name: idx_pidirt_on_t_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pidirt_on_t_id ON public.portfolio_item_diagnostic_informal_result_teachers USING btree (teacher_id);


--
-- Name: idx_pidm_on_pi_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pidm_on_pi_id ON public.portfolio_item_diagnostic_measurements USING btree (portfolio_item_id);


--
-- Name: idx_pidr_on_pidir_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pidr_on_pidir_id ON public.portfolio_item_diagnostic_results USING btree (portfolio_item_diagnostic_informal_result_id);


--
-- Name: idx_piip_on_pi_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_piip_on_pi_id ON public.portfolio_item_involved_people USING btree (portfolio_item_id);


--
-- Name: idx_piis_on_pi_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_piis_on_pi_id ON public.portfolio_item_involved_supporters USING btree (portfolio_item_id);


--
-- Name: idx_piis_on_s_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_piis_on_s_id ON public.portfolio_item_involved_supporters USING btree (supporter_id);


--
-- Name: idx_pim_on_pi_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pim_on_pi_id ON public.portfolio_item_measurements USING btree (portfolio_item_id);


--
-- Name: idx_pit_on_pi_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pit_on_pi_id ON public.portfolio_item_targets USING btree (portfolio_item_id);


--
-- Name: idx_pitr_on_pers_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pitr_on_pers_id ON public.portfolio_item_target_results USING btree (evaluative_type, evaluative_id);


--
-- Name: idx_pitr_on_pit_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_pitr_on_pit_id ON public.portfolio_item_target_results USING btree (portfolio_item_target_id);


--
-- Name: idx_portfolio_item_involved_guardians_unq_1; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX idx_portfolio_item_involved_guardians_unq_1 ON public.portfolio_item_involved_guardians USING btree (guardian_id, portfolio_item_id);


--
-- Name: idx_portfolio_item_involved_teachers_unq_1; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX idx_portfolio_item_involved_teachers_unq_1 ON public.portfolio_item_involved_teachers USING btree (teacher_id, portfolio_item_id);


--
-- Name: idx_qc_on_name_only_unlocked; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_qc_on_name_only_unlocked ON public.queue_classic_jobs USING btree (q_name, id) WHERE (locked_at IS NULL);


--
-- Name: idx_qc_on_scheduled_at_only_unlocked; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_qc_on_scheduled_at_only_unlocked ON public.queue_classic_jobs USING btree (scheduled_at, id) WHERE (locked_at IS NULL);


--
-- Name: idx_qu_on_c_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_qu_on_c_id ON public.questionnaires USING btree (client_id);


--
-- Name: idx_qu_on_g_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_qu_on_g_id ON public.questionnaires USING btree (guardian_id);


--
-- Name: idx_qu_on_s_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_qu_on_s_id ON public.questionnaires USING btree (supporter_id);


--
-- Name: idx_qu_on_t_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_qu_on_t_id ON public.questionnaires USING btree (teacher_id);


--
-- Name: idx_quere_on_qu_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_quere_on_qu_id ON public.questionnaire_results USING btree (questionnaire_id);


--
-- Name: idx_quest_on_pi_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX idx_quest_on_pi_id ON public.questionnaires USING btree (portfolio_item_id);


--
-- Name: idx_tir_on_institution_id_and_teacher_id; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX idx_tir_on_institution_id_and_teacher_id ON public.teacher_institution_relations USING btree (institution_id, teacher_id);


--
-- Name: index_addresses_on_latitude_and_longitude; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX index_addresses_on_latitude_and_longitude ON public.addresses USING btree (latitude, longitude);


--
-- Name: index_advancement_plan_borrows_on_institution_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_advancement_plan_borrows_on_institution_id ON public.advancement_plan_borrows USING btree (institution_id);


--
-- Name: index_advancement_plan_borrows_on_teacher_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_advancement_plan_borrows_on_teacher_id ON public.advancement_plan_borrows USING btree (teacher_id);


--
-- Name: index_advancement_plan_institution_stocks_on_institution_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_advancement_plan_institution_stocks_on_institution_id ON public.advancement_plan_institution_stocks USING btree (institution_id);


--
-- Name: index_advancement_plans_on_title; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_advancement_plans_on_title ON public.advancement_plans USING btree (title);


--
-- Name: index_app_versions_on_ensure_single_row; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX index_app_versions_on_ensure_single_row ON public.app_versions USING btree (ensure_single_row);


--
-- Name: index_career_item_on_client_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_career_item_on_client_id ON public.career_items USING btree (client_id);


--
-- Name: index_career_items_on_client_group_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_career_items_on_client_group_id ON public.career_items USING btree (client_group_id);


--
-- Name: index_career_items_on_institution_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_career_items_on_institution_id ON public.career_items USING btree (institution_id);


--
-- Name: index_career_items_on_teacher_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_career_items_on_teacher_id ON public.career_items USING btree (teacher_id);


--
-- Name: index_checklist_group_tpls_on_checklist_tpl_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_checklist_group_tpls_on_checklist_tpl_id ON public.checklist_group_tpls USING btree (checklist_tpl_id);


--
-- Name: index_checklist_group_tpls_on_portfolio_specialization_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_checklist_group_tpls_on_portfolio_specialization_id ON public.checklist_group_tpls USING btree (portfolio_specialization_id);


--
-- Name: index_checklist_groups_on_checklist_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_checklist_groups_on_checklist_id ON public.checklist_groups USING btree (checklist_id);


--
-- Name: index_checklist_groups_on_portfolio_specialization_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_checklist_groups_on_portfolio_specialization_id ON public.checklist_groups USING btree (portfolio_specialization_id);


--
-- Name: index_checklist_question_tpls_on_checklist_group_tpl_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_checklist_question_tpls_on_checklist_group_tpl_id ON public.checklist_question_tpls USING btree (checklist_group_tpl_id);


--
-- Name: index_checklist_question_tpls_on_checklist_tpl_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_checklist_question_tpls_on_checklist_tpl_id ON public.checklist_question_tpls USING btree (checklist_tpl_id);


--
-- Name: index_checklist_question_tpls_on_portfolio_specialization_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_checklist_question_tpls_on_portfolio_specialization_id ON public.checklist_question_tpls USING btree (portfolio_specialization_id);


--
-- Name: index_checklist_questions_on_checklist_group_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_checklist_questions_on_checklist_group_id ON public.checklist_questions USING btree (checklist_group_id);


--
-- Name: index_checklist_questions_on_checklist_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_checklist_questions_on_checklist_id ON public.checklist_questions USING btree (checklist_id);


--
-- Name: index_checklist_questions_on_portfolio_specialization_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_checklist_questions_on_portfolio_specialization_id ON public.checklist_questions USING btree (portfolio_specialization_id);


--
-- Name: index_checklist_tpls_on_portfolio_specialization_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_checklist_tpls_on_portfolio_specialization_id ON public.checklist_tpls USING btree (portfolio_specialization_id);


--
-- Name: index_checklists_on_checklist_tpl_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_checklists_on_checklist_tpl_id ON public.checklists USING btree (checklist_tpl_id);


--
-- Name: index_checklists_on_manager_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_checklists_on_manager_id ON public.checklists USING btree (manager_id);


--
-- Name: index_checklists_on_portfolio_item_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_checklists_on_portfolio_item_id ON public.checklists USING btree (portfolio_item_id);


--
-- Name: index_checklists_on_portfolio_specialization_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_checklists_on_portfolio_specialization_id ON public.checklists USING btree (portfolio_specialization_id);


--
-- Name: index_checklists_on_teacher_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_checklists_on_teacher_id ON public.checklists USING btree (teacher_id);


--
-- Name: index_ckeditor_assets_on_type; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_ckeditor_assets_on_type ON public.ckeditor_assets USING btree (type);


--
-- Name: index_client_group_histories_on_client_group_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_client_group_histories_on_client_group_id ON public.client_group_histories USING btree (client_group_id);


--
-- Name: index_client_group_histories_on_teacher_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_client_group_histories_on_teacher_id ON public.client_group_histories USING btree (teacher_id);


--
-- Name: index_client_groups_on_institution_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_client_groups_on_institution_id ON public.client_groups USING btree (institution_id);


--
-- Name: index_client_groups_on_running_portfolio_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_client_groups_on_running_portfolio_id ON public.client_groups USING btree (running_portfolio_id);


--
-- Name: index_client_groups_on_semester_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_client_groups_on_semester_id ON public.client_groups USING btree (semester_id);


--
-- Name: index_client_groups_on_teacher_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_client_groups_on_teacher_id ON public.client_groups USING btree (teacher_id);


--
-- Name: index_client_groups_on_teacher_id_and_semester_id; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX index_client_groups_on_teacher_id_and_semester_id ON public.client_groups USING btree (teacher_id, semester_id);


--
-- Name: index_client_guardian_relations_on_client_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_client_guardian_relations_on_client_id ON public.client_guardian_relations USING btree (client_id);


--
-- Name: index_client_guardian_relations_on_guardian_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_client_guardian_relations_on_guardian_id ON public.client_guardian_relations USING btree (guardian_id);


--
-- Name: index_client_phonetics_on_client_id; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX index_client_phonetics_on_client_id ON public.client_phonetics USING btree (client_id);


--
-- Name: index_client_phonetics_on_first_name_double_metaphone_alt_hash; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_client_phonetics_on_first_name_double_metaphone_alt_hash ON public.client_phonetics USING btree (first_name_double_metaphone_alt_hash);


--
-- Name: index_client_phonetics_on_first_name_double_metaphone_pri_hash; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_client_phonetics_on_first_name_double_metaphone_pri_hash ON public.client_phonetics USING btree (first_name_double_metaphone_pri_hash);


--
-- Name: index_client_phonetics_on_first_name_koelner_phonetic_hash; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_client_phonetics_on_first_name_koelner_phonetic_hash ON public.client_phonetics USING btree (first_name_koelner_phonetic_hash);


--
-- Name: index_client_phonetics_on_last_name_double_metaphone_alt_hash; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_client_phonetics_on_last_name_double_metaphone_alt_hash ON public.client_phonetics USING btree (last_name_double_metaphone_alt_hash);


--
-- Name: index_client_phonetics_on_last_name_double_metaphone_pri_hash; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_client_phonetics_on_last_name_double_metaphone_pri_hash ON public.client_phonetics USING btree (last_name_double_metaphone_pri_hash);


--
-- Name: index_client_phonetics_on_last_name_koelner_phonetic_hash; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_client_phonetics_on_last_name_koelner_phonetic_hash ON public.client_phonetics USING btree (last_name_koelner_phonetic_hash);


--
-- Name: index_client_supporter_relations_on_client_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_client_supporter_relations_on_client_id ON public.client_supporter_relations USING btree (client_id);


--
-- Name: index_client_supporter_relations_on_supporter_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_client_supporter_relations_on_supporter_id ON public.client_supporter_relations USING btree (supporter_id);


--
-- Name: index_clients_on_client_duplicate_request_id; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX index_clients_on_client_duplicate_request_id ON public.clients USING btree (client_duplicate_request_id);


--
-- Name: index_clients_on_client_group_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_clients_on_client_group_id ON public.clients USING btree (client_group_id);


--
-- Name: index_clients_on_expertise_institution_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_clients_on_expertise_institution_id ON public.clients USING btree (expertise_institution_id);


--
-- Name: index_clients_on_expertise_manager_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_clients_on_expertise_manager_id ON public.clients USING btree (expertise_manager_id);


--
-- Name: index_clients_on_expertise_school_inspector_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_clients_on_expertise_school_inspector_id ON public.clients USING btree (expertise_school_inspector_id);


--
-- Name: index_clients_on_expertise_teacher_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_clients_on_expertise_teacher_id ON public.clients USING btree (expertise_teacher_id);


--
-- Name: index_clients_on_institution_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_clients_on_institution_id ON public.clients USING btree (institution_id);


--
-- Name: index_clients_on_running_portfolio_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_clients_on_running_portfolio_id ON public.clients USING btree (running_portfolio_id);


--
-- Name: index_clients_on_teacher_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_clients_on_teacher_id ON public.clients USING btree (teacher_id);


--
-- Name: index_diagnostic_borrows_on_diagnostic_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_diagnostic_borrows_on_diagnostic_id ON public.diagnostic_borrows USING btree (diagnostic_id);


--
-- Name: index_diagnostic_borrows_on_institution_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_diagnostic_borrows_on_institution_id ON public.diagnostic_borrows USING btree (institution_id);


--
-- Name: index_diagnostic_borrows_on_teacher_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_diagnostic_borrows_on_teacher_id ON public.diagnostic_borrows USING btree (teacher_id);


--
-- Name: index_diagnostic_institution_stocks_on_diagnostic_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_diagnostic_institution_stocks_on_diagnostic_id ON public.diagnostic_institution_stocks USING btree (diagnostic_id);


--
-- Name: index_diagnostic_institution_stocks_on_institution_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_diagnostic_institution_stocks_on_institution_id ON public.diagnostic_institution_stocks USING btree (institution_id);


--
-- Name: index_diagnostics_on_title; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_diagnostics_on_title ON public.diagnostics USING btree (title);


--
-- Name: index_institution_document_hierarchies_on_child_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_institution_document_hierarchies_on_child_id ON public.institution_document_hierarchies USING btree (child_id);


--
-- Name: index_institution_document_hierarchies_on_level; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_institution_document_hierarchies_on_level ON public.institution_document_hierarchies USING btree (level);


--
-- Name: index_institution_document_hierarchies_on_parent_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_institution_document_hierarchies_on_parent_id ON public.institution_document_hierarchies USING btree (parent_id);


--
-- Name: index_institution_hierarchies_on_child_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_institution_hierarchies_on_child_id ON public.institution_hierarchies USING btree (child_id);


--
-- Name: index_institution_hierarchies_on_parent_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_institution_hierarchies_on_parent_id ON public.institution_hierarchies USING btree (parent_id);


--
-- Name: index_institutions_on_address_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_institutions_on_address_id ON public.institutions USING btree (address_id);


--
-- Name: index_institutions_on_institution_category_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_institutions_on_institution_category_id ON public.institutions USING btree (institution_category_id);


--
-- Name: index_notifications_on_client_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_notifications_on_client_id ON public.notifications USING btree (client_id);


--
-- Name: index_notifications_on_deleted_at; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_notifications_on_deleted_at ON public.notifications USING btree (deleted_at);


--
-- Name: index_notifications_on_institution_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_notifications_on_institution_id ON public.notifications USING btree (institution_id);


--
-- Name: index_people_on_deleted_at; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_people_on_deleted_at ON public.clients USING btree (deleted_at);


--
-- Name: index_portfolio_comments_on_author_type_and_author_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_comments_on_author_type_and_author_id ON public.portfolio_comments USING btree (author_type, author_id);


--
-- Name: index_portfolio_comments_on_portfolio_item_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_comments_on_portfolio_item_id ON public.portfolio_comments USING btree (portfolio_item_id);


--
-- Name: index_portfolio_comments_on_teacher_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_comments_on_teacher_id ON public.portfolio_comments USING btree (teacher_id);


--
-- Name: index_portfolio_dbrcs_on_client_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_dbrcs_on_client_id ON public.portfolio_dbrcs USING btree (client_id);


--
-- Name: index_portfolio_dbrcs_on_portfolio_item_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_dbrcs_on_portfolio_item_id ON public.portfolio_dbrcs USING btree (portfolio_item_id);


--
-- Name: index_portfolio_dbrcs_on_questionnaire_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_dbrcs_on_questionnaire_id ON public.portfolio_dbrcs USING btree (questionnaire_id);


--
-- Name: index_portfolio_dbrcs_on_questionnaire_result_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_dbrcs_on_questionnaire_result_id ON public.portfolio_dbrcs USING btree (questionnaire_result_id);


--
-- Name: index_portfolio_item_diagnostics_on_diagnostic_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_item_diagnostics_on_diagnostic_id ON public.portfolio_item_diagnostics USING btree (diagnostic_id);


--
-- Name: index_portfolio_item_involved_guardians_on_guardian_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_item_involved_guardians_on_guardian_id ON public.portfolio_item_involved_guardians USING btree (guardian_id);


--
-- Name: index_portfolio_item_involved_guardians_on_portfolio_item_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_item_involved_guardians_on_portfolio_item_id ON public.portfolio_item_involved_guardians USING btree (portfolio_item_id);


--
-- Name: index_portfolio_item_involved_teachers_on_portfolio_item_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_item_involved_teachers_on_portfolio_item_id ON public.portfolio_item_involved_teachers USING btree (portfolio_item_id);


--
-- Name: index_portfolio_item_involved_teachers_on_teacher_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_item_involved_teachers_on_teacher_id ON public.portfolio_item_involved_teachers USING btree (teacher_id);


--
-- Name: index_portfolio_item_targets_on_portfolio_dbrc_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_item_targets_on_portfolio_dbrc_id ON public.portfolio_item_targets USING btree (portfolio_dbrc_id);


--
-- Name: index_portfolio_items_on_client_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_items_on_client_id ON public.portfolio_items USING btree (client_id);


--
-- Name: index_portfolio_items_on_client_id_and_position; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX index_portfolio_items_on_client_id_and_position ON public.portfolio_items USING btree (client_id, "position");


--
-- Name: index_portfolio_items_on_portfolio_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_items_on_portfolio_id ON public.portfolio_items USING btree (portfolio_id);


--
-- Name: index_portfolio_items_on_portfolio_specialization_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_items_on_portfolio_specialization_id ON public.portfolio_items USING btree (portfolio_specialization_id);


--
-- Name: index_portfolio_items_on_portfolio_step_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_items_on_portfolio_step_id ON public.portfolio_items USING btree (portfolio_step_id);


--
-- Name: index_portfolio_items_on_portfolio_step_result_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolio_items_on_portfolio_step_result_id ON public.portfolio_items USING btree (portfolio_step_result_id);


--
-- Name: index_portfolios_on_rule_set_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolios_on_rule_set_id ON public.portfolios USING btree (rule_set_id);


--
-- Name: index_portfolios_on_subject_type_and_subject_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_portfolios_on_subject_type_and_subject_id ON public.portfolios USING btree (subject_type, subject_id);


--
-- Name: index_supporters_on_institution_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_supporters_on_institution_id ON public.supporters USING btree (institution_id);


--
-- Name: index_system_tasks_on_client_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_system_tasks_on_client_id ON public.system_tasks USING btree (client_id);


--
-- Name: index_system_tasks_on_due_at; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_system_tasks_on_due_at ON public.system_tasks USING btree (due_at);


--
-- Name: index_system_tasks_on_institution_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_system_tasks_on_institution_id ON public.system_tasks USING btree (institution_id);


--
-- Name: index_system_tasks_on_next_escalation; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_system_tasks_on_next_escalation ON public.system_tasks USING btree (next_escalation);


--
-- Name: index_system_tasks_on_start_at; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_system_tasks_on_start_at ON public.system_tasks USING btree (start_at);


--
-- Name: index_system_tasks_on_target_id_and_target_type; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_system_tasks_on_target_id_and_target_type ON public.system_tasks USING btree (target_id, target_type);


--
-- Name: index_teacher_institution_relations_on_institution_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_teacher_institution_relations_on_institution_id ON public.teacher_institution_relations USING btree (institution_id);


--
-- Name: index_teacher_institution_relations_on_teacher_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_teacher_institution_relations_on_teacher_id ON public.teacher_institution_relations USING btree (teacher_id);


--
-- Name: index_teachers_on_deleted_at; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_teachers_on_deleted_at ON public.teachers USING btree (deleted_at);


--
-- Name: index_teachers_on_teacher_category_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_teachers_on_teacher_category_id ON public.teachers USING btree (teacher_category_id);


--
-- Name: index_user_messages_on_recipient_id_and_recipient_type; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_user_messages_on_recipient_id_and_recipient_type ON public.user_messages USING btree (recipient_id, recipient_type);


--
-- Name: index_user_messages_on_sender_id_and_sender_type; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_user_messages_on_sender_id_and_sender_type ON public.user_messages USING btree (sender_id, sender_type);


--
-- Name: index_user_messages_on_system_task_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_user_messages_on_system_task_id ON public.user_messages USING btree (system_task_id);


--
-- Name: index_users_on_email; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX index_users_on_email ON public.users USING btree (email);


--
-- Name: index_users_on_identifiable_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX index_users_on_identifiable_id ON public.users USING btree (identifiable_id);


--
-- Name: index_users_on_reset_password_token; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX index_users_on_reset_password_token ON public.users USING btree (reset_password_token);


--
-- Name: index_users_on_username; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX index_users_on_username ON public.users USING btree (username);


--
-- Name: unique_schema_migrations; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX unique_schema_migrations ON public.schema_migrations USING btree (version);


--
-- Name: institution_documents institution_documents_maintain_tree_consistency; Type: TRIGGER; Schema: public; Owner: -
--

CREATE TRIGGER institution_documents_maintain_tree_consistency AFTER INSERT OR DELETE OR UPDATE ON public.institution_documents FOR EACH ROW EXECUTE PROCEDURE public.institution_document_hierarchies_update();


--
-- Name: institutions institutions_maintain_tree_consistency; Type: TRIGGER; Schema: public; Owner: -
--

CREATE TRIGGER institutions_maintain_tree_consistency AFTER INSERT OR DELETE OR UPDATE ON public.institutions FOR EACH ROW EXECUTE PROCEDURE public.institution_hierarchies_update();


--
-- Name: queue_classic_jobs queue_classic_notify; Type: TRIGGER; Schema: public; Owner: -
--

CREATE TRIGGER queue_classic_notify AFTER INSERT ON public.queue_classic_jobs FOR EACH ROW EXECUTE PROCEDURE public.queue_classic_notify();


--
-- Name: educational_courses_institutions fk_eci_on_ec_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.educational_courses_institutions
    ADD CONSTRAINT fk_eci_on_ec_id FOREIGN KEY (educational_course_id) REFERENCES public.educational_courses(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: educational_course_rules fk_ecr_on_ec_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.educational_course_rules
    ADD CONSTRAINT fk_ecr_on_ec_id FOREIGN KEY (educational_course_id) REFERENCES public.educational_courses(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: online_diagnostic_urls fk_odu_on_od_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.online_diagnostic_urls
    ADD CONSTRAINT fk_odu_on_od_id FOREIGN KEY (online_diagnostic_id) REFERENCES public.online_diagnostics(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: portfolio_item_class_diagnostics fk_picd_on_od_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_class_diagnostics
    ADD CONSTRAINT fk_picd_on_od_id FOREIGN KEY (diagnostic_id) REFERENCES public.online_diagnostics(id) ON UPDATE CASCADE ON DELETE RESTRICT;


--
-- Name: questionnaires fk_rails_01d61489b8; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.questionnaires
    ADD CONSTRAINT fk_rails_01d61489b8 FOREIGN KEY (teacher_id) REFERENCES public.teachers(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: teacher_institution_relations fk_rails_0291ee2b0d; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.teacher_institution_relations
    ADD CONSTRAINT fk_rails_0291ee2b0d FOREIGN KEY (teacher_id) REFERENCES public.teachers(id);


--
-- Name: evaluation_involved_guardians fk_rails_051c1d509e; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.evaluation_involved_guardians
    ADD CONSTRAINT fk_rails_051c1d509e FOREIGN KEY (guardian_id) REFERENCES public.guardians(id);


--
-- Name: clients fk_rails_084558fba0; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.clients
    ADD CONSTRAINT fk_rails_084558fba0 FOREIGN KEY (teacher_id) REFERENCES public.teachers(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: portfolio_rule_steps fk_rails_0bfa7ad218; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_rule_steps
    ADD CONSTRAINT fk_rails_0bfa7ad218 FOREIGN KEY (rule_id) REFERENCES public.portfolio_rules(id);


--
-- Name: diagnostic_borrows fk_rails_0fc356a15b; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.diagnostic_borrows
    ADD CONSTRAINT fk_rails_0fc356a15b FOREIGN KEY (diagnostic_id) REFERENCES public.diagnostics(id);


--
-- Name: evaluation_involved_guardians fk_rails_110db290cc; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.evaluation_involved_guardians
    ADD CONSTRAINT fk_rails_110db290cc FOREIGN KEY (portfolio_item_evaluation_id) REFERENCES public.portfolio_item_evaluations(id);


--
-- Name: advancement_plan_borrows fk_rails_126ed528fd; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.advancement_plan_borrows
    ADD CONSTRAINT fk_rails_126ed528fd FOREIGN KEY (advancement_plan_id) REFERENCES public.advancement_plans(id);


--
-- Name: checklists fk_rails_132c7199dc; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklists
    ADD CONSTRAINT fk_rails_132c7199dc FOREIGN KEY (checklist_tpl_id) REFERENCES public.checklist_tpls(id) ON DELETE SET NULL;


--
-- Name: portfolio_item_targets fk_rails_13480999dd; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_targets
    ADD CONSTRAINT fk_rails_13480999dd FOREIGN KEY (portfolio_item_id) REFERENCES public.portfolio_items(id);


--
-- Name: portfolio_item_diagnostics fk_rails_14a26bf3b9; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_diagnostics
    ADD CONSTRAINT fk_rails_14a26bf3b9 FOREIGN KEY (diagnostic_id) REFERENCES public.diagnostics(id) ON DELETE CASCADE;


--
-- Name: clients fk_rails_17e4661056; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.clients
    ADD CONSTRAINT fk_rails_17e4661056 FOREIGN KEY (expertise_institution_id) REFERENCES public.institutions(id) ON DELETE SET NULL;


--
-- Name: client_duplicate_responses fk_rails_1925496121; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_duplicate_responses
    ADD CONSTRAINT fk_rails_1925496121 FOREIGN KEY (client_duplicate_request_id) REFERENCES public.client_duplicate_requests(id);


--
-- Name: checklist_question_tpls fk_rails_1c4c34f004; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_question_tpls
    ADD CONSTRAINT fk_rails_1c4c34f004 FOREIGN KEY (portfolio_specialization_id) REFERENCES public.portfolio_specializations(id) ON DELETE SET NULL;


--
-- Name: checklist_questions fk_rails_223970977f; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_questions
    ADD CONSTRAINT fk_rails_223970977f FOREIGN KEY (portfolio_specialization_id) REFERENCES public.portfolio_specializations(id) ON DELETE SET NULL;


--
-- Name: evaluation_involved_supporters fk_rails_2348b725c4; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.evaluation_involved_supporters
    ADD CONSTRAINT fk_rails_2348b725c4 FOREIGN KEY (supporter_id) REFERENCES public.supporters(id);


--
-- Name: clients fk_rails_263e556f1c; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.clients
    ADD CONSTRAINT fk_rails_263e556f1c FOREIGN KEY (expertise_school_inspector_id) REFERENCES public.managers(id) ON DELETE SET NULL;


--
-- Name: portfolio_comments fk_rails_26f38a3e68; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_comments
    ADD CONSTRAINT fk_rails_26f38a3e68 FOREIGN KEY (portfolio_item_id) REFERENCES public.portfolio_items(id) ON DELETE CASCADE;


--
-- Name: portfolio_item_target_results fk_rails_29aee85b43; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_target_results
    ADD CONSTRAINT fk_rails_29aee85b43 FOREIGN KEY (portfolio_item_target_id) REFERENCES public.portfolio_item_targets(id);


--
-- Name: advancement_plan_borrows fk_rails_2b553f45df; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.advancement_plan_borrows
    ADD CONSTRAINT fk_rails_2b553f45df FOREIGN KEY (teacher_id) REFERENCES public.teachers(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: client_guardian_relations fk_rails_2bc851c444; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_guardian_relations
    ADD CONSTRAINT fk_rails_2bc851c444 FOREIGN KEY (guardian_id) REFERENCES public.guardians(id);


--
-- Name: checklist_question_tpls fk_rails_2c8279a7e8; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_question_tpls
    ADD CONSTRAINT fk_rails_2c8279a7e8 FOREIGN KEY (checklist_tpl_id) REFERENCES public.checklist_tpls(id);


--
-- Name: checklist_group_tpls fk_rails_2d77d16b7b; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_group_tpls
    ADD CONSTRAINT fk_rails_2d77d16b7b FOREIGN KEY (checklist_tpl_id) REFERENCES public.checklist_tpls(id) ON DELETE CASCADE;


--
-- Name: diagnostic_institution_stocks fk_rails_2dccb5ac10; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.diagnostic_institution_stocks
    ADD CONSTRAINT fk_rails_2dccb5ac10 FOREIGN KEY (institution_id) REFERENCES public.institutions(id);


--
-- Name: portfolio_item_involved_supporters fk_rails_2e52016032; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_involved_supporters
    ADD CONSTRAINT fk_rails_2e52016032 FOREIGN KEY (portfolio_item_id) REFERENCES public.portfolio_items(id);


--
-- Name: client_guardian_relations fk_rails_2f5ebf6403; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_guardian_relations
    ADD CONSTRAINT fk_rails_2f5ebf6403 FOREIGN KEY (client_id) REFERENCES public.clients(id);


--
-- Name: portfolio_item_targets fk_rails_313c5c6195; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_targets
    ADD CONSTRAINT fk_rails_313c5c6195 FOREIGN KEY (portfolio_dbrc_id) REFERENCES public.portfolio_dbrcs(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: checklist_questions fk_rails_3245896386; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_questions
    ADD CONSTRAINT fk_rails_3245896386 FOREIGN KEY (checklist_group_id) REFERENCES public.checklist_groups(id) ON DELETE CASCADE;


--
-- Name: portfolio_dbrcs fk_rails_34d47a66bc; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_dbrcs
    ADD CONSTRAINT fk_rails_34d47a66bc FOREIGN KEY (questionnaire_id) REFERENCES public.questionnaires(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: portfolio_rule_steps fk_rails_3b01962194; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_rule_steps
    ADD CONSTRAINT fk_rails_3b01962194 FOREIGN KEY (step_id) REFERENCES public.portfolio_steps(id);


--
-- Name: career_items fk_rails_3f40a82ad8; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.career_items
    ADD CONSTRAINT fk_rails_3f40a82ad8 FOREIGN KEY (client_id) REFERENCES public.clients(id) ON DELETE CASCADE;


--
-- Name: client_groups fk_rails_3f5d345a4a; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_groups
    ADD CONSTRAINT fk_rails_3f5d345a4a FOREIGN KEY (institution_id) REFERENCES public.institutions(id);


--
-- Name: client_duplicate_detections fk_rails_4c9c442194; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_duplicate_detections
    ADD CONSTRAINT fk_rails_4c9c442194 FOREIGN KEY (client_id) REFERENCES public.clients(id);


--
-- Name: questionnaires fk_rails_4d1fef9fb5; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.questionnaires
    ADD CONSTRAINT fk_rails_4d1fef9fb5 FOREIGN KEY (guardian_id) REFERENCES public.guardians(id);


--
-- Name: client_supporter_relations fk_rails_4dcd385e0d; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_supporter_relations
    ADD CONSTRAINT fk_rails_4dcd385e0d FOREIGN KEY (client_id) REFERENCES public.clients(id);


--
-- Name: checklist_tpls fk_rails_5156841934; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_tpls
    ADD CONSTRAINT fk_rails_5156841934 FOREIGN KEY (portfolio_specialization_id) REFERENCES public.portfolio_specializations(id) ON DELETE SET NULL;


--
-- Name: portfolio_item_involved_people fk_rails_53989c423d; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_involved_people
    ADD CONSTRAINT fk_rails_53989c423d FOREIGN KEY (portfolio_item_id) REFERENCES public.portfolio_items(id);


--
-- Name: portfolio_items fk_rails_5db3984de6; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_items
    ADD CONSTRAINT fk_rails_5db3984de6 FOREIGN KEY (client_id) REFERENCES public.clients(id);


--
-- Name: questionnaires fk_rails_5e5a7b74c6; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.questionnaires
    ADD CONSTRAINT fk_rails_5e5a7b74c6 FOREIGN KEY (client_id) REFERENCES public.clients(id);


--
-- Name: clients fk_rails_5eaf990457; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.clients
    ADD CONSTRAINT fk_rails_5eaf990457 FOREIGN KEY (institution_id) REFERENCES public.institutions(id);


--
-- Name: diagnostic_borrows fk_rails_60f5ce7089; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.diagnostic_borrows
    ADD CONSTRAINT fk_rails_60f5ce7089 FOREIGN KEY (teacher_id) REFERENCES public.teachers(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: portfolio_comments fk_rails_616fc29544; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_comments
    ADD CONSTRAINT fk_rails_616fc29544 FOREIGN KEY (teacher_id) REFERENCES public.teachers(id) ON DELETE SET NULL;


--
-- Name: checklist_questions_portfolio_items fk_rails_66bd17ee4e; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_questions_portfolio_items
    ADD CONSTRAINT fk_rails_66bd17ee4e FOREIGN KEY (checklist_question_id) REFERENCES public.checklist_questions(id) ON DELETE CASCADE;


--
-- Name: school_stat_portfolio_items fk_rails_66e799aeb6; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.school_stat_portfolio_items
    ADD CONSTRAINT fk_rails_66e799aeb6 FOREIGN KEY (school_stat_id) REFERENCES public.school_stats(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: portfolio_items fk_rails_688511fe46; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_items
    ADD CONSTRAINT fk_rails_688511fe46 FOREIGN KEY (portfolio_step_id) REFERENCES public.portfolio_steps(id);


--
-- Name: checklists fk_rails_6ae7c9159a; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklists
    ADD CONSTRAINT fk_rails_6ae7c9159a FOREIGN KEY (portfolio_item_id) REFERENCES public.portfolio_items(id) ON DELETE CASCADE;


--
-- Name: career_items fk_rails_6b189a9ba1; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.career_items
    ADD CONSTRAINT fk_rails_6b189a9ba1 FOREIGN KEY (institution_id) REFERENCES public.institutions(id) ON DELETE SET NULL;


--
-- Name: client_group_histories fk_rails_6b1de7d82f; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_group_histories
    ADD CONSTRAINT fk_rails_6b1de7d82f FOREIGN KEY (teacher_id) REFERENCES public.teachers(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: teachers fk_rails_6b78d715c1; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.teachers
    ADD CONSTRAINT fk_rails_6b78d715c1 FOREIGN KEY (teacher_category_id) REFERENCES public.teacher_categories(id);


--
-- Name: portfolio_dbrcs fk_rails_6de8816ef6; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_dbrcs
    ADD CONSTRAINT fk_rails_6de8816ef6 FOREIGN KEY (portfolio_item_id) REFERENCES public.portfolio_items(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: clients fk_rails_6e7d252f09; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.clients
    ADD CONSTRAINT fk_rails_6e7d252f09 FOREIGN KEY (client_duplicate_request_id) REFERENCES public.client_duplicate_requests(id) ON DELETE SET NULL;


--
-- Name: career_items fk_rails_719f0aa0c4; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.career_items
    ADD CONSTRAINT fk_rails_719f0aa0c4 FOREIGN KEY (teacher_id) REFERENCES public.teachers(id) ON DELETE SET NULL;


--
-- Name: clients fk_rails_74b2974877; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.clients
    ADD CONSTRAINT fk_rails_74b2974877 FOREIGN KEY (client_group_id) REFERENCES public.client_groups(id);


--
-- Name: evaluation_involved_supporters fk_rails_786e3bf8f2; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.evaluation_involved_supporters
    ADD CONSTRAINT fk_rails_786e3bf8f2 FOREIGN KEY (portfolio_item_evaluation_id) REFERENCES public.portfolio_item_evaluations(id);


--
-- Name: portfolio_items fk_rails_7c01184ea9; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_items
    ADD CONSTRAINT fk_rails_7c01184ea9 FOREIGN KEY (portfolio_specialization_id) REFERENCES public.portfolio_specializations(id);


--
-- Name: client_groups fk_rails_7f21c3479d; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_groups
    ADD CONSTRAINT fk_rails_7f21c3479d FOREIGN KEY (teacher_id) REFERENCES public.teachers(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: institution_documents fk_rails_7f6938128e; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.institution_documents
    ADD CONSTRAINT fk_rails_7f6938128e FOREIGN KEY (institution_id) REFERENCES public.institutions(id);


--
-- Name: portfolio_dbrcs fk_rails_7f73aaa872; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_dbrcs
    ADD CONSTRAINT fk_rails_7f73aaa872 FOREIGN KEY (client_id) REFERENCES public.clients(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: diagnostic_institution_stocks fk_rails_82b7613f18; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.diagnostic_institution_stocks
    ADD CONSTRAINT fk_rails_82b7613f18 FOREIGN KEY (diagnostic_id) REFERENCES public.diagnostics(id);


--
-- Name: client_supporter_relations fk_rails_8ab2fc9229; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_supporter_relations
    ADD CONSTRAINT fk_rails_8ab2fc9229 FOREIGN KEY (supporter_id) REFERENCES public.supporters(id);


--
-- Name: advancement_plan_institution_stocks fk_rails_8df7175366; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.advancement_plan_institution_stocks
    ADD CONSTRAINT fk_rails_8df7175366 FOREIGN KEY (advancement_plan_id) REFERENCES public.advancement_plans(id);


--
-- Name: questionnaires fk_rails_8fd9957206; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.questionnaires
    ADD CONSTRAINT fk_rails_8fd9957206 FOREIGN KEY (supporter_id) REFERENCES public.supporters(id);


--
-- Name: client_duplicate_detections fk_rails_90bc7cd0f3; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_duplicate_detections
    ADD CONSTRAINT fk_rails_90bc7cd0f3 FOREIGN KEY (client_duplicate_detection_request_id) REFERENCES public.client_duplicate_detection_requests(id);


--
-- Name: clients fk_rails_94a9a82be4; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.clients
    ADD CONSTRAINT fk_rails_94a9a82be4 FOREIGN KEY (expertise_teacher_id) REFERENCES public.teachers(id) ON DELETE SET NULL;


--
-- Name: supporters fk_rails_97adf32f4f; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.supporters
    ADD CONSTRAINT fk_rails_97adf32f4f FOREIGN KEY (institution_id) REFERENCES public.institutions(id);


--
-- Name: checklist_questions fk_rails_98779571e5; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_questions
    ADD CONSTRAINT fk_rails_98779571e5 FOREIGN KEY (checklist_id) REFERENCES public.checklists(id) ON DELETE CASCADE;


--
-- Name: checklist_groups fk_rails_9e1162cf48; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_groups
    ADD CONSTRAINT fk_rails_9e1162cf48 FOREIGN KEY (checklist_id) REFERENCES public.checklists(id) ON DELETE CASCADE;


--
-- Name: checklist_question_tpls fk_rails_a17a472484; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_question_tpls
    ADD CONSTRAINT fk_rails_a17a472484 FOREIGN KEY (checklist_group_tpl_id) REFERENCES public.checklist_group_tpls(id) ON DELETE CASCADE;


--
-- Name: checklists fk_rails_a31fed2450; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklists
    ADD CONSTRAINT fk_rails_a31fed2450 FOREIGN KEY (teacher_id) REFERENCES public.teachers(id) ON DELETE SET NULL;


--
-- Name: advancement_plan_institution_stocks fk_rails_a57678d533; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.advancement_plan_institution_stocks
    ADD CONSTRAINT fk_rails_a57678d533 FOREIGN KEY (institution_id) REFERENCES public.institutions(id);


--
-- Name: portfolio_dbrcs fk_rails_a74cbb0174; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_dbrcs
    ADD CONSTRAINT fk_rails_a74cbb0174 FOREIGN KEY (questionnaire_result_id) REFERENCES public.questionnaire_results(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: portfolio_conditions fk_rails_a9e4350df3; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_conditions
    ADD CONSTRAINT fk_rails_a9e4350df3 FOREIGN KEY (rule_id) REFERENCES public.portfolio_rules(id);


--
-- Name: portfolio_conditions_steps fk_rails_ab41c1c0b3; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_conditions_steps
    ADD CONSTRAINT fk_rails_ab41c1c0b3 FOREIGN KEY (step_id) REFERENCES public.portfolio_steps(id);


--
-- Name: portfolio_item_involved_guardians fk_rails_abbe964c80; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_involved_guardians
    ADD CONSTRAINT fk_rails_abbe964c80 FOREIGN KEY (portfolio_item_id) REFERENCES public.portfolio_items(id);


--
-- Name: portfolio_conditions_steps fk_rails_afc60ddf1d; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_conditions_steps
    ADD CONSTRAINT fk_rails_afc60ddf1d FOREIGN KEY (condition_id) REFERENCES public.portfolio_conditions(id);


--
-- Name: clients fk_rails_b04342ea4f; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.clients
    ADD CONSTRAINT fk_rails_b04342ea4f FOREIGN KEY (expertise_manager_id) REFERENCES public.managers(id) ON DELETE SET NULL;


--
-- Name: institutions fk_rails_b1843c638a; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.institutions
    ADD CONSTRAINT fk_rails_b1843c638a FOREIGN KEY (address_id) REFERENCES public.addresses(id);


--
-- Name: evaluation_involved_persons fk_rails_b32a7c370b; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.evaluation_involved_persons
    ADD CONSTRAINT fk_rails_b32a7c370b FOREIGN KEY (portfolio_item_evaluation_id) REFERENCES public.portfolio_item_evaluations(id);


--
-- Name: checklist_group_tpls fk_rails_bd7f0ae1bc; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_group_tpls
    ADD CONSTRAINT fk_rails_bd7f0ae1bc FOREIGN KEY (portfolio_specialization_id) REFERENCES public.portfolio_specializations(id) ON DELETE SET NULL;


--
-- Name: client_duplicate_detections fk_rails_bf01373527; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_duplicate_detections
    ADD CONSTRAINT fk_rails_bf01373527 FOREIGN KEY (client_duplicate_request_id) REFERENCES public.client_duplicate_requests(id);


--
-- Name: diagnostic_borrows fk_rails_c39789f31f; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.diagnostic_borrows
    ADD CONSTRAINT fk_rails_c39789f31f FOREIGN KEY (institution_id) REFERENCES public.institutions(id);


--
-- Name: career_items fk_rails_c447ad462d; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.career_items
    ADD CONSTRAINT fk_rails_c447ad462d FOREIGN KEY (client_group_id) REFERENCES public.client_groups(id) ON DELETE SET NULL;


--
-- Name: questionnaire_results fk_rails_c45556c53a; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.questionnaire_results
    ADD CONSTRAINT fk_rails_c45556c53a FOREIGN KEY (questionnaire_id) REFERENCES public.questionnaires(id);


--
-- Name: checklists fk_rails_c462d93aa8; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklists
    ADD CONSTRAINT fk_rails_c462d93aa8 FOREIGN KEY (manager_id) REFERENCES public.managers(id) ON DELETE SET NULL;


--
-- Name: institutions fk_rails_c765ff0f05; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.institutions
    ADD CONSTRAINT fk_rails_c765ff0f05 FOREIGN KEY (institution_category_id) REFERENCES public.institution_categories(id);


--
-- Name: client_groups fk_rails_d22141498e; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_groups
    ADD CONSTRAINT fk_rails_d22141498e FOREIGN KEY (semester_id) REFERENCES public.semesters(id);


--
-- Name: portfolio_items fk_rails_d51f21d867; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_items
    ADD CONSTRAINT fk_rails_d51f21d867 FOREIGN KEY (portfolio_step_result_id) REFERENCES public.portfolio_step_results(id);


--
-- Name: portfolio_step_results fk_rails_d57ea9e4d4; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_step_results
    ADD CONSTRAINT fk_rails_d57ea9e4d4 FOREIGN KEY (step_id) REFERENCES public.portfolio_steps(id);


--
-- Name: portfolio_item_involved_teachers fk_rails_d9734cd045; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_involved_teachers
    ADD CONSTRAINT fk_rails_d9734cd045 FOREIGN KEY (teacher_id) REFERENCES public.teachers(id);


--
-- Name: checklist_questions_portfolio_items fk_rails_e223294071; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklist_questions_portfolio_items
    ADD CONSTRAINT fk_rails_e223294071 FOREIGN KEY (portfolio_item_id) REFERENCES public.portfolio_items(id) ON DELETE CASCADE;


--
-- Name: portfolio_item_involved_guardians fk_rails_e537b0fce7; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_involved_guardians
    ADD CONSTRAINT fk_rails_e537b0fce7 FOREIGN KEY (guardian_id) REFERENCES public.guardians(id);


--
-- Name: checklists fk_rails_e5b7d74d21; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.checklists
    ADD CONSTRAINT fk_rails_e5b7d74d21 FOREIGN KEY (portfolio_specialization_id) REFERENCES public.portfolio_specializations(id) ON DELETE SET NULL;


--
-- Name: portfolio_item_involved_supporters fk_rails_ea2c403e68; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_involved_supporters
    ADD CONSTRAINT fk_rails_ea2c403e68 FOREIGN KEY (supporter_id) REFERENCES public.supporters(id);


--
-- Name: portfolio_item_involved_teachers fk_rails_f021c14c75; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_involved_teachers
    ADD CONSTRAINT fk_rails_f021c14c75 FOREIGN KEY (portfolio_item_id) REFERENCES public.portfolio_items(id);


--
-- Name: client_group_histories fk_rails_f46a6ad99a; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.client_group_histories
    ADD CONSTRAINT fk_rails_f46a6ad99a FOREIGN KEY (client_group_id) REFERENCES public.client_groups(id);


--
-- Name: advancement_plan_borrows fk_rails_fac03adcd9; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.advancement_plan_borrows
    ADD CONSTRAINT fk_rails_fac03adcd9 FOREIGN KEY (institution_id) REFERENCES public.institutions(id);


--
-- Name: portfolio_item_measurements fk_rails_fd4c24bfca; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_item_measurements
    ADD CONSTRAINT fk_rails_fd4c24bfca FOREIGN KEY (portfolio_item_id) REFERENCES public.portfolio_items(id);


--
-- Name: teacher_institution_relations fk_rails_ffdcc8f696; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.teacher_institution_relations
    ADD CONSTRAINT fk_rails_ffdcc8f696 FOREIGN KEY (institution_id) REFERENCES public.institutions(id);


--
-- Name: user_messages fk_um_on_st_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.user_messages
    ADD CONSTRAINT fk_um_on_st_id FOREIGN KEY (system_task_id) REFERENCES public.system_tasks(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: portfolio_template_documents idx_ptd_on_pr; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.portfolio_template_documents
    ADD CONSTRAINT idx_ptd_on_pr FOREIGN KEY (rule_id) REFERENCES public.portfolio_rules(id);


--
-- PostgreSQL database dump complete
--

SET search_path TO public;

INSERT INTO schema_migrations (version) VALUES ('20151007113755');

INSERT INTO schema_migrations (version) VALUES ('20151015092650');

INSERT INTO schema_migrations (version) VALUES ('20151016100428');

INSERT INTO schema_migrations (version) VALUES ('20151016122102');

INSERT INTO schema_migrations (version) VALUES ('20151016122419');

INSERT INTO schema_migrations (version) VALUES ('20151019102904');

INSERT INTO schema_migrations (version) VALUES ('20151019104007');

INSERT INTO schema_migrations (version) VALUES ('20151020145914');

INSERT INTO schema_migrations (version) VALUES ('20151020155908');

INSERT INTO schema_migrations (version) VALUES ('20151021121722');

INSERT INTO schema_migrations (version) VALUES ('20151103131547');

INSERT INTO schema_migrations (version) VALUES ('20151116145001');

INSERT INTO schema_migrations (version) VALUES ('20151117123903');

INSERT INTO schema_migrations (version) VALUES ('20151201195043');

INSERT INTO schema_migrations (version) VALUES ('20151207141214');

INSERT INTO schema_migrations (version) VALUES ('20151208163856');

INSERT INTO schema_migrations (version) VALUES ('20151210101707');

INSERT INTO schema_migrations (version) VALUES ('20151211125428');

INSERT INTO schema_migrations (version) VALUES ('20151217121333');

INSERT INTO schema_migrations (version) VALUES ('20151217121737');

INSERT INTO schema_migrations (version) VALUES ('20151217121738');

INSERT INTO schema_migrations (version) VALUES ('20160107102331');

INSERT INTO schema_migrations (version) VALUES ('20160111134125');

INSERT INTO schema_migrations (version) VALUES ('20160119091957');

INSERT INTO schema_migrations (version) VALUES ('20160125115219');

INSERT INTO schema_migrations (version) VALUES ('20160125120050');

INSERT INTO schema_migrations (version) VALUES ('20160126110716');

INSERT INTO schema_migrations (version) VALUES ('20160202130830');

INSERT INTO schema_migrations (version) VALUES ('20160216131639');

INSERT INTO schema_migrations (version) VALUES ('20160301135817');

INSERT INTO schema_migrations (version) VALUES ('20160301151956');

INSERT INTO schema_migrations (version) VALUES ('20160301153514');

INSERT INTO schema_migrations (version) VALUES ('20160301153650');

INSERT INTO schema_migrations (version) VALUES ('20160308102706');

INSERT INTO schema_migrations (version) VALUES ('20160308112113');

INSERT INTO schema_migrations (version) VALUES ('20160315150415');

INSERT INTO schema_migrations (version) VALUES ('20160323074905');

INSERT INTO schema_migrations (version) VALUES ('20160323102753');

INSERT INTO schema_migrations (version) VALUES ('20160323121345');

INSERT INTO schema_migrations (version) VALUES ('20160329130927');

INSERT INTO schema_migrations (version) VALUES ('20160412122927');

INSERT INTO schema_migrations (version) VALUES ('20160421073137');

INSERT INTO schema_migrations (version) VALUES ('20160422093556');

INSERT INTO schema_migrations (version) VALUES ('20160422094603');

INSERT INTO schema_migrations (version) VALUES ('20160427142847');

INSERT INTO schema_migrations (version) VALUES ('20160428115301');

INSERT INTO schema_migrations (version) VALUES ('20160428191444');

INSERT INTO schema_migrations (version) VALUES ('20160501172821');

INSERT INTO schema_migrations (version) VALUES ('20160501175308');

INSERT INTO schema_migrations (version) VALUES ('20160503090913');

INSERT INTO schema_migrations (version) VALUES ('20160503092449');

INSERT INTO schema_migrations (version) VALUES ('20160503092634');

INSERT INTO schema_migrations (version) VALUES ('20160503092824');

INSERT INTO schema_migrations (version) VALUES ('20160503111402');

INSERT INTO schema_migrations (version) VALUES ('20160503123829');

INSERT INTO schema_migrations (version) VALUES ('20160509085833');

INSERT INTO schema_migrations (version) VALUES ('20160509144241');

INSERT INTO schema_migrations (version) VALUES ('20160510082947');

INSERT INTO schema_migrations (version) VALUES ('20160511101020');

INSERT INTO schema_migrations (version) VALUES ('20160523090907');

INSERT INTO schema_migrations (version) VALUES ('20160524083748');

INSERT INTO schema_migrations (version) VALUES ('20160530113910');

INSERT INTO schema_migrations (version) VALUES ('20160531143156');

INSERT INTO schema_migrations (version) VALUES ('20160603090743');

INSERT INTO schema_migrations (version) VALUES ('20160603121319');

INSERT INTO schema_migrations (version) VALUES ('20160607205952');

INSERT INTO schema_migrations (version) VALUES ('20160608084019');

INSERT INTO schema_migrations (version) VALUES ('20160608085539');

INSERT INTO schema_migrations (version) VALUES ('20160608085737');

INSERT INTO schema_migrations (version) VALUES ('20160608120727');

INSERT INTO schema_migrations (version) VALUES ('20160610113353');

INSERT INTO schema_migrations (version) VALUES ('20160616131720');

INSERT INTO schema_migrations (version) VALUES ('20160622124219');

INSERT INTO schema_migrations (version) VALUES ('20160623074455');

INSERT INTO schema_migrations (version) VALUES ('20160623123657');

INSERT INTO schema_migrations (version) VALUES ('20160627070744');

INSERT INTO schema_migrations (version) VALUES ('20160629132217');

INSERT INTO schema_migrations (version) VALUES ('20160630115508');

INSERT INTO schema_migrations (version) VALUES ('20160630130050');

INSERT INTO schema_migrations (version) VALUES ('20160701082342');

INSERT INTO schema_migrations (version) VALUES ('20160701084324');

INSERT INTO schema_migrations (version) VALUES ('20160705151627');

INSERT INTO schema_migrations (version) VALUES ('20160705152547');

INSERT INTO schema_migrations (version) VALUES ('20160708110124');

INSERT INTO schema_migrations (version) VALUES ('20160708110903');

INSERT INTO schema_migrations (version) VALUES ('20160708143710');

INSERT INTO schema_migrations (version) VALUES ('20160709155800');

INSERT INTO schema_migrations (version) VALUES ('20160711091347');

INSERT INTO schema_migrations (version) VALUES ('20160714112608');

INSERT INTO schema_migrations (version) VALUES ('20160715101228');

INSERT INTO schema_migrations (version) VALUES ('20160719105641');

INSERT INTO schema_migrations (version) VALUES ('20160719145322');

INSERT INTO schema_migrations (version) VALUES ('20160728102710');

INSERT INTO schema_migrations (version) VALUES ('20160816145214');

INSERT INTO schema_migrations (version) VALUES ('20160816150212');

INSERT INTO schema_migrations (version) VALUES ('20160825094007');

INSERT INTO schema_migrations (version) VALUES ('20160825094053');

INSERT INTO schema_migrations (version) VALUES ('20160825094109');

INSERT INTO schema_migrations (version) VALUES ('20160830102555');

INSERT INTO schema_migrations (version) VALUES ('20160830150606');

INSERT INTO schema_migrations (version) VALUES ('20160830151636');

INSERT INTO schema_migrations (version) VALUES ('20160831115230');

INSERT INTO schema_migrations (version) VALUES ('20160905113527');

INSERT INTO schema_migrations (version) VALUES ('20160906082545');

INSERT INTO schema_migrations (version) VALUES ('20160907082643');

INSERT INTO schema_migrations (version) VALUES ('20160907140203');

INSERT INTO schema_migrations (version) VALUES ('20160912082934');

INSERT INTO schema_migrations (version) VALUES ('20160913083904');

INSERT INTO schema_migrations (version) VALUES ('20160919122858');

INSERT INTO schema_migrations (version) VALUES ('20160920114048');

INSERT INTO schema_migrations (version) VALUES ('20160920143353');

INSERT INTO schema_migrations (version) VALUES ('20160920150948');

INSERT INTO schema_migrations (version) VALUES ('20160922113022');

INSERT INTO schema_migrations (version) VALUES ('20160927111907');

INSERT INTO schema_migrations (version) VALUES ('20160927144953');

INSERT INTO schema_migrations (version) VALUES ('20160929130931');

INSERT INTO schema_migrations (version) VALUES ('20161010112329');

INSERT INTO schema_migrations (version) VALUES ('20161027114641');

INSERT INTO schema_migrations (version) VALUES ('20161031125430');

INSERT INTO schema_migrations (version) VALUES ('20161102134424');

INSERT INTO schema_migrations (version) VALUES ('20161110132203');

INSERT INTO schema_migrations (version) VALUES ('20161122111433');

INSERT INTO schema_migrations (version) VALUES ('20161123092203');

INSERT INTO schema_migrations (version) VALUES ('20161129102331');

INSERT INTO schema_migrations (version) VALUES ('20161130122413');

INSERT INTO schema_migrations (version) VALUES ('20161201105149');

INSERT INTO schema_migrations (version) VALUES ('20161201121647');

INSERT INTO schema_migrations (version) VALUES ('20161202090035');

INSERT INTO schema_migrations (version) VALUES ('20161202105158');

INSERT INTO schema_migrations (version) VALUES ('20161205115921');

INSERT INTO schema_migrations (version) VALUES ('20161206132850');

INSERT INTO schema_migrations (version) VALUES ('20161206140127');

INSERT INTO schema_migrations (version) VALUES ('20161206163701');

INSERT INTO schema_migrations (version) VALUES ('20161219114529');

INSERT INTO schema_migrations (version) VALUES ('20161221111005');

INSERT INTO schema_migrations (version) VALUES ('20170123095908');

INSERT INTO schema_migrations (version) VALUES ('20170127091630');

INSERT INTO schema_migrations (version) VALUES ('20170206123838');

INSERT INTO schema_migrations (version) VALUES ('20170206131717');

INSERT INTO schema_migrations (version) VALUES ('20170301080805');

INSERT INTO schema_migrations (version) VALUES ('20170308123206');

INSERT INTO schema_migrations (version) VALUES ('20170313123037');

INSERT INTO schema_migrations (version) VALUES ('20170320101629');

INSERT INTO schema_migrations (version) VALUES ('20170320101630');

INSERT INTO schema_migrations (version) VALUES ('20170320101631');

INSERT INTO schema_migrations (version) VALUES ('20170320102407');

INSERT INTO schema_migrations (version) VALUES ('20170320102952');

INSERT INTO schema_migrations (version) VALUES ('20170320134314');

INSERT INTO schema_migrations (version) VALUES ('20170323123031');

INSERT INTO schema_migrations (version) VALUES ('20170323135326');

INSERT INTO schema_migrations (version) VALUES ('20170324092626');

INSERT INTO schema_migrations (version) VALUES ('20170329112445');

INSERT INTO schema_migrations (version) VALUES ('20170411080710');

INSERT INTO schema_migrations (version) VALUES ('20170508123729');

INSERT INTO schema_migrations (version) VALUES ('20170509122829');

INSERT INTO schema_migrations (version) VALUES ('20170523094443');

INSERT INTO schema_migrations (version) VALUES ('20170526104108');

INSERT INTO schema_migrations (version) VALUES ('20170530133041');

INSERT INTO schema_migrations (version) VALUES ('20170530153358');

INSERT INTO schema_migrations (version) VALUES ('20170531110747');

INSERT INTO schema_migrations (version) VALUES ('20170531113634');

INSERT INTO schema_migrations (version) VALUES ('20170531122332');

INSERT INTO schema_migrations (version) VALUES ('20170531135322');

INSERT INTO schema_migrations (version) VALUES ('20170606160040');

INSERT INTO schema_migrations (version) VALUES ('20170607125042');

INSERT INTO schema_migrations (version) VALUES ('20170613145409');

INSERT INTO schema_migrations (version) VALUES ('20170624100746');

INSERT INTO schema_migrations (version) VALUES ('20170625160437');

INSERT INTO schema_migrations (version) VALUES ('20170626110218');

INSERT INTO schema_migrations (version) VALUES ('20170707142701');

INSERT INTO schema_migrations (version) VALUES ('20170712124804');

INSERT INTO schema_migrations (version) VALUES ('20170801124131');

INSERT INTO schema_migrations (version) VALUES ('20170904122742');

INSERT INTO schema_migrations (version) VALUES ('20170904135007');

INSERT INTO schema_migrations (version) VALUES ('20170905150320');

INSERT INTO schema_migrations (version) VALUES ('20170906154513');

INSERT INTO schema_migrations (version) VALUES ('20170911120436');

INSERT INTO schema_migrations (version) VALUES ('20170915163724');

INSERT INTO schema_migrations (version) VALUES ('20170921071950');

INSERT INTO schema_migrations (version) VALUES ('20170921111715');

INSERT INTO schema_migrations (version) VALUES ('20170922065338');

INSERT INTO schema_migrations (version) VALUES ('20170922155326');

INSERT INTO schema_migrations (version) VALUES ('20170925081618');

INSERT INTO schema_migrations (version) VALUES ('20170925110602');

INSERT INTO schema_migrations (version) VALUES ('20171002122336');

INSERT INTO schema_migrations (version) VALUES ('20171010082126');

INSERT INTO schema_migrations (version) VALUES ('20171019110945');

INSERT INTO schema_migrations (version) VALUES ('20171110110551');

INSERT INTO schema_migrations (version) VALUES ('20171130122447');

INSERT INTO schema_migrations (version) VALUES ('20171205121823');

INSERT INTO schema_migrations (version) VALUES ('20171215120314');

INSERT INTO schema_migrations (version) VALUES ('20171220113044');

INSERT INTO schema_migrations (version) VALUES ('20180111093511');

INSERT INTO schema_migrations (version) VALUES ('20180116103154');

INSERT INTO schema_migrations (version) VALUES ('20180119085729');

INSERT INTO schema_migrations (version) VALUES ('20180123101805');

INSERT INTO schema_migrations (version) VALUES ('20180123120449');

INSERT INTO schema_migrations (version) VALUES ('20180307120140');

INSERT INTO schema_migrations (version) VALUES ('20180606082109');

INSERT INTO schema_migrations (version) VALUES ('20180612134811');

INSERT INTO schema_migrations (version) VALUES ('20180628105735');

INSERT INTO schema_migrations (version) VALUES ('20180725082721');

INSERT INTO schema_migrations (version) VALUES ('20180730094420');

INSERT INTO schema_migrations (version) VALUES ('20180802094103');

INSERT INTO schema_migrations (version) VALUES ('20180828110353');

INSERT INTO schema_migrations (version) VALUES ('20180903141807');

INSERT INTO schema_migrations (version) VALUES ('20181219110302');

INSERT INTO schema_migrations (version) VALUES ('20190107140122');

INSERT INTO schema_migrations (version) VALUES ('20190122151731');

INSERT INTO schema_migrations (version) VALUES ('20190125124537');

INSERT INTO schema_migrations (version) VALUES ('20190205160106');

INSERT INTO schema_migrations (version) VALUES ('20190212133619');

INSERT INTO schema_migrations (version) VALUES ('20190320114625');

